@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2009 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -13,24 +13,50 @@
 #include "backend/bookshelfmodel/btbookshelftreemodel.h"
 
 #include <QSet>
+#include <QSettings>
 #include "backend/bookshelfmodel/categoryitem.h"
 #include "backend/bookshelfmodel/indexingitem.h"
 #include "backend/bookshelfmodel/languageitem.h"
 #include "backend/bookshelfmodel/moduleitem.h"
+#include "backend/config/cbtconfig.h"
+#include "util/macros.h"
 
 
 using namespace BookshelfModel;
 
+bool BtBookshelfTreeModel::Grouping::loadFrom(const QString &configKey) {
+    Q_ASSERT(!configKey.isNull());
+    QVariant v = CBTConfig::getConfig()->value(configKey);
+    (*this) = v.value<Grouping>();
+    return v.canConvert<Grouping>();
+}
+
+void BtBookshelfTreeModel::Grouping::saveTo(const QString &configKey) const {
+    Q_ASSERT(!configKey.isNull());
+    CBTConfig::getConfig()->setValue(configKey, QVariant::fromValue(*this));
+}
+
+
 BtBookshelfTreeModel::BtBookshelfTreeModel(QObject *parent)
-        : QAbstractItemModel(parent), m_sourceModel(0), m_rootItem(new RootItem),
-        m_defaultChecked(MODULE_HIDDEN), m_checkable(false) {
-    m_groupingOrder.push_back(GROUP_CATEGORY);
-    m_groupingOrder.push_back(GROUP_LANGUAGE);
+    : QAbstractItemModel(parent), m_sourceModel(0), m_rootItem(new RootItem),
+    m_defaultChecked(MODULE_HIDDEN), m_checkable(false)
+{
+    // Intentionally empty
+}
+
+BtBookshelfTreeModel::BtBookshelfTreeModel(const QString &configKey,
+                                           QObject *parent)
+       : QAbstractItemModel(parent), m_sourceModel(0), m_rootItem(new RootItem),
+       m_groupingOrder(configKey), m_defaultChecked(MODULE_HIDDEN),
+       m_checkable(false)
+{
+    // Intentionally empty
 }
 
 BtBookshelfTreeModel::BtBookshelfTreeModel(const Grouping &g, QObject *parent)
         : QAbstractItemModel(parent), m_sourceModel(0), m_rootItem(new RootItem),
-        m_groupingOrder(g), m_defaultChecked(MODULE_HIDDEN), m_checkable(false) {
+        m_groupingOrder(g), m_defaultChecked(MODULE_HIDDEN), m_checkable(false)
+{
     // Intentionally empty
 }
 
@@ -123,13 +149,14 @@ QVariant BtBookshelfTreeModel::data(CSwordModuleInfo *module, int role) const {
 bool BtBookshelfTreeModel::setData(const QModelIndex &itemIndex,
                                    const QVariant &value,
                                    int role) {
+    Q_ASSERT(itemIndex.isValid());
     typedef QPair<Item *, QModelIndex> IP;
 
     Qt::CheckState newState;
-    if (role == Qt::CheckStateRole) {
+    if (LIKELY(role == Qt::CheckStateRole)) {
         bool ok;
         newState = (Qt::CheckState) value.toInt(&ok);
-        if (!ok) return false;
+        if (UNLIKELY(!ok)) return false;
     }
     else {
         return false;
@@ -262,7 +289,9 @@ void BtBookshelfTreeModel::setSourceModel(QAbstractItemModel *sourceModel) {
     }
 }
 
-void BtBookshelfTreeModel::setGroupingOrder(const Grouping &groupingOrder) {
+void BtBookshelfTreeModel::setGroupingOrder(const Grouping &groupingOrder,
+                                            bool emitSignal)
+{
     if (m_groupingOrder == groupingOrder) return;
     m_groupingOrder = groupingOrder;
 
@@ -291,6 +320,8 @@ void BtBookshelfTreeModel::setGroupingOrder(const Grouping &groupingOrder) {
             addModule(module, checked.contains(module));
         }
     }
+
+    if (emitSignal) emit groupingOrderChanged(groupingOrder);
 }
 
 void BtBookshelfTreeModel::setCheckable(bool checkable) {
@@ -299,14 +330,29 @@ void BtBookshelfTreeModel::setCheckable(bool checkable) {
     if (m_sourceModel == 0) return;
 
     // Notify views that flags changed for all items:
+    resetData();
+}
+
+void BtBookshelfTreeModel::setCheckedModules(const QSet<CSwordModuleInfo*> &modules) {
+    typedef ModuleItemMap::const_iterator MIMCI;
+
+    for (MIMCI it(m_modules.constBegin()); it != m_modules.constEnd(); it++) {
+        if (modules.contains(it.key())) {
+            setData(getIndex(it.value()), Qt::Checked, Qt::CheckStateRole);
+        } else {
+            setData(getIndex(it.value()), Qt::Unchecked, Qt::CheckStateRole);
+        }
+    }
+}
+
+void BtBookshelfTreeModel::resetData() {
     QModelIndexList queue;
     queue.append(QModelIndex());
     do {
         QModelIndex parent(queue.takeFirst());
-        int numChildren(rowCount(parent));
         emit dataChanged(index(0, 0, parent),
-                         index(numChildren - 1, 0, parent));
-        for (int i(0); i < numChildren; i++) {
+                         index(rowCount(parent) - 1, columnCount() - 1, parent));
+        for (int i(0); i < rowCount(parent); i++) {
             QModelIndex childIndex(index(i, 0, parent));
             if (rowCount(childIndex) > 0) {
                 queue.append(childIndex);
@@ -402,7 +448,7 @@ void BtBookshelfTreeModel::removeModule(CSwordModuleInfo *module) {
 }
 
 Item *BtBookshelfTreeModel::getItem(const QModelIndex &index) const {
-    if (index.isValid()) {
+    if (LIKELY(index.isValid())) {
         Item *item(static_cast<Item*>(index.internalPointer()));
         Q_ASSERT(item != 0);
         return item;
@@ -504,8 +550,7 @@ void BtBookshelfTreeModel::moduleDataChanged(const QModelIndex &topLeft,
     }
 }
 
-void BtBookshelfTreeModel::moduleInserted(const QModelIndex &parent, int start,
-        int end) {
+void BtBookshelfTreeModel::moduleInserted(const QModelIndex &parent, int start, int end) {
     typedef BtBookshelfModel BM;
     static const BM::ModuleRole PR(BM::ModulePointerRole);
     static const BM::ModuleRole HR(BM::ModuleHiddenRole);
@@ -531,8 +576,7 @@ void BtBookshelfTreeModel::moduleInserted(const QModelIndex &parent, int start,
     }
 }
 
-void BtBookshelfTreeModel::moduleRemoved(const QModelIndex &parent, int start,
-        int end) {
+void BtBookshelfTreeModel::moduleRemoved(const QModelIndex &parent, int start, int end) {
     typedef BtBookshelfModel BM;
     static const BM::ModuleRole PR(BM::ModulePointerRole);
 
@@ -557,6 +601,7 @@ QDataStream &operator<<(QDataStream &os, const BtBookshelfTreeModel::Grouping &o
 QDataStream &operator>>(QDataStream &is, BtBookshelfTreeModel::Grouping &o) {
     int s;
     is >> s;
+    o.clear();
     for (int i(0); i < s; i++) {
         int g;
         is >> g;
