@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -27,21 +27,21 @@ different set of filters you have to create a new tree - it's not possible to mo
 
 Example:
 
-	...
-	QList<BTModuleTreeItem::Filter*> noFilters
-	BTModuleTreeItem root(noFilters, BTModuleTreeItem::CatLangMod);
-	add_to_view(&root, qtreewidget->invisibleRootItem());
-	...
-	void add_to_view(BTModuleTreeItem* item, QTreeWidgetItem* widgetItem) {
-		foreach (BTModuleTreeItem* i, item->children()) {
-			add_to_view(i, new QTreeWidgetItem(widgetItem));
-		}
-		if (item->type() == BTModuleTreeItem::Category) prepare_category_item(widgetItem, item);
-		...
-	}
+    ...
+    QList<BTModuleTreeItem::Filter*> noFilters
+    BTModuleTreeItem root(noFilters, BTModuleTreeItem::CatLangMod);
+    add_to_view(&root, qtreewidget->invisibleRootItem());
+    ...
+    void add_to_view(BTModuleTreeItem* item, QTreeWidgetItem* widgetItem) {
+        foreach (BTModuleTreeItem* i, item->children()) {
+            add_to_view(i, new QTreeWidgetItem(widgetItem));
+        }
+        if (item->type() == BTModuleTreeItem::Category) prepare_category_item(widgetItem, item);
+        ...
+    }
 
 
-	@author The BibleTime team <info@bibletime.info>
+    @author The BibleTime team <info@bibletime.info>
 */
 class BTModuleTreeItem {
     public:
@@ -63,10 +63,10 @@ class BTModuleTreeItem {
         * will stop with the first negative.
         *
         * Example:
-        *	QList<BTModuleTreeItem::Filter*> filters;
-        *	MyFilter filter; BTModuleTreeItem::HiddenOff hideFilter;
-        *	filters.append(&hideFilter); filters.append(&filter);
-        *	BTModuleTreeItem root(filters, BTModuleTreeItem::CatLangMod);
+        *    QList<BTModuleTreeItem::Filter*> filters;
+        *    MyFilter filter; BTModuleTreeItem::HiddenOff hideFilter;
+        *    filters.append(&hideFilter); filters.append(&filter);
+        *    BTModuleTreeItem root(filters, BTModuleTreeItem::CatLangMod);
         */
         struct Filter {
             virtual bool filter(CSwordModuleInfo*) = 0;
@@ -102,7 +102,7 @@ class BTModuleTreeItem {
         * The root item is populated with the item tree.
         * The constructor takes a list of filters (see Filter), grouping indicator (see Grouping)
         * and optionally the module list from which the tree is constructed
-        * (by default CPointers::backend()->moduleList() is used).
+        * (by default CSwordBackend::instance()()->moduleList() is used).
         */
         BTModuleTreeItem(QList<BTModuleTreeItem::Filter*>& filters,
                          BTModuleTreeItem::Grouping grouping, QList<CSwordModuleInfo*>* modules = 0);
