@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -16,9 +16,9 @@
 #include <QWebSettings>
 #include "backend/btmoduletreeitem.h"
 #include "backend/managers/cdisplaytemplatemgr.h"
+#include "btglobal.h"
 #include "frontend/displaywindow/btactioncollection.h"
 #include "frontend/searchdialog/btsearchoptionsarea.h"
-#include "util/cpointers.h"
 #include "util/directory.h"
 
 // Sword includes:
@@ -91,6 +91,8 @@ QString getKey(const bools ID) {
             return "autoTileHorizontal";
         case autoTile:
             return "autoTile";
+        case autoTabbed:
+            return "autoTabbed";
         case autoCascade:
             return "autoCascade";
 
@@ -112,18 +114,24 @@ QString getKey(const bools ID) {
             return "bookshelfShowHidden";
         case allowNetworkConnection:
             return "allowNetworkConnection";
-            
+
         case showTextWindowHeaders:
             return "showTextWindowHeaders";
         case showTextWindowNavigator:
             return "showTextWindowNavigator";
         case showTextWindowModuleSelectorButtons:
             return "showTextWindowModuleSelectorButtons";
+        case showFormatToolbarButtons:
+            return "showFormatToolbarButtons";
         case showTextWindowToolButtons:
             return "showTextWindowToolButtons";
+        case showToolbarsInEachWindow:
+            return "showToolbarsInEachWindow";
+        case showTipAtStartup:
+            return "showTipAtStartup";
     }
     Q_ASSERT(false);
-    return false;
+    return QString::null;
 }
 
 QString getKey(const ints ID) {
@@ -188,6 +196,8 @@ QString getKey(const ints ID) {
             return "configDialogHeight";
         case configDialogWidth:
             return "configDialogWidth";
+        case tipNumber:
+            return "tipNumber";
     }
     Q_ASSERT(false);
     return QString::null;
@@ -249,7 +259,7 @@ QString IntListToString(const QList<int> intList) {
     return intStrings.join(",");
 }
 
-QList<int> StringToIntList(const QString intListString) {
+QList<int> StringToIntList(const QString &intListString) {
     QList<int> intList;
     if (!intListString.isEmpty() && intListString.contains(',')) {
         foreach(QString intString, intListString.split(',')) {
@@ -268,13 +278,13 @@ QString getDefault(const strings ID) {
         case displayStyle:
             return CDisplayTemplateMgr::defaultTemplate();
         case bookshelfCurrentItem:
-            return QString();
+            return QString::null;
     }
     return QString::null;
 }
 
 QString getDefault(const modules ID) {
-    // CSwordBackend *b = CPointers::backend();
+    // CSwordBackend *b = CSwordBackend::instance()();
     switch (ID) {
         case standardBible:
             return "KJV";
@@ -318,6 +328,8 @@ bool getDefault(const bools ID) {
             return false;
         case autoTile:
             return false;
+        case autoTabbed:
+            return false;
         case autoCascade:
             return false;
 
@@ -338,7 +350,7 @@ bool getDefault(const bools ID) {
             return false;
         case allowNetworkConnection:
             return false;
-            
+
         case showTextWindowHeaders:
             return true;
         case showTextWindowNavigator:
@@ -347,6 +359,12 @@ bool getDefault(const bools ID) {
             return true;
         case showTextWindowToolButtons:
             return true;
+        case showFormatToolbarButtons:
+            return true;
+        case showToolbarsInEachWindow:
+            return true;
+        case showTipAtStartup:
+            return true;
     }
     return false;
 }
@@ -413,6 +431,8 @@ int getDefault(const ints ID) {
             return 1;
         case configDialogWidth:
             return 1;
+        case tipNumber:
+            return 0;
     }
     return 0;
 }
@@ -498,7 +518,7 @@ QString get(const strings ID) {
 
 CSwordModuleInfo *get(const modules ID) {
     getConfig()->beginGroup("modules");
-    CSwordModuleInfo *result(CPointers::backend()->findModuleByName(
+    CSwordModuleInfo *result(CSwordBackend::instance()->findModuleByName(
                                  getConfig()->value(getKey(ID), getDefault(ID)).toString()
                              ));
     getConfig()->endGroup();
@@ -603,7 +623,7 @@ FontSettingsPair get(const CLanguageMgr::Language * const language) {
     return settings;
 }
 
-void set(const strings ID, const QString value) {
+void set(const strings ID, const QString &value) {
 //     KConfigGroup cg = getConfig()->group("strings");
 //     cg.writeEntry(getKey(ID), value);
     getConfig()->beginGroup("strings");
@@ -620,7 +640,7 @@ void set(const modules ID, CSwordModuleInfo * const value) {
 }
 
 void set(const modules ID, const QString& value) {
-    CSwordModuleInfo *module(CPointers::backend()->findModuleByName(value));
+    CSwordModuleInfo *module(CSwordBackend::instance()->findModuleByName(value));
     if (module) {
         set(ID, module);
     }
@@ -704,15 +724,15 @@ void set(const CLanguageMgr::Language * const language,
     m_fontCache.remove(language);
 }
 
-CSwordBackend::DisplayOptions getDisplayOptionDefaults() {
-    CSwordBackend::DisplayOptions options;
+DisplayOptions getDisplayOptionDefaults() {
+    DisplayOptions options;
     options.lineBreaks   = get(lineBreaks);
     options.verseNumbers = get(verseNumbers);
     return options;
 }
 
-CSwordBackend::FilterOptions getFilterOptionDefaults() {
-    CSwordBackend::FilterOptions options;
+FilterOptions getFilterOptionDefaults() {
+    FilterOptions options;
 
     options.footnotes           = true; // Required for the info display
     options.strongNumbers       = true; // get(strongNumbers);
