@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -56,6 +56,7 @@ enum bools {
     autoTileVertical,
     autoTileHorizontal,
     autoTile,
+    autoTabbed,
     autoCascade,
 
     lineBreaks,
@@ -73,7 +74,10 @@ enum bools {
     showTextWindowHeaders,
     showTextWindowNavigator,
     showTextWindowToolButtons,
-    showTextWindowModuleSelectorButtons
+    showTextWindowModuleSelectorButtons,
+    showFormatToolbarButtons,
+    showToolbarsInEachWindow,
+    showTipAtStartup
 };
 enum ints {
     footnotes,
@@ -110,7 +114,8 @@ enum ints {
     configDialogPosX,
     configDialogPosY,
     configDialogHeight,
-    configDialogWidth
+    configDialogWidth,
+    tipNumber
 };
 enum intLists {
     leftPaneSplitterSizes,
@@ -140,7 +145,7 @@ enum stringMaps {
 };
 
 QString    IntListToString(const QList<int> intList);
-QList<int> StringToIntList(const QString    intListString);
+QList<int> StringToIntList(const QString   &intListString);
 
 QString     getDefault(const strings);
 QString     getDefault(const modules);
@@ -160,7 +165,7 @@ QStringList       get(const stringLists);
 StringMap         get(const stringMaps);
 FontSettingsPair  get(const CLanguageMgr::Language * const);
 
-void set(const strings,     const QString            value);
+void set(const strings,     const QString           &value);
 void set(const modules,     CSwordModuleInfo * const module);
 void set(const modules,     const QString&           moduleName);
 void set(const bools,       const bool               value);
@@ -171,8 +176,8 @@ void set(const stringMaps,  const StringMap          value);
 void set(const CLanguageMgr::Language * const language,
          const FontSettingsPair &fontSettings);
 
-CSwordBackend::FilterOptions  getFilterOptionDefaults();
-CSwordBackend::DisplayOptions getDisplayOptionDefaults();
+FilterOptions  getFilterOptionDefaults();
+DisplayOptions getDisplayOptionDefaults();
 
 void setupAccelSettings(const keys type,
                         BtActionCollection * const actionCollection);
