@@ -2,14 +2,13 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
 
 #include "backend/drivers/cswordlexiconmoduleinfo.h"
 
-#include <algorithm>
 #include <QFile>
 #include <QDataStream>
 #include <QTextCodec>
@@ -24,45 +23,23 @@
 //Change it once the format changed to make all systems rebuild their caches
 #define CACHE_FORMAT "3"
 
-CSwordLexiconModuleInfo::CSwordLexiconModuleInfo( sword::SWModule* module, CSwordBackend* const backend ) : CSwordModuleInfo(module, backend) {
-    m_entryList = 0;
-}
-
-CSwordLexiconModuleInfo::CSwordLexiconModuleInfo( const CSwordLexiconModuleInfo& m ) : CSwordModuleInfo(m) {
-    delete m_entryList;
-    m_entryList = 0;
-
-    if (m.m_entryList) {
-        m_entryList = new QStringList();
-        *m_entryList = *m.m_entryList;//copy list items
-    }
-}
-
-CSwordLexiconModuleInfo::~CSwordLexiconModuleInfo() {
-    delete m_entryList;
-    m_entryList = 0;
-}
-
-/** Returns the entries of the module. */
-QStringList* CSwordLexiconModuleInfo::entries() {
+const QStringList &CSwordLexiconModuleInfo::entries() const {
     namespace DU = util::directory;
 
-    if (!module()) {
-        return 0;
+    // If cache is ok, just return it:
+    if (!m_entries.empty()) {
+        return m_entries;
     }
 
-    if (m_entryList) return m_entryList;
-
-    m_entryList = new QStringList();
-
+    // Initialize cache:
     //Check for buggy modules! They will not be loaded any more.
     if ( name() == QString("ZhEnglish")) {
         qWarning() << "Module ZhEnglish is buggy and will not be loaded.";
-        return m_entryList;
+        return m_entries;
     }
     if ( name() == QString("EReo_en")) {
         qWarning() << "Module EReo_en is buggy and will not be loaded.";
-        return m_entryList;
+        return m_entries;
     }
 
     QString dir(DU::getUserCacheDir().absolutePath());
@@ -88,11 +65,11 @@ QStringList* CSwordLexiconModuleInfo::entries() {
         if (ModuleVersion == config(CSwordModuleInfo::ModuleVersion)
                 && CacheVersion == CACHE_FORMAT
                 && QDataStreamVersion == QString::number(s.version())) {
-            s >> *m_entryList;
+            s >> m_entries;
 
             f1.close();
-            qDebug() << "Read" << m_entryList->count() << "entries from lexicon cache for module" << name();
-            return m_entryList;
+            qDebug() << "Read" << m_entries.count() << "entries from lexicon cache for module" << name();
+            return m_entries;
         }
 
         f1.close();
@@ -103,40 +80,37 @@ QStringList* CSwordLexiconModuleInfo::entries() {
      */
     qDebug() << "Read all entries of lexicon" << name();
 
-    sword::SWModule* my_module = module();
-    my_module->setSkipConsecutiveLinks(true);
-    (*my_module) = sword::TOP;
+    module()->setSkipConsecutiveLinks(true);
+    module()->setPosition(sword::TOP);
     snap(); //snap to top entry
 
     do {
         if ( isUnicode() ) {
-            m_entryList->append(QString::fromUtf8(my_module->KeyText()));
+            m_entries.append(QString::fromUtf8(module()->KeyText()));
         }
         else {
             //for latin1 modules use fromLatin1 because of speed
             QTextCodec* codec = QTextCodec::codecForName("Windows-1252");
-            m_entryList->append(codec->toUnicode(my_module->KeyText()));
+            m_entries.append(codec->toUnicode(module()->KeyText()));
         }
 
-        (*my_module)++;
-    }
-    while ( !my_module->Error() );
+        module()->increment();
+    } while (!module()->Error());
 
-    (*my_module) = sword::TOP; //back to the first entry
+    module()->setPosition(sword::TOP); // back to the first entry
+    module()->setSkipConsecutiveLinks(false);
 
-    my_module->setSkipConsecutiveLinks(false);
+    if (m_entries.count()) {
+        m_entries.first().simplified();
 
-    if (m_entryList->count()) {
-        m_entryList->first().simplified();
-
-        if (m_entryList->first().trimmed().isEmpty()) {
-            m_entryList->erase( m_entryList->begin() );
+        if (m_entries.first().trimmed().isEmpty()) {
+            m_entries.erase( m_entries.begin() );
         }
     }
 
     qDebug() << "Writing cache file for lexicon module" << name();
 
-    if (m_entryList->count()) {
+    if (m_entries.count()) {
         //create cache
         QString dir(DU::getUserCacheDir().absolutePath());
         QFile f2( QString(dir).append("/").append(name()) );
@@ -146,24 +120,10 @@ QStringList* CSwordLexiconModuleInfo::entries() {
             s << config(CSwordModuleInfo::ModuleVersion) //store module version
             << QString(CACHE_FORMAT) //store BT version -- format may change
             << QString::number(s.version()) //store QDataStream version -- format may change
-            << *m_entryList;
+            << m_entries;
             f2.close();
         }
     }
 
-    return m_entryList;
-}
-
-/** Jumps to the closest entry in the module.  */
-bool CSwordLexiconModuleInfo::snap() {
-    if (module()->getRawEntry()) { // Snap to the current entry
-        return true;
-    }
-
-    return false;
-}
-
-/** No descriptions */
-CSwordModuleInfo* CSwordLexiconModuleInfo::clone() {
-    return new CSwordLexiconModuleInfo(*this);
+    return m_entries;
 }
