@@ -2,14 +2,14 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
 
 #include "backend/drivers/cswordmoduleinfo.h"
 
-#include <boost/scoped_ptr.hpp>
+#include <QSharedPointer>
 #include <CLucene.h>
 #include <CLucene/util/Misc.h>
 #include <CLucene/util/Reader.h>
@@ -28,8 +28,9 @@
 #include "backend/managers/cswordbackend.h"
 #include "backend/rendering/centrydisplay.h"
 #include "backend/cswordmodulesearch.h"
+#include "btglobal.h"
+#include "util/cresmgr.h"
 #include "util/directory.h"
-#include "util/cpointers.h"
 #include "util/exceptions.h"
 #include "util/dialogutil.h"
 
@@ -42,6 +43,29 @@
 #include <versekey.h>
 
 
+#ifdef BT_DEBUG
+namespace {
+
+/** HELPER Method to dump all current EntryAttributes of a module. */
+void dumpEntryAttributes(sword::SWModule *m) {
+    qDebug() << "Attributes for key: " << m->getKeyText();
+    sword::AttributeTypeList::iterator i1;
+    sword::AttributeList::iterator i2;
+    sword::AttributeValue::iterator i3;
+    for (i1 = m->getEntryAttributes().begin(); i1 != m->getEntryAttributes().end(); i1++) {
+        qDebug() << "[ " << i1->first << " ]";
+        for (i2 = i1->second.begin(); i2 != i1->second.end(); i2++) {
+            qDebug() << "\t[ " << i2->first << " ]";
+            for (i3 = i2->second.begin(); i3 != i2->second.end(); i3++) {
+                qDebug() << "\t\t" << i3->first << " = " << i3->second;
+            }
+        }
+    }
+}
+
+} // anonymous namespace
+#endif
+
 //Increment this, if the index format changes
 //Then indices on the user's systems will be rebuilt
 const unsigned int INDEX_VERSION = 7;
@@ -50,69 +74,76 @@ const unsigned int INDEX_VERSION = 7;
 //Lucene default is too small
 const unsigned long BT_MAX_LUCENE_FIELD_LENGTH = 1024 * 1024;
 
-CSwordModuleInfo::CSwordModuleInfo(sword::SWModule * module, CSwordBackend * const usedBackend) {
-    m_module = module;
-    Q_ASSERT(module);
+CSwordModuleInfo::CSwordModuleInfo(sword::SWModule *module,
+                                   CSwordBackend * const usedBackend,
+                                   ModuleType type)
+    : m_module(module),
+      m_backend(usedBackend ? usedBackend : CSwordBackend::instance()),
+      m_type(type),
+      m_cancelIndexing(false),
+      m_cachedName(QString::fromUtf8(module->Name())),
+      m_cachedHasVersion(!QString((*m_backend->getConfig())[module->Name()]["Version"]).isEmpty())
+{
+    Q_ASSERT(module != 0);
+    Q_ASSERT(usedBackend != 0);
+
+    initCachedCategory();
+    initCachedLanguage();
 
-    m_cancelIndexing = false;
-    m_searchResult.ClearList();
-    m_backend = usedBackend ? usedBackend : CPointers::backend();
-    m_dataCache.name = module ? QString(module->Name()) : QString::null;
-    m_dataCache.isUnicode = module ? module->isUnicode() : false;
-    m_dataCache.category = UnknownCategory;
-    m_dataCache.language = 0;
-    m_dataCache.hasVersion = !QString((*m_backend->getConfig())[module->Name()]["Version"]).isEmpty();
     m_hidden = CBTConfig::get(CBTConfig::hiddenModules).contains(name());
 
     if (backend()) {
         if (hasVersion() && (minimumSwordVersion() > sword::SWVersion::currentVersion)) {
             qWarning("The module \"%s\" requires a newer Sword library. Please update to \"Sword %s\".",
                      name().toUtf8().constData(), (const char *)minimumSwordVersion());
+
+            /// \todo if this is the case, can we use the module at all?
         }
     }
 }
 
-CSwordModuleInfo::CSwordModuleInfo(const CSwordModuleInfo & m) : QObject() {
-    m_module = m.m_module;
-    m_backend = m.m_backend;
-    m_dataCache = m.m_dataCache;
-    m_searchResult = m.m_searchResult;
-    m_hidden = m.m_hidden;
-    m_cancelIndexing = m.m_cancelIndexing;
+CSwordModuleInfo::CSwordModuleInfo(const CSwordModuleInfo &o)
+    : QObject(0), m_module(o.m_module), m_backend(o.m_backend),
+      m_type(o.m_type), m_hidden(o.m_hidden),
+      m_cancelIndexing(o.m_cancelIndexing), m_cachedName(o.m_cachedName),
+      m_cachedCategory(o.m_cachedCategory),
+      m_cachedLanguage(o.m_cachedLanguage),
+      m_cachedHasVersion(o.m_cachedHasVersion)
+{
+    // Intentionally empty
 }
 
-/** No descriptions */
-CSwordModuleInfo *CSwordModuleInfo::clone() {
-    return new CSwordModuleInfo(*this);
-}
-
-CSwordModuleInfo::~CSwordModuleInfo() {
-    m_searchResult.ClearList();
-    m_module = 0;    //the Sword module object is deleted by the backend
-}
-
-/** Sets the unlock key of the modules and writes the key into the cofig file.*/
 bool CSwordModuleInfo::unlock(const QString & unlockKey) {
     if (!isEncrypted()) {
         return false;
     }
 
+    bool unlocked = unlockKeyIsValid();
+
     CBTConfig::setModuleEncryptionKey(name(), unlockKey);
+
+    /// \todo remove this comment once it is no longer needed
+    /* There is currently a deficiency in sword 1.6.1 in that backend->setCipherKey() does
+     * not work correctly for modules from which data was already fetched. Therefore we have to
+     * reload the modules in bibletime.cpp
+     */
     backend()->setCipherKey(m_module->Name(), unlockKey.toUtf8().constData());
+
     /// \todo write to Sword config as well
 
+    if (unlockKeyIsValid() != unlocked) {
+        emit unlockedChanged(!unlocked);
+    }
     return true;
 }
 
-/** This function returns true if this module is locked, otherwise return false. */
-bool CSwordModuleInfo::isLocked() {
+bool CSwordModuleInfo::isLocked() const {
     //still works, but the cipherkey is stored in CBTConfig.
     //Works because it is set in sword on program startup.
 
     return isEncrypted() && !unlockKeyIsValid();
 }
 
-/** This functions returns true if this module is encrypted (locked or unlocked). */
 bool CSwordModuleInfo::isEncrypted() const {
     /**
     * If we have the CipherKey entry the module
@@ -120,22 +151,18 @@ bool CSwordModuleInfo::isEncrypted() const {
     */
 
     //This code is still right, though we do no longer write to the module config files any more
-    sword::ConfigEntMap config = backend()->getConfig()->Sections.find(name().toUtf8().constData())->second;
+    std::map < sword::SWBuf, sword::ConfigEntMap, std::less < sword::SWBuf > >::iterator SectionMapIter;
+    SectionMapIter = backend()->getConfig()->Sections.find(name().toUtf8().constData());
+    if (SectionMapIter == backend()->getConfig()->Sections.end())
+        return false;
+    sword::ConfigEntMap config = SectionMapIter->second;
     sword::ConfigEntMap::iterator it = config.find("CipherKey");
 
     return it != config.end();
 }
 
-/** This function makes an estimate if a module was properly unlocked.
-* It returns true if the first entry of the module is not empty and
-* contains only printable characters (for the first 100 chars or so).
-* If that is the case, we can safely assume that a) the module was properly
-* unlocked and b) no buffer overflows will occur, which can happen when
-* Sword filters process garbage text which was not properly decrypted.
-*/
-bool CSwordModuleInfo::unlockKeyIsValid() {
-
-    (*m_module) = sword::TOP;
+bool CSwordModuleInfo::unlockKeyIsValid() const {
+    m_module->setPosition(sword::TOP);
 
     // This needs to use ::fromLatin1 because if the text is still locked,
     // a lot of garbage will show up. It will also work with properly decrypted
@@ -146,18 +173,15 @@ bool CSwordModuleInfo::unlockKeyIsValid() {
                    : QString::fromLatin1( m_module->getRawEntryBuf().c_str() );
 
     if (test.isEmpty()) {
-        qWarning() << "Unlock key of module" << name() << "is NOT valid!";
         return false;
     }
 
     for (int i = 0; i <= test.length() && i < 100; i++) {
         if ( !test[i].isPrint() && !test[i].isNull() ) {
-            qWarning() << "Unlock key of module" << name() << "is NOT valid!";
             return false;
         }
     }
 
-    qDebug() << "Unlock key of module" << name() << "is valid";
     return true;
 }
 
@@ -173,7 +197,7 @@ QString CSwordModuleInfo::getModuleStandardIndexLocation() const { //this for no
     return getModuleBaseIndexLocation() + QString("/standard");
 }
 
-bool CSwordModuleInfo::hasIndex() {
+bool CSwordModuleInfo::hasIndex() const {
     //this will return true only
     //if the index exists and has correct version information for both index and module
     QDir d;
@@ -199,25 +223,6 @@ bool CSwordModuleInfo::hasIndex() {
     return lucene::index::IndexReader::indexExists(getModuleStandardIndexLocation().toAscii().constData());
 }
 
-// HELPER Method: this dumps all current EntryAttributes of a module
-//#include <iostream>
-//void dumpEntryAttributes(sword::SWModule *module) {
-//	std::cout << "Attributes for key: " << module->getKeyText() << std::endl;
-//	sword::AttributeTypeList::iterator i1;
-//	sword::AttributeList::iterator i2;
-//	sword::AttributeValue::iterator i3;
-//	for (i1 = module->getEntryAttributes().begin(); i1 != module->getEntryAttributes().end(); i1++) {
-//		std::cout << "[ " << i1->first << " ]\n";
-//		for (i2 = i1->second.begin(); i2 != i1->second.end(); i2++) {
-//			std::cout << "\t[ " << i2->first << " ]\n";
-//			for (i3 = i2->second.begin(); i3 != i2->second.end(); i3++) {
-//				std::cout << "\t\t" << i3->first << " = " << i3->second << "\n";
-//			}
-//		}
-//	}
-//	std::cout << std::endl;
-//}
-
 void CSwordModuleInfo::buildIndex() {
 
     m_cancelIndexing = false;
@@ -252,14 +257,14 @@ void CSwordModuleInfo::buildIndex() {
             }
         }
 
-        boost::scoped_ptr<lucene::index::IndexWriter> writer( new lucene::index::IndexWriter(index.toAscii().constData(), &an, true) ); //always create a new index
+        QSharedPointer<lucene::index::IndexWriter> writer( new lucene::index::IndexWriter(index.toAscii().constData(), &an, true) ); //always create a new index
         writer->setMaxFieldLength(BT_MAX_LUCENE_FIELD_LENGTH);
         writer->setUseCompoundFile(true); //merge segments into a single file
         writer->setMinMergeDocs(1000);
 
-        *m_module = sword::TOP;
+        m_module->setPosition(sword::TOP);
         unsigned long verseLowIndex = m_module->Index();
-        *m_module = sword::BOTTOM;
+        m_module->setPosition(sword::BOTTOM);
         unsigned long verseHighIndex = m_module->Index();
 
         //verseLowIndex is not 0 in all cases (i.e. NT-only modules)
@@ -271,7 +276,7 @@ void CSwordModuleInfo::buildIndex() {
         if (type() == CSwordModuleInfo::Lexicon) {
             verseIndex = 0;
             verseLowIndex = 0;
-            verseSpan = ((CSwordLexiconModuleInfo*)this)->entries()->size();
+            verseSpan = ((CSwordLexiconModuleInfo*)this)->entries().size();
         }
 
         emit indexingProgress(0);
@@ -296,14 +301,15 @@ void CSwordModuleInfo::buildIndex() {
 
         wchar_t wcharBuffer[BT_MAX_LUCENE_FIELD_LENGTH + 1];
 
-        for (*m_module = sword::TOP; !(m_module->Error()) && !m_cancelIndexing; (*m_module)++) {
+        m_module->setPosition(sword::TOP);
+        while (!(m_module->Error()) && !m_cancelIndexing) {
 
             // Also index Chapter 0 and Verse 0, because they might have information in the entry attributes
             // We used to just put their content into the textBuffer and continue to the next verse, but
             // with entry attributes this doesn't work any more.
             // Hits in the search dialog will show up as 1:1 (instead of 0)
 
-            boost::scoped_ptr<lucene::document::Document> doc(new lucene::document::Document());
+            QSharedPointer<lucene::document::Document> doc(new lucene::document::Document());
 
             //index the key
             lucene_utf8towcs(wcharBuffer, key->getText(), BT_MAX_LUCENE_FIELD_LENGTH);
@@ -357,7 +363,7 @@ void CSwordModuleInfo::buildIndex() {
                 }
             } // for attListI
 
-            writer->addDocument(doc.get());
+            writer->addDocument(doc.data());
             //Index() is not implemented properly for lexicons, so we use a
             //workaround.
             if (type() == CSwordModuleInfo::Lexicon) {
@@ -380,7 +386,9 @@ void CSwordModuleInfo::buildIndex() {
                 //m_indexingProgress.activate();
                 emit indexingProgress(indexingProgressValue);
             }
-        }
+
+            m_module->increment();
+        } // while (!(m_module->Error()) && !m_cancelIndexing)
 
         if (!m_cancelIndexing) {
             writer->optimize();
@@ -421,20 +429,23 @@ unsigned long CSwordModuleInfo::indexSize() const {
 }
 
 
-bool CSwordModuleInfo::searchIndexed(const QString& searchedText, sword::ListKey& scope) {
+int CSwordModuleInfo::searchIndexed(const QString &searchedText,
+                                    const sword::ListKey &scope,
+                                    sword::ListKey &results) const
+{
     char utfBuffer[BT_MAX_LUCENE_FIELD_LENGTH  + 1];
     wchar_t wcharBuffer[BT_MAX_LUCENE_FIELD_LENGTH + 1];
 
     // work around Swords thread insafety for Bibles and Commentaries
-    boost::scoped_ptr < CSwordKey > key(CSwordKey::createInstance(this));
-    sword::SWKey* s = dynamic_cast < sword::SWKey * >(key.get());
+    QSharedPointer < CSwordKey > key(CSwordKey::createInstance(this));
+    sword::SWKey* s = dynamic_cast < sword::SWKey * >(key.data());
     QList<sword::VerseKey*> list;
 
     if (s) {
         m_module->SetKey(*s);
     }
 
-    m_searchResult.ClearList();
+    results.ClearList();
 
     try {
         // do not use any stop words
@@ -442,15 +453,16 @@ bool CSwordModuleInfo::searchIndexed(const QString& searchedText, sword::ListKey
         lucene::analysis::standard::StandardAnalyzer analyzer( stop_words );
         lucene::search::IndexSearcher searcher(getModuleStandardIndexLocation().toAscii().constData());
         lucene_utf8towcs(wcharBuffer, searchedText.toUtf8().constData(), BT_MAX_LUCENE_FIELD_LENGTH);
-        boost::scoped_ptr<lucene::search::Query> q( lucene::queryParser::QueryParser::parse((const TCHAR*)wcharBuffer, (const TCHAR*)_T("content"), &analyzer) );
+        QSharedPointer<lucene::search::Query> q( lucene::queryParser::QueryParser::parse((const TCHAR*)wcharBuffer, (const TCHAR*)_T("content"), &analyzer) );
 
-        boost::scoped_ptr<lucene::search::Hits> h( searcher.search(q.get(), lucene::search::Sort::INDEXORDER) );
+        QSharedPointer<lucene::search::Hits> h( searcher.search(q.data(), lucene::search::Sort::INDEXORDER) );
 
-        const bool useScope = (scope.Count() > 0);
-//		const bool isVerseModule = (type() == CSwordModuleInfo::Bible) || (type() == CSwordModuleInfo::Commentary);
+        /// \warning This is a workaround for Sword constness
+        const bool useScope = (const_cast<sword::ListKey&>(scope).Count() > 0);
+//        const bool isVerseModule = (type() == CSwordModuleInfo::Bible) || (type() == CSwordModuleInfo::Commentary);
 
         lucene::document::Document* doc = 0;
-        boost::scoped_ptr<sword::SWKey> swKey( module()->CreateKey() );
+        QSharedPointer<sword::SWKey> swKey( module()->CreateKey() );
 
 
         for (int i = 0; i < h->length(); ++i) {
@@ -462,46 +474,34 @@ bool CSwordModuleInfo::searchIndexed(const QString& searchedText, sword::ListKey
             // limit results based on scope
             //if (searchOptions & CSwordModuleSearch::useScope && scope.Count() > 0){
             if (useScope) {
-                for (int j = 0; j < scope.Count(); j++) {
-                    sword::VerseKey* vkey = dynamic_cast<sword::VerseKey*>(scope.getElement(j));
+                /// \warning This is a workaround for sword constness
+                for (int j = 0; j < const_cast<sword::ListKey&>(scope).Count(); j++) {
+                    /// \warning This is a workaround for sword constness
+                    sword::ListKey &scope2 = const_cast<sword::ListKey&>(scope);
+                    sword::VerseKey* vkey = dynamic_cast<sword::VerseKey*>(scope2.getElement(j));
                     if (vkey->LowerBound().compare(*swKey) <= 0 && vkey->UpperBound().compare(*swKey) >= 0) {
-                        m_searchResult.add(*swKey);
+                        results.add(*swKey);
                     }
                 }
             }
             else { // no scope, give me all buffers
-                m_searchResult.add(*swKey);
+                results.add(*swKey);
             }
         }
     }
     catch (...) {
         qWarning("CLucene exception occurred");
         util::showWarning(0, QCoreApplication::tr("Search aborted"), QCoreApplication::tr("An internal error occurred while executing your search."));
-        return false;
+        return 0;
     }
 
     qDeleteAll(list);
     list.clear();
 
-    return (m_searchResult.Count() > 0);
+    return results.Count();
 }
 
-/** Returns the last search result for this module. */
-sword::ListKey & CSwordModuleInfo::searchResult(const sword::ListKey * newResult) {
-    if (newResult) {
-        m_searchResult.copyFrom(*newResult);
-    }
-
-    return m_searchResult;
-}
-
-/** Clears the last search result. */
-void CSwordModuleInfo::clearSearchResult() {
-    m_searchResult.ClearList();
-}
-
-/** Returns the required Sword version for this module. Returns -1 if no special Sword version is required. */
-sword::SWVersion CSwordModuleInfo::minimumSwordVersion() {
+sword::SWVersion CSwordModuleInfo::minimumSwordVersion() const {
     return sword::SWVersion(config(CSwordModuleInfo::MinimumSwordVersion).toUtf8().constData());
 }
 
@@ -634,12 +634,11 @@ QString CSwordModuleInfo::config(const CSwordModuleInfo::ConfigEntry entry) cons
     }
 }
 
-/** Returns true if the module supports the feature given as parameter. */
 bool CSwordModuleInfo::has(const CSwordModuleInfo::Feature feature) const {
     switch (feature) {
 
-            // 		case StrongsNumbers:
-            // 		return m_module->getConfig().has("Feature", "StrongsNumber");
+            //         case StrongsNumbers:
+            //         return m_module->getConfig().has("Feature", "StrongsNumber");
 
         case GreekDef:
             return m_module->getConfig().has("Feature", "GreekDef");
@@ -684,25 +683,20 @@ bool CSwordModuleInfo::has(const CSwordModuleInfo::FilterTypes option) const {
     return false;
 }
 
-/** Returns the text direction of the module's text., */
-CSwordModuleInfo::TextDirection CSwordModuleInfo::textDirection() {
-    if (config(TextDir) == "RtoL") {
+CSwordModuleInfo::TextDirection CSwordModuleInfo::textDirection() const {
+    if (config(TextDir) == "RtoL")
         return CSwordModuleInfo::RightToLeft;
-    }
-    else {
-        return CSwordModuleInfo::LeftToRight;
-    }
+
+    return CSwordModuleInfo::LeftToRight;
 }
 
-/** Writes the new text at the given position into the module. This does only work for writable modules. */
-void CSwordModuleInfo::write(CSwordKey * key, const QString & newText) {
+void CSwordModuleInfo::write(CSwordKey *key, const QString &newText) {
     module()->KeyText(key->key().toUtf8().constData());
 
     //don't store a pointer to the const char* value somewhere because QCString doesn't keep the value of it
     module()->setEntry(isUnicode() ? newText.toUtf8().constData() : newText.toLocal8Bit().constData());
 }
 
-/** Deletes the current entry and removes it from the module. */
 bool CSwordModuleInfo::deleteEntry(CSwordKey * const key) {
     module()->KeyText(isUnicode() ? key->key().toUtf8().constData() : key->key().toLocal8Bit().constData());
 
@@ -714,43 +708,48 @@ bool CSwordModuleInfo::deleteEntry(CSwordKey * const key) {
     return false;
 }
 
-/** Returns the category of this module. See CSwordModuleInfo::Category for possible values. */
-CSwordModuleInfo::Category CSwordModuleInfo::category() const {
-    //qDebug() << "CSwordModuleInfo::category";
-    if (m_dataCache.category == CSwordModuleInfo::UnknownCategory) {
-        const QString cat(m_module->getConfigEntry("Category"));
-        //qDebug() << "the category was unknown, add a category "<< cat << "for module" << m_module->Name();
+void CSwordModuleInfo::initCachedCategory() {
+    /// \todo Maybe we can use raw string comparsion instead of QString?
+    const QString cat(m_module->getConfigEntry("Category"));
 
-        if (cat == "Cults / Unorthodox / Questionable Material") {
-            m_dataCache.category = Cult;
-        }
-        else if (cat == "Daily Devotional" || m_module->getConfig().has("Feature", "DailyDevotion")) {
-            m_dataCache.category = DailyDevotional;
-        }
-        else if (cat == "Glossaries" || m_module->getConfig().has("Feature", "Glossary")) { //allow both
-            m_dataCache.category = Glossary;
-        }
-        else if (cat == "Images" || cat == "Maps") {
-            m_dataCache.category = Images;
-        }
-        else if (type() == Commentary) {
-            m_dataCache.category = Commentaries;
-        }
-        else if (type() == Bible) {
-            m_dataCache.category = Bibles;
-        }
-        else if (type() == Lexicon) {
-            m_dataCache.category = Lexicons;
-        }
-        else if (type() == GenericBook) {
-            m_dataCache.category = Books;
+    /// \warning cat has to be checked before type() !!!
+    if (cat == "Cults / Unorthodox / Questionable Material") {
+        m_cachedCategory = Cult;
+    } else if (cat == "Daily Devotional"
+               || m_module->getConfig().has("Feature","DailyDevotion"))
+    {
+        m_cachedCategory = DailyDevotional;
+    } else if (cat == "Glossaries"
+               || m_module->getConfig().has("Feature", "Glossary"))
+    {
+        m_cachedCategory = Glossary;
+    } else if (cat == "Images" || cat == "Maps") {
+        m_cachedCategory = Images;
+    } else {
+        switch (type()) {
+            case Bible:       m_cachedCategory = Bibles; break;
+            case Commentary:  m_cachedCategory = Commentaries; break;
+            case Lexicon:     m_cachedCategory = Lexicons; break;
+            case GenericBook: m_cachedCategory = Books; break;
+            case Unknown: // Fall thru
+            default:          m_cachedCategory = UnknownCategory; break;
         }
     }
-    //qDebug() << "assigned category: " << m_dataCache.category;
-    return m_dataCache.category;
 }
 
-/** Returns the display object for this module. */
+void CSwordModuleInfo::initCachedLanguage() {
+    CLanguageMgr *lm = CLanguageMgr::instance();
+    if (category() == Glossary) {
+        /*
+          Special handling for glossaries, we use the "from language" as
+          language for the module.
+        */
+        m_cachedLanguage = lm->languageForAbbrev(config(GlossaryFrom));
+    } else {
+        m_cachedLanguage = lm->languageForAbbrev(m_module->Lang());
+    }
+}
+
 Rendering::CEntryDisplay * CSwordModuleInfo::getDisplay() const {
     return dynamic_cast < Rendering::CEntryDisplay * >(m_module->Disp());
 }
@@ -873,30 +872,114 @@ QString CSwordModuleInfo::aboutText() const {
     return text;
 }
 
-/** Returns the language of the module. */
-const CLanguageMgr::Language* CSwordModuleInfo::language() const {
-    if (!m_dataCache.language) {
-        if (module()) {
-            if (category() == Glossary) {
-                //special handling for glossaries, we use the "from language" as language for the module
-                m_dataCache.language = (CPointers::languageMgr())->languageForAbbrev(config(GlossaryFrom));
-            }
-            else {
-                m_dataCache.language = (CPointers::languageMgr())->languageForAbbrev(module()->Lang());
-            }
-        }
-        else {
-            m_dataCache.language = (CPointers::languageMgr())->defaultLanguage(); //default language
-        }
-    }
-
-    return m_dataCache.language;
+QIcon CSwordModuleInfo::moduleIcon(const CSwordModuleInfo *module) {
+    const QString &filename = moduleIconFilename(module);
+    if (filename.isEmpty()) return QIcon();
+    return util::directory::getIcon(filename);
 }
 
+const QString &CSwordModuleInfo::moduleIconFilename(
+        const CSwordModuleInfo *module)
+{
+    const CSwordModuleInfo::Category cat(module->category());
+    switch (cat) {
+        case CSwordModuleInfo::Bibles:
+            if (module->isLocked()) {
+                return CResMgr::modules::bible::icon_locked;
+            }
+            else {
+                return CResMgr::modules::bible::icon_unlocked;
+            }
+        case CSwordModuleInfo::Commentaries:
+            if (module->isLocked()) {
+                return CResMgr::modules::commentary::icon_locked;
+            }
+            else {
+                return CResMgr::modules::commentary::icon_unlocked;
+            }
+        case CSwordModuleInfo::Lexicons:
+            if (module->isLocked()) {
+                return CResMgr::modules::lexicon::icon_locked;
+            }
+            else {
+                return CResMgr::modules::lexicon::icon_unlocked;
+            }
+        case CSwordModuleInfo::Books:
+            if (module->isLocked()) {
+                return CResMgr::modules::book::icon_locked;
+            }
+            else {
+                return CResMgr::modules::book::icon_unlocked;
+            }
+        case CSwordModuleInfo::Cult:
+        case CSwordModuleInfo::Images:
+        case CSwordModuleInfo::DailyDevotional:
+        case CSwordModuleInfo::Glossary:
+        case CSwordModuleInfo::UnknownCategory:
+        default:
+            return categoryIconFilename(cat);
+    }
+}
+
+QIcon CSwordModuleInfo::categoryIcon(const CSwordModuleInfo::Category &category)
+{
+    QString filename = categoryIconFilename(category);
+    if (filename.isEmpty()) return QIcon();
+    return util::directory::getIcon(filename);
+}
+
+const QString &CSwordModuleInfo::categoryIconFilename(
+        const CSwordModuleInfo::Category &category)
+{
+    static const QString noFilename;
+
+    switch (category) {
+        case CSwordModuleInfo::Bibles:
+            return CResMgr::categories::bibles::icon;
+        case CSwordModuleInfo::Commentaries:
+            return CResMgr::categories::commentaries::icon;
+        case CSwordModuleInfo::Books:
+            return CResMgr::categories::books::icon;
+        case CSwordModuleInfo::Cult:
+            return CResMgr::categories::cults::icon;
+        case CSwordModuleInfo::Images:
+            return CResMgr::categories::images::icon;
+        case CSwordModuleInfo::DailyDevotional:
+            return CResMgr::categories::dailydevotional::icon;
+        case CSwordModuleInfo::Lexicons:
+            return CResMgr::categories::lexicons::icon;
+        case CSwordModuleInfo::Glossary:
+            return CResMgr::categories::glossary::icon;
+        case CSwordModuleInfo::UnknownCategory:
+        default:
+            return noFilename;
+    }
+}
+
+QString CSwordModuleInfo::categoryName(
+    const CSwordModuleInfo::Category &category) {
+    switch (category) {
+        case CSwordModuleInfo::Bibles:
+            return tr("Bibles");
+        case CSwordModuleInfo::Commentaries:
+            return tr("Commentaries");
+        case CSwordModuleInfo::Books:
+            return tr("Books");
+        case CSwordModuleInfo::Cult:
+            return tr("Cults/Unorthodox");
+        case CSwordModuleInfo::Images:
+            return tr("Maps and Images");
+        case CSwordModuleInfo::DailyDevotional:
+            return tr("Daily Devotionals");
+        case CSwordModuleInfo::Lexicons:
+            return  tr("Lexicons and Dictionaries");
+        case CSwordModuleInfo::Glossary:
+            return tr("Glossaries");
+        default:
+            return tr("Unknown");
+    }
+}
 
-/*!
-	\fn CSwordModuleInfo::getSimpleConfigEntry(char* name)
-*/
 QString CSwordModuleInfo::getSimpleConfigEntry(const QString& name) const {
     QString ret = isUnicode()
                   ? QString::fromUtf8(m_module->getConfigEntry(name.toUtf8().constData()))
@@ -933,3 +1016,4 @@ bool CSwordModuleInfo::setHidden(bool hide) {
     emit hiddenChanged(hide);
     return true;
 }
+
