@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -18,8 +18,8 @@
 #include <utilstr.h>
 
 
-CSwordLDKey::CSwordLDKey( CSwordModuleInfo* module ) {
-    if ((m_module = dynamic_cast<CSwordLexiconModuleInfo*>(module))) {
+CSwordLDKey::CSwordLDKey(const CSwordModuleInfo *module) {
+    if ((m_module = dynamic_cast<const CSwordLexiconModuleInfo*>(module))) {
         //    *(m_module->module()) = TOP;
     }
 
@@ -30,7 +30,11 @@ CSwordLDKey::CSwordLDKey( CSwordModuleInfo* module ) {
 CSwordLDKey::CSwordLDKey( const CSwordLDKey &k ) : CSwordKey(k), SWKey((const char*)k) {}
 
 /** No descriptions */
-CSwordLDKey::CSwordLDKey( const SWKey *k, CSwordModuleInfo* module) : CSwordKey(module), SWKey(*k) {}
+CSwordLDKey::CSwordLDKey(const SWKey *k, const CSwordModuleInfo *module)
+    : CSwordKey(module), SWKey(*k)
+{
+    // Intentionally empty
+}
 
 /** Clones this object by copying the members. */
 CSwordLDKey* CSwordLDKey::copy() const {
@@ -38,14 +42,14 @@ CSwordLDKey* CSwordLDKey::copy() const {
 }
 
 /** Sets the module of this key. */
-CSwordModuleInfo* CSwordLDKey::module(CSwordModuleInfo* const newModule) {
-    if (newModule && newModule->type() == CSwordModuleInfo::Lexicon) {
-        const QString oldKey = key();
-        m_module = newModule;
-        key(oldKey);
-    }
+void CSwordLDKey::setModule(const CSwordModuleInfo *newModule) {
+    Q_ASSERT(newModule);
+    if (m_module == newModule) return;
+    Q_ASSERT(newModule->type() == CSwordModuleInfo::Lexicon);
 
-    return m_module;
+    const QString oldKey = key();
+    m_module = newModule;
+    setKey(oldKey);
 }
 
 QString CSwordLDKey::key() const {
@@ -61,23 +65,23 @@ QString CSwordLDKey::key() const {
 }
 
 const char * CSwordLDKey::rawKey() const {
-    return (const char*)*this;
+    return getText();
 }
 
-bool CSwordLDKey::key( const QString& newKey ) {
+bool CSwordLDKey::setKey(const QString &newKey) {
     Q_ASSERT(m_module);
 
     if (m_module->isUnicode()) {
-        return key(newKey.toUtf8().constData());
+        return setKey(newKey.toUtf8().constData());
     }
     else {
-        return key((const char*)cp1252Codec()->fromUnicode(newKey));
+        return setKey((const char*)cp1252Codec()->fromUnicode(newKey));
     }
 }
 
 
 /** Sets the key of this instance */
-bool CSwordLDKey::key( const char* newKey ) {
+bool CSwordLDKey::setKey(const char *newKey) {
     Q_ASSERT(newKey);
 
     if (newKey) {
@@ -98,7 +102,7 @@ CSwordLDKey* CSwordLDKey::NextEntry() {
     ( *( m_module->module() ) )++;
     m_module->module()->setSkipConsecutiveLinks(false);
 
-    key(m_module->module()->KeyText());
+    setKey(m_module->module()->KeyText());
     SWKey::operator = (m_module->module()->KeyText());
 
     return this;
