@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -14,19 +14,22 @@
 
 #include "backend/drivers/cswordbiblemoduleinfo.h"
 #include "backend/drivers/cswordcommentarymoduleinfo.h"
+#include "util/btsignal.h"
 
 // Sword includes:
 #include <swmodule.h>
 #include <localemgr.h>
 
 
-CSwordVerseKey::CSwordVerseKey( CSwordModuleInfo* const module ) :
-        CSwordKey(module) {
-    if ( CSwordBibleModuleInfo* bible = dynamic_cast<CSwordBibleModuleInfo*>(module) ) {
+CSwordVerseKey::CSwordVerseKey(const CSwordModuleInfo *module)
+    : CSwordKey(module)
+{
+    typedef CSwordBibleModuleInfo CSBMI;
+    if (const CSBMI *bible = dynamic_cast<const CSBMI*>(module) ) {
         // Copy important settings like versification system
         copyFrom((sword::VerseKey*) bible->module()->getKey());
 
-        key( bible->lowerBound().key() );
+        setKey( bible->lowerBound().key() );
     }
     this->VerseKey::setAutoNormalize(true);
 }
@@ -35,7 +38,12 @@ CSwordVerseKey::CSwordVerseKey( const CSwordVerseKey& k ) : CSwordKey(k), VerseK
     this->VerseKey::setAutoNormalize(true);
 }
 
-CSwordVerseKey::CSwordVerseKey( const VerseKey* const k, CSwordModuleInfo* const module ) : CSwordKey(module), VerseKey(*k) {}
+CSwordVerseKey::CSwordVerseKey(const VerseKey *k,
+                               const CSwordModuleInfo *module)
+    : CSwordKey(module), VerseKey(*k)
+{
+    // Intentionally empty
+}
 
 /** Clones this object. */
 CSwordKey* CSwordVerseKey::copy() const {
@@ -43,33 +51,38 @@ CSwordKey* CSwordVerseKey::copy() const {
 }
 
 /** Sets the module for this key */
-CSwordModuleInfo* CSwordVerseKey::module( CSwordModuleInfo* const newModule ) {
-    if (newModule && ((newModule->type() == CSwordModuleInfo::Bible)  || (newModule->type() == CSwordModuleInfo::Commentary) ) ) {
-        m_module = newModule;
+void CSwordVerseKey::setModule(const CSwordModuleInfo *newModule) {
+    typedef CSwordBibleModuleInfo CSBMI;
 
-        //check if the module contains the key we present
-        CSwordBibleModuleInfo* bible = dynamic_cast<CSwordBibleModuleInfo*>(newModule);
+    Q_ASSERT(newModule);
+    if (m_module == newModule) return;
+    Q_ASSERT(newModule->type() == CSwordModuleInfo::Bible
+             || newModule->type() == CSwordModuleInfo::Commentary);
 
-        if (_compare(bible->lowerBound()) < 0) {
-            key( bible->lowerBound() );
-        }
+    m_module = newModule;
 
-        if (_compare(bible->upperBound()) > 0) {
-            key( bible->upperBound() );
-        }
+    //check if the module contains the key we present
+    const CSBMI* bible = dynamic_cast<const CSBMI*>(newModule);
+
+    if (_compare(bible->lowerBound()) < 0) {
+        setKey(bible->lowerBound());
     }
 
-    return dynamic_cast<CSwordBibleModuleInfo*>(m_module);
+    if (_compare(bible->upperBound()) > 0) {
+        setKey(bible->upperBound());
+    }
 }
 
 /** Returns the current book as Text, not as integer. */
 QString CSwordVerseKey::book( const QString& newBook ) {
+    typedef CSwordBibleModuleInfo CSBMI;
     int min = 0;
     int max = 1;
 
-    if (CSwordBibleModuleInfo* bible = dynamic_cast<CSwordBibleModuleInfo*>(module())) {
-        const bool hasOT = bible->hasTestament(CSwordBibleModuleInfo::OldTestament);
-        const bool hasNT = bible->hasTestament(CSwordBibleModuleInfo::NewTestament);
+    const CSBMI *bible = dynamic_cast<const CSBMI*>(module());
+    if (bible != 0) {
+        const bool hasOT = bible->hasTestament(CSBMI::OldTestament);
+        const bool hasNT = bible->hasTestament(CSBMI::NewTestament);
 
         if (hasOT && hasNT) {
             min = 0;
@@ -110,26 +123,37 @@ const char * CSwordVerseKey::rawKey() const {
     return getText();
 }
 
-bool CSwordVerseKey::key( const QString& newKey ) {
-    return key( newKey.toUtf8().constData() );
+bool CSwordVerseKey::setKey(const QString &newKey) {
+    return setKey(newKey.toUtf8().constData());
 }
 
-bool CSwordVerseKey::key( const char* newKey ) {
-    if (newKey && (strlen(newKey) > 0) ) {
-        VerseKey::operator = (newKey);
-    }
-    else if (newKey && !strlen(newKey)) {
-        CSwordBibleModuleInfo* bible = dynamic_cast<CSwordBibleModuleInfo*>(module());
+bool CSwordVerseKey::setKey(const char *newKey) {
+    typedef CSwordBibleModuleInfo CSBMI;
 
-        if ( bible ) {
-            VerseKey::operator = (bible->lowerBound().key().toUtf8().constData());
+    /// \todo Is this check necessary?
+    if (newKey) {
+        /// \todo Is this check necessary?
+        // Check if empty string:
+        if (*newKey != '\0') {
+            positionFrom(newKey);
+        } else {
+            const CSwordModuleInfo *m = module();
+            if (m->type() == CSwordModuleInfo::Bible) {
+                Q_ASSERT(dynamic_cast<const CSBMI*>(m) != 0);
+                const CSBMI *bible = static_cast<const CSBMI*>(m);
+                positionFrom(bible->lowerBound().key().toUtf8().constData());
+            }
         }
     }
 
+    /// \todo Do we ALWAYS need to emit this signal and check for errors?
+    emitChanged();
     return !Error();
 }
 
 bool CSwordVerseKey::next( const JumpType type ) {
+    typedef CSwordBibleModuleInfo CSBMI;
+
     Error(); //clear Error status
     bool ret = true;
 
@@ -174,7 +198,7 @@ bool CSwordVerseKey::next( const JumpType type ) {
                 m_module->module()->setSkipConsecutiveLinks(oldStatus);
 
                 if (!m_module->module()->Error()) {
-                    key( QString::fromUtf8(m_module->module()->KeyText()) );
+                    setKey(QString::fromUtf8(m_module->module()->KeyText()));
                 }
                 else {
                     //         Verse(Verse()+1);
@@ -196,27 +220,32 @@ bool CSwordVerseKey::next( const JumpType type ) {
             return false;
     }
 
-    if ( CSwordBibleModuleInfo* bible = dynamic_cast<CSwordBibleModuleInfo*>(module()) ) {
+    const CSBMI *bible = dynamic_cast<const CSBMI*>(module());
+    if (bible != 0) {
         if (_compare(bible->lowerBound()) < 0 ) {
-            key( bible->lowerBound() );
+            setKey(bible->lowerBound());
             ret = false;
         }
 
         if (_compare(bible->upperBound()) > 0 ) {
-            key( bible->upperBound() );
+            setKey(bible->upperBound());
             ret = false;
         }
 
+        emitChanged();
         return ret;
     }
     else if (Error()) { //we have no module, so take care of VerseKey::Error()
         return false;
     }
 
+    emitChanged();
     return ret;
 }
 
 bool CSwordVerseKey::previous( const JumpType type ) {
+    typedef CSwordBibleModuleInfo CSBMI;
+
     bool ret = true;
 
     switch (type) {
@@ -256,7 +285,7 @@ bool CSwordVerseKey::previous( const JumpType type ) {
                 m_module->module()->setSkipConsecutiveLinks(oldStatus);
 
                 if (!m_module->module()->Error()) {
-                    key( QString::fromUtf8(m_module->module()->KeyText()) );//don't use fromUtf8
+                    setKey(QString::fromUtf8(m_module->module()->KeyText()));//don't use fromUtf8
                 }
                 else {
                     ret = false;
@@ -275,22 +304,25 @@ bool CSwordVerseKey::previous( const JumpType type ) {
             return false;
     }
 
-    if ( CSwordBibleModuleInfo* bible = dynamic_cast<CSwordBibleModuleInfo*>(module()) ) {
+    const CSBMI *bible = dynamic_cast<const CSBMI*>(module());
+    if (bible != 0) {
         if (_compare(bible->lowerBound()) < 0 ) {
-            key( bible->lowerBound() );
+            setKey(bible->lowerBound());
             ret = false;
         }
 
         if (_compare(bible->upperBound()) > 0 ) {
-            key( bible->upperBound() );
+            setKey(bible->upperBound());
             ret = false;
         }
 
+        emitChanged();
         return ret;
     }
     else if (Error()) {
         return false;
     }
 
+    emitChanged();
     return ret;
 }
