@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -17,15 +17,38 @@
 #include "backend/config/cbtconfig.h"
 #include "backend/drivers/cswordmoduleinfo.h"
 #include "backend/managers/clanguagemgr.h"
-#include "util/cpointers.h"
 #include "util/directory.h"
 
 
-CDisplayTemplateMgr::CDisplayTemplateMgr() {
-    loadTemplates();
-}
+CDisplayTemplateMgr *CDisplayTemplateMgr::m_instance = 0;
 
-CDisplayTemplateMgr::~CDisplayTemplateMgr() {
+CDisplayTemplateMgr::CDisplayTemplateMgr(QString &errorMessage) {
+    Q_ASSERT(m_instance == 0);
+
+    m_instance = this;
+    namespace DU = util::directory;
+
+    QStringList filter("*.tmpl");
+
+    // Preload global display templates from disk:
+    QDir td = DU::getDisplayTemplatesDir();
+    Q_FOREACH(QString file, td.entryList(filter, QDir::Files | QDir::Readable))
+        loadTemplate(td.canonicalPath() + "/" + file);
+
+    /*
+      Preload user display templates from disk, overriding any global templates
+      with the same file name:
+    */
+    QDir utd = DU::getUserDisplayTemplatesDir();
+    Q_FOREACH(QString file, utd.entryList(filter, QDir::Files | QDir::Readable))
+        loadTemplate(utd.canonicalPath() + "/" + file);
+
+    if (m_templateMap.contains(defaultTemplate())) {
+        errorMessage = QString::null;
+    } else {
+        errorMessage = QObject::tr("Default template \"%1\" not found!")
+                       .arg(defaultTemplate());
+    }
 }
 
 const QString CDisplayTemplateMgr::fillTemplate( const QString& name, const QString& content, Settings& settings ) {
@@ -70,9 +93,9 @@ const QString CDisplayTemplateMgr::fillTemplate( const QString& name, const QStr
         qDebug() << "There were more than 1 module, create headers";
         QString header;
 
-        QList<CSwordModuleInfo*>::iterator end_it = settings.modules.end();
+        QList<const CSwordModuleInfo*>::iterator end_it = settings.modules.end();
 
-        for (QList<CSwordModuleInfo*>::iterator it(settings.modules.begin()); it != end_it; ++it) {
+        for (QList<const CSwordModuleInfo*>::iterator it(settings.modules.begin()); it != end_it; ++it) {
             header.append("<th style=\"width:")
             .append(QString::number(int( 100.0 / (float)moduleCount )))
             .append("%;\">")
@@ -88,7 +111,7 @@ const QString CDisplayTemplateMgr::fillTemplate( const QString& name, const QStr
     }
 
     QString langCSS;
-    CLanguageMgr::LangMap langMap = CPointers::languageMgr()->availableLanguages();
+    CLanguageMgr::LangMap langMap = CLanguageMgr::instance()->availableLanguages();
 
     qDebug() << "langMap length:" << langMap.count();
     qDebug() << "loop through langMap";
@@ -118,7 +141,7 @@ const QString CDisplayTemplateMgr::fillTemplate( const QString& name, const QStr
 
     //at first append the font standard settings for all languages without configured font
     // Create a dummy language (the langmap may be empty)
-    CLanguageMgr::Language lang_v(QString("en"), QString("English"), QString());
+    CLanguageMgr::Language lang_v(QString("en"), QString("English"), QString::null);
     CLanguageMgr::Language* lang = &lang_v;
 
     if (lang && !lang->abbrev().isEmpty()/*&& lang->isValid()*/) {
@@ -132,7 +155,7 @@ const QString CDisplayTemplateMgr::fillTemplate( const QString& name, const QStr
         );
     }
 
-// 	qWarning("Outputing unformated text");
+//     qWarning("Outputing unformated text");
     const QString t = QString(m_templateMap[ templateName ]) //don't change the map's content directly, use  a copy
                       .replace("#TITLE#", settings.title)
                       .replace("#LANG_ABBREV#", settings.langAbbrev.isEmpty() ? QString("en") : settings.langAbbrev)
@@ -144,25 +167,13 @@ const QString CDisplayTemplateMgr::fillTemplate( const QString& name, const QStr
     return t;
 }
 
-void CDisplayTemplateMgr::loadTemplates() {
-    namespace DU = util::directory;
+void CDisplayTemplateMgr::loadTemplate(const QString &filename) {
+    QFile f(filename);
+    if (f.open(QIODevice::ReadOnly)) {
+        QString fileContent = QTextStream(&f).readAll();
 
-    QStringList files;
-    foreach (QString file, DU::getDisplayTemplatesDir().entryList(QStringList("*.tmpl"))) {
-        files += DU::getDisplayTemplatesDir().canonicalPath() + "/" + file;
-    }
-    foreach (QString file, DU::getUserDisplayTemplatesDir().entryList(QStringList("*.tmpl"))) {
-        files += DU::getUserDisplayTemplatesDir().canonicalPath() + "/" + file;
-    }
-
-    foreach (QString file, files) {
-        QFile f(file);
-        if (f.exists() && f.open( QIODevice::ReadOnly )) {
-            QString fileContent = QTextStream( &f ).readAll();
-
-            if (!fileContent.isEmpty()) {
-                m_templateMap[ QFileInfo(file).fileName() ] = fileContent;
-            }
+        if (!fileContent.isEmpty()) {
+            m_templateMap[QFileInfo(f).fileName()] = fileContent;
         }
     }
 }
