@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -20,16 +20,9 @@
 #include "backend/drivers/cswordbookmoduleinfo.h"
 #include "backend/drivers/cswordcommentarymoduleinfo.h"
 #include "backend/drivers/cswordlexiconmoduleinfo.h"
-#include "backend/filters/bt_gbfhtml.h"
-#include "backend/filters/bt_osishtml.h"
-#include "backend/filters/bt_teihtml.h"
-#include "backend/filters/bt_plainhtml.h"
-#include "backend/filters/bt_thmlhtml.h"
-#include "backend/filters/bt_thmlplain.h"
+#include "backend/filters/thmltoplain.h"
 #include "backend/filters/osismorphsegmentation.h"
-#include "backend/rendering/cbookdisplay.h"
-#include "backend/rendering/cchapterdisplay.h"
-#include "backend/rendering/centrydisplay.h"
+#include "btglobal.h"
 #include "util/directory.h"
 
 // Sword includes:
@@ -42,52 +35,25 @@
 #include <utilstr.h>
 
 
-using namespace Filters;
 using namespace Rendering;
 
+CSwordBackend *CSwordBackend::m_instance = 0;
+
 CSwordBackend::CSwordBackend()
-        : sword::SWMgr(0, 0, false, new sword::EncodingFilterMgr( sword::ENC_UTF8 ), true),
-        m_dataModel(this) {
-    m_filters.gbf = new BT_GBFHTML();
-    m_filters.plain = new BT_PLAINHTML();
-    m_filters.thml = new BT_ThMLHTML();
-    m_filters.osis = new BT_OSISHTML();
-    m_filters.tei = new BT_TEIHTML();
-
-    m_displays.entry = new CEntryDisplay();
-    m_displays.chapter = new CChapterDisplay();
-    m_displays.book = new CBookDisplay();
-
+        : sword::SWMgr(0, 0, false,
+                       new sword::EncodingFilterMgr(sword::ENC_UTF8), true),
+          m_dataModel(this)
+{
     filterInit();
 }
 
 CSwordBackend::CSwordBackend(const QString& path, const bool augmentHome)
         : sword::SWMgr(!path.isEmpty() ? path.toLocal8Bit().constData() : 0, false, new sword::EncodingFilterMgr( sword::ENC_UTF8 ), false, augmentHome) { // don't allow module renaming, because we load from a path
-    m_filters.gbf = new BT_GBFHTML();
-    m_filters.plain = new BT_PLAINHTML();
-    m_filters.thml = new BT_ThMLHTML();
-    m_filters.osis = new BT_OSISHTML();
-    m_filters.tei = new BT_TEIHTML();
-
-    m_displays.entry = new CEntryDisplay();
-    m_displays.chapter = new CChapterDisplay();
-    m_displays.book = new CBookDisplay();
-
     filterInit();
 }
 
 CSwordBackend::~CSwordBackend() {
     shutdownModules();
-
-    delete m_filters.gbf;
-    delete m_filters.plain;
-    delete m_filters.thml;
-    delete m_filters.osis;
-    delete m_filters.tei;
-
-    delete m_displays.book;
-    delete m_displays.chapter;
-    delete m_displays.entry;
 }
 
 void CSwordBackend::filterInit() {
@@ -97,7 +63,7 @@ void CSwordBackend::filterInit() {
         optionFilters.erase("OSISMorphSegmentation");
         delete filter;
     }
-    sword::SWOptionFilter* tmpFilter = new OSISMorphSegmentation();
+    sword::SWOptionFilter *tmpFilter = new Filters::OSISMorphSegmentation();
     optionFilters.insert(sword::OptionFilterMap::value_type("OSISMorphSegmentation", tmpFilter));
     cleanupFilters.push_back(tmpFilter);
 
@@ -105,7 +71,7 @@ void CSwordBackend::filterInit() {
     //remove this hack as soon as Sword is fixed
     cleanupFilters.remove(thmlplain);
     delete thmlplain;
-    thmlplain = new BT_ThMLPlain();
+    thmlplain = new Filters::ThmlToPlain();
     cleanupFilters.push_back(thmlplain);
 }
 
@@ -125,10 +91,23 @@ QList<CSwordModuleInfo*> CSwordBackend::takeModulesFromList(QStringList names) {
     return list;
 }
 
-QList<CSwordModuleInfo*> CSwordBackend::getPointerList(QStringList names) {
+QList<CSwordModuleInfo*> CSwordBackend::getPointerList(const QStringList &names) {
     QList<CSwordModuleInfo*> list;
-    foreach(QString name, names) {
-        CSwordModuleInfo* mInfo = findModuleByName(name);
+    Q_FOREACH (const QString &name, names) {
+        CSwordModuleInfo *mInfo = findModuleByName(name);
+        if (mInfo) {
+            list.append(mInfo);
+        }
+    }
+    return list;
+}
+
+QList<const CSwordModuleInfo*> CSwordBackend::getConstPointerList(
+        const QStringList &names)
+{
+    QList<const CSwordModuleInfo*> list;
+    Q_FOREACH (const QString &name, names) {
+        const CSwordModuleInfo *mInfo = findModuleByName(name);
         if (mInfo) {
             list.append(mInfo);
         }
@@ -154,19 +133,19 @@ CSwordBackend::LoadError CSwordBackend::initModules(SetupChangedReason reason) {
 
         if (!strcmp(curMod->Type(), "Biblical Texts")) {
             newModule = new CSwordBibleModuleInfo(curMod, this);
-            newModule->module()->Disp(m_displays.chapter);
+            newModule->module()->Disp(&m_chapterDisplay);
         }
         else if (!strcmp(curMod->Type(), "Commentaries")) {
             newModule = new CSwordCommentaryModuleInfo(curMod, this);
-            newModule->module()->Disp(m_displays.entry);
+            newModule->module()->Disp(&m_entryDisplay);
         }
         else if (!strcmp(curMod->Type(), "Lexicons / Dictionaries")) {
             newModule = new CSwordLexiconModuleInfo(curMod, this);
-            newModule->module()->Disp(m_displays.entry);
+            newModule->module()->Disp(&m_entryDisplay);
         }
         else if (!strcmp(curMod->Type(), "Generic Books")) {
             newModule = new CSwordBookModuleInfo(curMod, this);
-            newModule->module()->Disp(m_displays.book);
+            newModule->module()->Disp(&m_bookDisplay);
         }
 
         if (newModule) {
@@ -181,8 +160,7 @@ CSwordBackend::LoadError CSwordBackend::initModules(SetupChangedReason reason) {
         }
     }
 
-    Q_FOREACH(CSwordModuleInfo* mod, m_dataModel.modules()) {
-        m_moduleDescriptionMap.insert( mod->config(CSwordModuleInfo::Description), mod->name() );
+    Q_FOREACH(CSwordModuleInfo* mod, m_dataModel.moduleList()) {
         //unlock modules if keys are present
         if ( mod->isEncrypted() ) {
             const QString unlockKey = CBTConfig::getModuleEncryptionKey( mod->name() );
@@ -206,29 +184,29 @@ void CSwordBackend::AddRenderFilters(sword::SWModule *module, sword::ConfigEntMa
     moduleDriver = ((entry = section.find("ModDrv")) != section.end()) ? (*entry).second : (sword::SWBuf) "";
 
     if (sourceformat == "OSIS") {
-        module->AddRenderFilter(m_filters.osis);
+        module->AddRenderFilter(&m_osisFilter);
         noDriver = false;
     }
     else if (sourceformat == "ThML") {
-        module->AddRenderFilter(m_filters.thml);
+        module->AddRenderFilter(&m_thmlFilter);
         noDriver = false;
     }
     else if (sourceformat == "TEI") {
-        module->AddRenderFilter(m_filters.tei);
+        module->AddRenderFilter(&m_teiFilter);
         noDriver = false;
     }
     else if (sourceformat == "GBF") {
-        module->AddRenderFilter(m_filters.gbf);
+        module->AddRenderFilter(&m_gbfFilter);
         noDriver = false;
     }
     else if (sourceformat == "PLAIN") {
-        module->AddRenderFilter(m_filters.plain);
+        module->AddRenderFilter(&m_plainFilter);
         noDriver = false;
     }
 
     if (noDriver) { //no driver found
         if ( (moduleDriver == "RawCom") || (moduleDriver == "RawLD") ) {
-            module->AddRenderFilter(m_filters.plain);
+            module->AddRenderFilter(&m_plainFilter);
             noDriver = false;
         }
     }
@@ -284,7 +262,7 @@ void CSwordBackend::setOption( const CSwordModuleInfo::FilterTypes type, const i
         setGlobalOption(optionName(type).toUtf8().constData(), value.c_str());
 }
 
-void CSwordBackend::setFilterOptions( const CSwordBackend::FilterOptions options) {
+void CSwordBackend::setFilterOptions(const FilterOptions &options) {
     setOption( CSwordModuleInfo::footnotes,      options.footnotes );
     setOption( CSwordModuleInfo::strongNumbers,    options.strongNumbers );
     setOption( CSwordModuleInfo::headings,       options.headings );
@@ -302,93 +280,27 @@ void CSwordBackend::setFilterOptions( const CSwordBackend::FilterOptions options
 
 /** This function searches for a module with the specified description */
 CSwordModuleInfo* CSwordBackend::findModuleByDescription(const QString& description) {
-    Q_FOREACH (CSwordModuleInfo *mod, m_dataModel.modules()) {
+    Q_FOREACH (CSwordModuleInfo *mod, m_dataModel.moduleList()) {
         if (mod->config(CSwordModuleInfo::Description) == description) return mod;
     }
     return 0;
 }
 
-/** This function searches for a module with the specified description */
-const QString CSwordBackend::findModuleNameByDescription(const QString& description) {
-    if (m_moduleDescriptionMap.contains(description)) {
-        return m_moduleDescriptionMap[description];
-    }
-    return QString::null;
-}
-
 /** This function searches for a module with the specified name */
 CSwordModuleInfo* CSwordBackend::findModuleByName(const QString& name) {
-    Q_FOREACH (CSwordModuleInfo *mod, m_dataModel.modules()) {
+    Q_FOREACH (CSwordModuleInfo *mod, m_dataModel.moduleList()) {
         if (mod->name() == name) return mod;
     }
     return 0;
 }
 
 CSwordModuleInfo* CSwordBackend::findSwordModuleByPointer(const sword::SWModule* const swmodule) {
-    Q_FOREACH (CSwordModuleInfo *mod, m_dataModel.modules()) {
+    Q_FOREACH (CSwordModuleInfo *mod, m_dataModel.moduleList()) {
         if (mod->module() == swmodule ) return mod;
     }
     return 0;
 }
 
-CSwordModuleInfo* CSwordBackend::findModuleByPointer(const CSwordModuleInfo* const module) {
-    Q_FOREACH (CSwordModuleInfo *mod, m_dataModel.modules()) {
-        if (mod  == module) return mod;
-    }
-    return 0;
-}
-
-/** Returns our local config object to store the cipher keys etc. locally for each user. The values of the config are merged with the global config. */
-bool CSwordBackend::moduleConfig(const QString& module, sword::SWConfig& moduleConfig) {
-
-    sword::SectionMap::iterator section;
-    QDir dir(QString::fromUtf8(configPath));
-    bool foundConfig = false;
-
-    QFileInfoList list = dir.entryInfoList();
-    if (dir.isReadable()) {
-        for (int i = 0; i < list.size(); ++i) {
-            QFileInfo fileInfo = list.at(i);
-
-            moduleConfig = sword::SWConfig( fileInfo.absoluteFilePath().toLocal8Bit().constData() );
-            section = moduleConfig.Sections.find( module.toLocal8Bit().constData() );
-            foundConfig = ( section != moduleConfig.Sections.end() );
-        }
-    }
-    else { //try to read mods.conf
-        moduleConfig = sword::SWConfig("");//global config
-        section = config->Sections.find( module.toLocal8Bit().constData() );
-        foundConfig = ( section != config->Sections.end() );
-
-        sword::ConfigEntMap::iterator entry;
-
-        if (foundConfig) { //copy module section
-
-            for (entry = section->second.begin(); entry != section->second.end(); entry++) {
-                moduleConfig.Sections[section->first].insert(sword::ConfigEntMap::value_type(entry->first, entry->second));
-            }
-        }
-    }
-
-    if (!foundConfig && configType != 2) { //search in $HOME/.sword/
-
-        QString myPath = util::directory::getUserHomeSwordModsDir().absolutePath();
-        dir.setPath(myPath);
-
-        QFileInfoList list = dir.entryInfoList();
-        if (dir.isReadable()) {
-            for (int i = 0; i < list.size(); ++i) {
-                QFileInfo fileInfo = list.at(i);
-                moduleConfig = sword::SWConfig( fileInfo.absoluteFilePath().toLocal8Bit().constData() );
-                section = moduleConfig.Sections.find( module.toLocal8Bit().constData() );
-                foundConfig = ( section != moduleConfig.Sections.end() );
-            }
-        }
-    }
-
-    return foundConfig;
-}
-
 /** Returns the text used for the option given as parameter. */
 const QString CSwordBackend::optionName( const CSwordModuleInfo::FilterTypes option ) {
     switch (option) {
@@ -490,7 +402,7 @@ const QString CSwordBackend::booknameLanguage( const QString& language ) {
         //use what sword returns, language may be different
         QString newLocaleName( sword::LocaleMgr::getSystemLocaleMgr()->getDefaultLocaleName()  );
 
-        Q_FOREACH (CSwordModuleInfo *mod, m_dataModel.modules()) {
+        Q_FOREACH (CSwordModuleInfo *mod, m_dataModel.moduleList()) {
             if ( (mod->type() == CSwordModuleInfo::Bible) || (mod->type() == CSwordModuleInfo::Commentary) ) {
                 //Create a new key, it will get the default bookname language
                 ((sword::VerseKey*)(mod->module()->getKey()))->setLocale( newLocaleName.toUtf8().constData() );
@@ -609,3 +521,26 @@ QStringList CSwordBackend::swordDirList() const {
 
     return swordDirSet.values();
 }
+
+void CSwordBackend::deleteOrphanedIndices() {
+    QDir dir(CSwordModuleInfo::getGlobalBaseIndexLocation());
+    dir.setFilter(QDir::Dirs);
+    CSwordModuleInfo* module;
+
+    for (unsigned int i = 0; i < dir.count(); i++) {
+        if (dir[i] != "." && dir[i] != "..") {
+            if ( (module = this->findModuleByName(dir[i])) ) { //mod exists
+                if (!module->hasIndex()) { //index files found, but wrong version etc.
+                    qDebug() << "deleting outdated index for module" << dir[i];
+                    CSwordModuleInfo::deleteIndexForModule( dir[i] );
+                }
+            }
+            else { //no module exists
+                if (CBTConfig::get( CBTConfig::autoDeleteOrphanedIndices ) ) {
+                    qDebug() << "deleting orphaned index in directory" << dir[i];
+                    CSwordModuleInfo::deleteIndexForModule( dir[i] );
+                }
+            }
+        }
+    }
+}
