@@ -2,14 +2,14 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
 
 #include "backend/rendering/cbookdisplay.h"
 
-#include <boost/scoped_ptr.hpp>
+#include <QSharedPointer>
 #include <QtAlgorithms>
 
 #include "backend/drivers/cswordbookmoduleinfo.h"
@@ -17,12 +17,18 @@
 #include "backend/rendering/cdisplayrendering.h"
 
 
-/** Returns the rendered text using the modules in the list and using the key parameter. The displayoptions and filter options are used, too. */
-const QString Rendering::CBookDisplay::text( const QList<CSwordModuleInfo*>& modules, const QString& keyName, const CSwordBackend::DisplayOptions displayOptions, const CSwordBackend::FilterOptions filterOptions ) {
-    CSwordBookModuleInfo* book = dynamic_cast<CSwordBookModuleInfo*>(modules.first());
+const QString Rendering::CBookDisplay::text(
+        const QList<const CSwordModuleInfo*> &modules,
+        const QString &keyName,
+        const DisplayOptions &displayOptions,
+        const FilterOptions &filterOptions)
+{
+    typedef CSwordBookModuleInfo CSBMI;
+
+    const CSBMI* book = dynamic_cast<const CSBMI*>(modules.first());
     Q_ASSERT(book);
 
-    CSwordBackend::DisplayOptions dOpts = displayOptions;
+    DisplayOptions dOpts = displayOptions;
     dOpts.lineBreaks = true; //books should render with blocks, not with inlined sections
 
     CDisplayRendering render(dOpts, filterOptions);
@@ -32,10 +38,10 @@ const QString Rendering::CBookDisplay::text( const QList<CSwordModuleInfo*>& mod
     // the number of levels which should be display together, 1 means display no entries together
     int displayLevel = book->config( CSwordModuleInfo::DisplayLevel ).toInt();
 
-    boost::scoped_ptr<CSwordTreeKey> key (
+    QSharedPointer<CSwordTreeKey> key (
         dynamic_cast<CSwordTreeKey*>( CSwordKey::createInstance(book) )
     );
-    key->key(keyName); //set the key to position we'd like to get
+    key->setKey(keyName); //set the key to position we'd like to get
 
     const unsigned long offset = key->getOffset();
 
@@ -60,7 +66,7 @@ const QString Rendering::CBookDisplay::text( const QList<CSwordModuleInfo*>& mod
 
     int possibleLevels = 1; //we start with the default value of displayLevel, which means no entries together
 
-    while ( key->parent() && (key->key() != "/") && !key->key().isEmpty() ) {//add parents
+    while ( key->sword::TreeKeyIdx::parent() && (key->key() != "/") && !key->key().isEmpty() ) {//add parents
         ++possibleLevels;
     };
 
@@ -90,7 +96,7 @@ const QString Rendering::CBookDisplay::text( const QList<CSwordModuleInfo*>& mod
     // at the moment we're at the lowest level, so we only have to go up!
     for (int currentLevel = 1; currentLevel < displayLevel; ++currentLevel) { //we start again with 1 == standard of displayLevel
 
-        if ( !key->parent() ) { //something went wrong although we checked before! Be safe and return entry's text
+        if ( !key->sword::TreeKeyIdx::parent() ) { //something went wrong although we checked before! Be safe and return entry's text
             tree.append( new CDisplayRendering::KeyTreeItem( key->key(), modules, itemSettings ) );
 
             const QString renderedText = render.renderKeyTree(tree);
@@ -108,7 +114,7 @@ const QString Rendering::CBookDisplay::text( const QList<CSwordModuleInfo*>& mod
     //const bool hasToplevelText = !key->strippedText().isEmpty();
     key->firstChild(); //go to the first sibling on the same level
 
-    setupRenderTree(key.get(), &tree, keyName);
+    setupRenderTree(key.data(), &tree, keyName);
 
     const QString renderedText = render.renderKeyTree(tree);
 
@@ -126,7 +132,9 @@ void Rendering::CBookDisplay::setupRenderTree(CSwordTreeKey * swordTree, CTextRe
     CTextRendering::KeyTreeItem::Settings settings;
     settings.highlight = (key == highlightKey);
 
-    CTextRendering::KeyTreeItem* item = new CTextRendering::KeyTreeItem(key, swordTree->module(0), settings );
+    /// \todo Check whether this is correct:
+    CTextRendering::KeyTreeItem *item = new CTextRendering::KeyTreeItem(
+            key, swordTree->module(), settings);
     renderTree->append( item );
 
     if (swordTree->hasChildren()) { //print tree for the child items
