@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -14,11 +14,18 @@
 #include "backend/rendering/cdisplayrendering.h"
 
 
-const QString Rendering::CChapterDisplay::text( const QList<CSwordModuleInfo*>& modules, const QString& keyName, const CSwordBackend::DisplayOptions displayOptions, const CSwordBackend::FilterOptions filterOptions ) {
+const QString Rendering::CChapterDisplay::text(
+        const QList<const CSwordModuleInfo*> &modules,
+        const QString &keyName,
+        const DisplayOptions &displayOptions,
+        const FilterOptions &filterOptions)
+{
+    typedef CSwordBibleModuleInfo CSBMI;
+
     Q_ASSERT( modules.count() >= 1 );
     Q_ASSERT( !keyName.isEmpty() );
 
-    CSwordModuleInfo* module = modules.first();
+    const CSwordModuleInfo *module = modules.first();
 
     if (modules.count() == 1) module->module()->setSkipConsecutiveLinks( true ); //skip empty, linked verses
 
@@ -37,14 +44,14 @@ const QString Rendering::CChapterDisplay::text( const QList<CSwordModuleInfo*>&
     if (module->type() == CSwordModuleInfo::Bible) {
         ((sword::VerseKey*)(module->module()->getKey()))->Headings(1); //HACK: enable headings for VerseKeys
 
-        CSwordBibleModuleInfo* bible = dynamic_cast<CSwordBibleModuleInfo*>(module);
-        Q_ASSERT(bible);
+        Q_ASSERT(dynamic_cast<const CSBMI*>(module) != 0);
+        const CSBMI *bible = static_cast<const CSBMI*>(module);
 
         CSwordVerseKey k1(module);
         k1.Headings(1);
-        k1.key(keyName);
+        k1.setKey(keyName);
 
-        if (k1.Chapter() == 1)	k1.Chapter(0); //Chapter 1, start with 0:0, otherwise X:0
+        if (k1.Chapter() == 1)    k1.Chapter(0); //Chapter 1, start with 0:0, otherwise X:0
 
         k1.Verse(0);
 
