@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -16,15 +16,21 @@
 #include "backend/keys/cswordversekey.h"
 #include "backend/managers/cdisplaytemplatemgr.h"
 #include "backend/managers/referencemanager.h"
-#include "util/cpointers.h"
 
 
 namespace Rendering {
 
-CDisplayRendering::CDisplayRendering(CSwordBackend::DisplayOptions displayOptions, CSwordBackend::FilterOptions filterOptions)
-        : CHTMLExportRendering(CHTMLExportRendering::Settings(true), displayOptions, filterOptions) {}
+CDisplayRendering::CDisplayRendering(const DisplayOptions &displayOptions,
+                                     const FilterOptions &filterOptions)
+        : CHTMLExportRendering(CHTMLExportRendering::Settings(true),
+                               displayOptions, filterOptions)
+{
+    // Intentionally empty
+}
 
-const QString CDisplayRendering::entryLink( const KeyTreeItem& item, CSwordModuleInfo*  module ) {
+const QString CDisplayRendering::entryLink(const KeyTreeItem &item,
+                                           const CSwordModuleInfo *module)
+{
     QString linkText;
 
     const bool isBible = module && (module->type() == CSwordModuleInfo::Bible);
@@ -32,7 +38,7 @@ const QString CDisplayRendering::entryLink( const KeyTreeItem& item, CSwordModul
     vk.Headings(true);
 
     if (isBible) {
-        vk.key(item.key());
+        vk.setKey(item.key());
     }
 
     if (isBible && (vk.Verse() == 0)) {
@@ -105,7 +111,7 @@ const QString CDisplayRendering::keyToHTMLAnchor(const QString& key) {
 }
 
 const QString CDisplayRendering::finishText( const QString& oldText, KeyTree& tree ) {
-    QList<CSwordModuleInfo*> modules = collectModules(&tree);
+    QList<const CSwordModuleInfo*> modules = collectModules(&tree);
     qDebug() << "CDisplayRendering::finishText";
 
     //marking words is very slow, we have to find a better solution
@@ -139,9 +145,9 @@ const QString CDisplayRendering::finishText( const QString& oldText, KeyTree& tr
     const CLanguageMgr::Language* const lang =
         (modules.count() >= 1)
         ? modules.first()->language()
-        : CPointers::languageMgr()->defaultLanguage();
+        : CLanguageMgr::instance()->defaultLanguage();
 
-    CDisplayTemplateMgr* tMgr = CPointers::displayTemplateManager();
+    CDisplayTemplateMgr *tMgr = CDisplayTemplateMgr::instance();
 
     //Q_ASSERT(modules.count() >= 1);
 
