@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -24,15 +24,17 @@
 
 using namespace Rendering;
 
-/** Returns the rendered text using the modules in the list and using the key parameter.
- * The displayoptions and filter options are used, too.
- */
-const QString CEntryDisplay::text( const QList<CSwordModuleInfo*>& modules, const QString& keyName, const CSwordBackend::DisplayOptions displayOptions, const CSwordBackend::FilterOptions filterOptions ) {
+const QString CEntryDisplay::text(
+        const QList<const CSwordModuleInfo*> &modules,
+        const QString &keyName,
+        const DisplayOptions &displayOptions,
+        const FilterOptions &filterOptions)
+{
     CDisplayRendering render(displayOptions, filterOptions);
 
     //no highlighted key and no extra key link in the text
     CTextRendering::KeyTreeItem::Settings normal_settings(false, CTextRendering::KeyTreeItem::Settings::CompleteShort);
-    CSwordModuleInfo* module = modules.first();
+    const CSwordModuleInfo *module = modules.first();
 
     Rendering::CTextRendering::KeyTree tree;
 
@@ -42,7 +44,7 @@ const QString CEntryDisplay::text( const QList<CSwordModuleInfo*>& modules, cons
 
         CSwordVerseKey k1(module);
         k1.Headings(1);
-        k1.key(keyName);
+        k1.setKey(keyName);
 
         // don't print the key
         CTextRendering::KeyTreeItem::Settings preverse_settings(false, CTextRendering::KeyTreeItem::Settings::NoKey);
