@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -25,11 +25,11 @@ class CPlainTextExportRendering : public CHTMLExportRendering {
 
     public:
         CPlainTextExportRendering(
-            const Settings& settings,
-            CSwordBackend::DisplayOptions displayOptions = CBTConfig::getDisplayOptionDefaults(),
-            CSwordBackend::FilterOptions filterOptions = CBTConfig::getFilterOptionDefaults()
+            const Settings &settings,
+            const DisplayOptions &displayOptions = CBTConfig::getDisplayOptionDefaults(),
+            const FilterOptions &filterOptions = CBTConfig::getFilterOptionDefaults()
         );
-        virtual ~CPlainTextExportRendering();
+        virtual inline ~CPlainTextExportRendering() {};
 
     protected:
         virtual const QString renderEntry( const KeyTreeItem&, CSwordKey* = 0 );
