@@ -2,14 +2,14 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
 
 #include "backend/rendering/ctextrendering.h"
 
-#include <boost/scoped_ptr.hpp>
+#include <QSharedPointer>
 
 #include <QRegExp>
 #include <QtAlgorithms>
@@ -26,17 +26,20 @@
 
 using namespace Rendering;
 
-CTextRendering::KeyTreeItem::KeyTreeItem(const QString& key, CSwordModuleInfo const * mod, const Settings settings )
-        : m_settings( settings ),
+CTextRendering::KeyTreeItem::KeyTreeItem(const QString &key,
+                                         const CSwordModuleInfo *module,
+                                         const Settings &settings)
+        : m_settings(settings),
         m_moduleList(),
         m_key( key ),
         m_childList(),
         m_stopKey( QString::null ),
         m_alternativeContent( QString::null ) {
-    m_moduleList.append( const_cast<CSwordModuleInfo*>(mod) ); //BAD CODE
+    m_moduleList.append( const_cast<CSwordModuleInfo*>(module) ); //BAD CODE
 }
 
-CTextRendering::KeyTreeItem::KeyTreeItem(const QString& content, const Settings settings )
+CTextRendering::KeyTreeItem::KeyTreeItem(const QString &content,
+                                         const Settings &settings)
         : m_settings( settings ),
         m_moduleList(),
         m_key( QString::null ),
@@ -45,7 +48,9 @@ CTextRendering::KeyTreeItem::KeyTreeItem(const QString& content, const Settings
         m_alternativeContent( content ) {
 }
 
-CTextRendering::KeyTreeItem::KeyTreeItem(const QString& key, const QList<CSwordModuleInfo*>& mods, const Settings settings )
+CTextRendering::KeyTreeItem::KeyTreeItem(const QString &key,
+                                         const QList<const CSwordModuleInfo*> &mods,
+                                         const Settings &settings)
         : m_settings( settings ),
         m_moduleList( mods ),
         m_key( key ),
@@ -76,11 +81,10 @@ CTextRendering::KeyTreeItem::KeyTreeItem(const KeyTreeItem& i)
 
 }
 
-CTextRendering::KeyTreeItem::~KeyTreeItem() {
-    qDeleteAll(m_childList);
-}
-
-CTextRendering::KeyTreeItem::KeyTreeItem(const QString& startKey, const QString& stopKey, CSwordModuleInfo* module, const Settings settings)
+CTextRendering::KeyTreeItem::KeyTreeItem(const QString &startKey,
+                                         const QString &stopKey,
+                                         const CSwordModuleInfo *module,
+                                         const Settings &settings)
         : m_settings( settings ),
         m_moduleList(),
         m_key( startKey ),
@@ -94,10 +98,10 @@ CTextRendering::KeyTreeItem::KeyTreeItem(const QString& startKey, const QString&
 
     if (module->type() == CSwordModuleInfo::Bible) {
         CSwordVerseKey start(module);
-        start.key(startKey);
+        start.setKey(startKey);
 
         CSwordVerseKey stop(module);
-        stop.key(stopKey);
+        stop.setKey(stopKey);
 
         if (!m_key.isEmpty() && !m_stopKey.isEmpty()) { //we have a range of keys
             bool ok = true;
@@ -154,13 +158,13 @@ const QString& CTextRendering::KeyTreeItem::getAlternativeContent() const {
     return m_alternativeContent;
 }
 
-const QList<CSwordModuleInfo*> CTextRendering::collectModules(KeyTree* const tree) const {
+const QList<const CSwordModuleInfo*> CTextRendering::collectModules(KeyTree* const tree) const {
     //collect all modules which are available and used by child items
-    QList<CSwordModuleInfo*> modules;
+    QList<const CSwordModuleInfo*> modules;
 
     foreach (KeyTreeItem* c, (*tree)) {
         Q_ASSERT(c);
-        foreach (CSwordModuleInfo* mod, c->modules()) {
+        foreach (const CSwordModuleInfo* mod, c->modules()) {
             if (!modules.contains(mod)) {
                 modules.append(mod);
             }
@@ -172,20 +176,22 @@ const QList<CSwordModuleInfo*> CTextRendering::collectModules(KeyTree* const tre
 const QString CTextRendering::renderKeyTree( KeyTree& tree ) {
     initRendering();
 
-    QList<CSwordModuleInfo*> modules = collectModules(&tree);
+    QList<const CSwordModuleInfo*> modules = collectModules(&tree);
     QString t;
 
     //optimization for entries with the same key
-    boost::scoped_ptr<CSwordKey> key(
+    QSharedPointer<CSwordKey> key(
         (modules.count() == 1) ? CSwordKey::createInstance(modules.first()) : 0
     );
 
-    foreach (KeyTreeItem* c, tree) {
-        if (modules.count() == 1) { //this optimizes the rendering, only one key created for all items
-            key->key( c->key() );
-            t.append( renderEntry( *c, key.get()) );
+    if (modules.count() == 1) { //this optimizes the rendering, only one key created for all items
+        foreach (KeyTreeItem* c, tree) {
+            key->setKey(c->key());
+            t.append( renderEntry( *c, key.data()) );
         }
-        else {
+    }
+    else {
+        foreach (KeyTreeItem* c, tree) {
             t.append( renderEntry( *c ) );
         }
     }
@@ -193,19 +199,25 @@ const QString CTextRendering::renderKeyTree( KeyTree& tree ) {
     return finishText(t, tree);
 }
 
-const QString CTextRendering::renderKeyRange( const QString& start, const QString& stop, const QList<CSwordModuleInfo*>& modules, const QString& highlightKey, const KeyTreeItem::Settings& keySettings ) {
+const QString CTextRendering::renderKeyRange(
+        const QString &start,
+        const QString &stop,
+        const QList<const CSwordModuleInfo*> &modules,
+        const QString &highlightKey,
+        const KeyTreeItem::Settings &keySettings)
+{
 
-    CSwordModuleInfo* module = modules.first();
+    const CSwordModuleInfo *module = modules.first();
     //qWarning( "renderKeyRange start %s stop %s \n", start.latin1(), stop.latin1() );
 
-    boost::scoped_ptr<CSwordKey> lowerBound( CSwordKey::createInstance(module) );
-    lowerBound->key(start);
+    QSharedPointer<CSwordKey> lowerBound( CSwordKey::createInstance(module) );
+    lowerBound->setKey(start);
 
-    boost::scoped_ptr<CSwordKey> upperBound( CSwordKey::createInstance(module) );
-    upperBound->key(stop);
+    QSharedPointer<CSwordKey> upperBound( CSwordKey::createInstance(module) );
+    upperBound->setKey(stop);
 
-    sword::SWKey* sw_start = dynamic_cast<sword::SWKey*>(lowerBound.get());
-    sword::SWKey* sw_stop = dynamic_cast<sword::SWKey*>(upperBound.get());
+    sword::SWKey* sw_start = dynamic_cast<sword::SWKey*>(lowerBound.data());
+    sword::SWKey* sw_stop = dynamic_cast<sword::SWKey*>(upperBound.data());
 
     Q_ASSERT((*sw_start == *sw_stop) || (*sw_start < *sw_stop));
 
@@ -216,10 +228,10 @@ const QString CTextRendering::renderKeyRange( const QString& start, const QStrin
         KeyTree tree;
         KeyTreeItem::Settings settings = keySettings;
 
-        CSwordVerseKey* vk_start = dynamic_cast<CSwordVerseKey*>(lowerBound.get());
+        CSwordVerseKey* vk_start = dynamic_cast<CSwordVerseKey*>(lowerBound.data());
         Q_ASSERT(vk_start);
 
-        CSwordVerseKey* vk_stop = dynamic_cast<CSwordVerseKey*>(upperBound.get());
+        CSwordVerseKey* vk_stop = dynamic_cast<CSwordVerseKey*>(upperBound.data());
         Q_ASSERT(vk_stop);
 
         bool ok = true;
@@ -250,13 +262,15 @@ const QString CTextRendering::renderKeyRange( const QString& start, const QStrin
     return QString::null;
 }
 
-const QString CTextRendering::renderSingleKey( const QString& key, const QList<CSwordModuleInfo*>& moduleList, const KeyTreeItem::Settings& settings ) {
+const QString CTextRendering::renderSingleKey(
+        const QString &key,
+        const QList<const CSwordModuleInfo*> &modules,
+        const KeyTreeItem::Settings &settings)
+{
     KeyTree tree;
-    tree.append( new KeyTreeItem(key, moduleList, settings) );
+    tree.append( new KeyTreeItem(key, modules, settings) );
 
     const QString renderedText = renderKeyTree(tree);
     qDeleteAll(tree);
     return renderedText;
 }
-
-
