@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -14,9 +14,13 @@
 
 #include <QList>
 #include "frontend/displaywindow/cdisplaywindow.h"
+#include "frontend/displaywindow/cwritewindow.h"
 #include "frontend/profile/cprofile.h"
 #include "frontend/profile/cprofilemgr.h"
 #include <QSignalMapper>
+#ifdef BT_DEBUG
+#include <QMutex>
+#endif
 
 
 namespace InfoDisplay {
@@ -24,11 +28,13 @@ class CInfoDisplay;
 }
 class BtActionClass;
 class BtBookshelfDockWidget;
+class BtOpenWorkAction;
 class CBookmarkIndex;
 class CDisplayWindow;
 class CMDIArea;
 class CSwordModuleInfo;
 class QAction;
+class QLabel;
 class QMenu;
 class QToolBar;
 class QSplitter;
@@ -45,7 +51,7 @@ class QSignalMapper;
   * and SWKey (CSwordLDKey).
   * </p>
   * <p>
-  * The classes used to handle all module based stuff are derived from CModuleInfo.
+  * The classes used to handle all module based stuff are derived from CSwordModuleInfo.
   * The module classes are: CSwordModuleInfo (for Sword modules),
   * CSwordBibleModuleInfo (for bibles), CSwordCommentaryModuleInfo (for commentaries) and
   * CSwordLexiconModuleInfo (for lexicons).
@@ -67,44 +73,43 @@ class QSignalMapper;
   * @page frontend The structure of the frontend
   *
   * <p>
-  * The frontend contains the classes which interact with the user. For example the main index,
-  * the display windows, the searchdialog or the other parts.
+  * The frontend contains the classes which interact with the user. For example the
+  * display windows, the searchdialog or the other parts.
   * </p><p>
-  * The main index is implemented in the class CGroupManager, the items of the
-  * main index are implemented in the class CGroupManagerItem.
-  * Each CGroupManagerItem has a type() function which returns the type of
-  * the object (Module, Bookmark or Group).<br/>
-  * The display windows are all derived from the base class CPresenter.
-  * The display windows which handle Sword modules are all derived from the
-  * CSwordPresenter class.
-  * The display windows which provide functionality are CBiblePresenter for
-  * Bibles, CCommentaryPresenter for commentaries and CLexiconPresenter for
-  * lexicon and dictionaries.
-  * CSwordPresenter provides the essential base functions which are
-  * reimplemented in the derived classes (for example CSwordPresenter::lookup).<br/>
+  * The display windows which provide functionality are CBibleReadWindow for
+  * Bibles, CBookReadWindow for books, CCommentaryReadWindow for commentaries and CLexiconReadWindow for
+  * lexicon and dictionaries. CHTMLWriteWindow and CPlainWriteWindows are used for editing the Personal Commentary.
   * </p><p>
+  *
+  * The class CDisplayWindow is the class that various views with in the windows are derived.
+  * </p><p>
+  *
   * Another important part of the frontend are the keychoosers.
   * They provide an interface to choose a key of a module.
   * The interface for different module types is different.
   * The base class is CKeyChooser which is the factory for the derived classes.
   * Use the function CKeyChooser::createInstance to get the correct
   * keychooser implementation for the desired module.<br/>
+  * </p><p>
+  * Some major toolbar widgets are CKeyChooser and BtDisplaySettingsButton.
   * </p>
   */
 
 /** @mainpage BibleTime - sourcecode documentation
  * BibleTime main page.
- * <p>This is the sourcecode documentation of BibleTime, a Bible study tool for KDE/Linux.
- * BibleTime is devided in two major parts, the backend and the frontend.
+ * <p>This is the sourcecode documentation of BibleTime, a Bible study tool.
+ * <p>
+ * The main class of BibleTime is called @ref BibleTime, which is the main window
+ * and initializes all important parts at startup.
+ * </p><p>
+ * BibleTime is divided in two major parts, the backend and the frontend.
+ * The text display windows belong to the @ref frontend.
  * The backend is mainly a wrapper around Sword's classes to use Qt functionality
  * to allow easy access to it's functionality and to have it in a (more or less :)
  * object oriented structure.</p><br/>
  * <p>
- *       -Introduction to the backend: @ref backend<br/>
  *       -Introduction to the frontend: @ref frontend.<br/>
- * The main class of BibleTime is called @ref BibleTime, which is the main window
- * and initializes all important parts at startup. The text display windows
- * belong to the @ref frontend.
+ *       -Introduction to the backend: @ref backend<br/>
  * </p>
  */
 
@@ -122,16 +127,15 @@ class BibleTime : public QMainWindow {
         friend class CDisplayWindow;
         friend class BibleTimeDBusAdaptor;
         Q_OBJECT
+
     public:
-        /**
-         * construtor of BibleTime
-         */
-        BibleTime();
-        /**
-         * destructor of BibleTime
-         */
+
+        BibleTime(QWidget *parent = 0, Qt::WindowFlags flags = 0);
+
         ~BibleTime();
 
+        static inline BibleTime *instance() { return m_instance; }
+
         /**
         * Reads the settings from the configfile and sets the right properties.
         */
@@ -157,9 +161,51 @@ class BibleTime : public QMainWindow {
         */
         void saveConfigSettings();
         /**
-        *  Get QAction from actionCollection
+        * Get pointer to Navigation toolbar
         */
-        QAction* getAction(const QString& actionName);
+        inline QToolBar *navToolBar() const {
+            return m_navToolBar;
+        }
+        /**
+        * Get pointer to Works toolbar
+        */
+        inline BtModuleChooserBar *worksToolBar() const {
+            return m_worksToolBar;
+        }
+        /**
+        * Get pointer to Tools toolbar
+        */
+        inline QToolBar *toolsToolBar() const {
+            return m_toolsToolBar;
+        }
+        /**
+        * Get pointer to Format toolbar
+        */
+        inline QToolBar *formatToolBar() const {
+            return m_formatToolBar;
+        }
+
+        /**
+          \returns a pointer to the info display.
+        */
+        inline InfoDisplay::CInfoDisplay *infoDisplay() const {
+            return m_infoDisplay;
+        }
+
+        /**
+        * Clears the actions of the MDI related toolbars
+        */
+        void clearMdiToolBars();
+
+        /**
+          Displays a dialog which asks the user an unlock key for the given module and tries
+          to unlock the module. If an invalid unlock key is given, a warning message is
+          issued and the user is again asked for the key.
+          \param[in] module The module to unlock.
+          \param[in] parent The parent widget for the unlock dialogs.
+          \returns whether the module was successfully unlocked.
+        */
+        static bool moduleUnlock(CSwordModuleInfo *module, QWidget *parent = 0);
 
     public slots:
         /**
@@ -178,10 +224,20 @@ class BibleTime : public QMainWindow {
         * Opens the bible study howto.
         */
         void openOnlineHelp_Howto();
+
         /**
-        * Processes the commandline options given to BibleTime.
+        * Open the Tip Dialog
         */
-        void processCommandline();
+        void slotOpenTipDialog();
+
+        /**
+          Processes the command-line options given to BibleTime.
+          \param[in] ignoreSession Specifies whether --ignore-session was used.
+          \param[in] bibleKey If --open-default-bible was used, the bible key
+                              specified, or null otherwise.
+        */
+        void processCommandline(bool ignoreSession, const QString &bibleKey);
+
         /**
         * Creates QAction's that have keyboard shortcuts
         */
@@ -193,6 +249,10 @@ class BibleTime : public QMainWindow {
         */
         bool event(QEvent* event);
         /**
+        * Create the main window menu and toolbar
+        */
+        void createMenuAndToolBar();
+        /**
         * Initializes the sword.conf in the $HOME\Sword directory
         */
         void initSwordConfigFile();
@@ -216,6 +276,18 @@ class BibleTime : public QMainWindow {
         * Initializes the action objects of the GUI
         */
         void initActions();
+        /**
+          Initializes the toolbars.
+        */
+        void initToolbars();
+        /**
+          Retranslates the UI.
+        */
+        void retranslateUi();
+        /**
+          Retranslates the UI actions.
+        */
+        static void retranslateUiActions(BtActionCollection* ac);
         /**
         * Initializes one action object
         */
@@ -229,10 +301,11 @@ class BibleTime : public QMainWindow {
         * Refresh main window accelerators
         */
         void refreshBibleTimeAccel();
+
         /**
-        * Called before a window is closed
+        * Reimplemented from QWidget.
         */
-        bool queryClose();
+        void closeEvent(QCloseEvent *event);
 
     protected slots:
         /**
@@ -240,11 +313,11 @@ class BibleTime : public QMainWindow {
          */
         CDisplayWindow* createReadDisplayWindow(QList<CSwordModuleInfo*> modules, const QString& key);
         CDisplayWindow* createReadDisplayWindow(CSwordModuleInfo* module, const QString& key = QString::null);
-        CDisplayWindow* createWriteDisplayWindow(CSwordModuleInfo* module, const QString& key, const CDisplayWindow::WriteWindowType& type);
+        CDisplayWindow* createWriteDisplayWindow(CSwordModuleInfo* module, const QString& key, const CWriteWindow::WriteWindowType& type);
         CDisplayWindow* moduleEditPlain(CSwordModuleInfo *module);
         CDisplayWindow* moduleEditHtml(CSwordModuleInfo *module);
         void searchInModule(CSwordModuleInfo *module);
-        void moduleUnlock(CSwordModuleInfo *module);
+        void slotModuleUnlock(CSwordModuleInfo *module);
         void moduleAbout(CSwordModuleInfo *module);
         void quit();
 
@@ -257,19 +330,23 @@ class BibleTime : public QMainWindow {
          */
         void slotOpenWindowsMenuAboutToShow();
         /**
-         * This slot is connected with the windowAutoTile_action object
+         * This slot is connected with the windowAutoTileVerticalAction object
          */
         void slotAutoTileVertical();
         /**
-         * This slot is connected with the windowAutoTile_action object
+         * This slot is connected with the windowAutoTileHorizontalAction object
          */
         void slotAutoTileHorizontal();
         /**
-         * This slot is connected with the windowAutoCascade_action object
+         * This slot is connected with the windowAutoTileAction object
          */
         void slotAutoTile();
         /**
-         * This slot is connected with the windowAutoTile_action object
+         * This slot is connected with the windowAutoTabbedAction object
+         */
+        void slotAutoTabbed();
+        /**
+         * This slot is connected with the windowAutoCascadeAction object
          */
         void slotAutoCascade();
         void slotUpdateWindowArrangementActions( QAction* );
@@ -282,20 +359,22 @@ class BibleTime : public QMainWindow {
         void slotManualArrangementMode();
 
         /**
-         * Shows/hides the toolbar
+         * Shows/hides the main toolbar
          */
-        void slotToggleToolbar();
-        
+        void slotToggleMainToolbar();
+        void slotToggleToolsToolbar();
+        void slotToggleNavigatorToolbar();
+        void slotToggleWorksToolbar();
+        void slotToggleFormatToolbar();
+
+        void slotToggleToolBarsInEachWindow();
+
         /**
         * Shows/hides the text window text area headers and sets
         * configuration that newly opened windows don't user headers.
         */
         void slotToggleTextWindowHeader();
-        
-        void slotToggleTextWindowToolButtons();
-        void slotToggleTextWindowNavigator();
-        void slotToggleTextWindowModuleChooser();
-        
+
         /**
          * Used to set the active menu
          */
@@ -346,10 +425,7 @@ class BibleTime : public QMainWindow {
         * Slot to refresh the save profile and load profile menus.
         */
         void refreshProfileMenus();
-        /**
-        * Called before quit.
-        */
-        void slot_aboutToQuit();
+
         /**
         * Open the About Dialog
         */
@@ -360,8 +436,11 @@ class BibleTime : public QMainWindow {
         void toggledTextWindowNavigator(bool newState);
         void toggledTextWindowToolButtons(bool newState);
         void toggledTextWindowModuleChooser(bool newState);
+        void toggledTextWindowFormatToolbar(bool newState);
 
     private:
+        static BibleTime *m_instance;
+
         //  True if window was maximized before last toggle to full screen.
         bool m_WindowWasMaximizedBeforeFullScreen;
 
@@ -373,29 +452,71 @@ class BibleTime : public QMainWindow {
         InfoDisplay::CInfoDisplay* m_infoDisplay;
 
         QToolBar* m_mainToolBar;
-        // VIEW menu actions
-        QAction* m_viewToolbar_action;
-        QMenu* m_windowMenu;
-        QMenu* m_openWindowsMenu;
-        /** WINDOW menu actions */
-        QAction* m_windowCascade_action;
-        QAction* m_windowTile_action;
-        QAction* m_windowTileHorizontal_action;
-        QAction* m_windowTileVertical_action;
-        QAction* m_windowManualMode_action;
-        QAction* m_windowAutoCascade_action;
-        QAction* m_windowAutoTile_action;
-        QAction* m_windowAutoTileVertical_action;
-        QAction* m_windowAutoTileHorizontal_action;
-        QAction* m_windowClose_action;
-        QAction* m_windowCloseAll_action;
+        QToolBar* m_navToolBar;
+        BtModuleChooserBar* m_worksToolBar;
+        QToolBar* m_toolsToolBar;
+        QToolBar* m_formatToolBar;
+
+        // File menu:
+        QMenu *m_fileMenu;
+        BtOpenWorkAction *m_openWorkAction;
+        QAction *m_quitAction;
+
+        // View menu:
+        QMenu *m_viewMenu;
+        QAction* m_viewToolbarAction;
+        QAction *m_showBookshelfAction;
+        QAction *m_showBookmarksAction;
+        QAction *m_showMagAction;
+        QMenu *m_toolBarsMenu;
+        QAction *m_showTextAreaHeadersAction;
+        QAction *m_showTextWindowNavigationAction;
+        QAction *m_showTextWindowModuleChooserAction;
+        QAction *m_showTextWindowToolButtonsAction;
+        QAction *m_showFormatToolbarAction;
+        QAction *m_toolbarsInEachWindow;
+
+        // Search menu:
+        QMenu *m_searchMenu;
+        QAction *m_searchOpenWorksAction;
+        QAction *m_searchStandardBibleAction;
+
+        // Window menu:
+        QMenu *m_windowMenu;
+        QMenu *m_openWindowsMenu;
+        QAction *m_windowCascadeAction;
+        QAction *m_windowTileAction;
+        QAction *m_windowTileHorizontalAction;
+        QAction *m_windowTileVerticalAction;
+        QAction *m_windowManualModeAction;
+        QMenu *m_windowArrangementMenu;
+        QAction *m_windowAutoCascadeAction;
+        QAction *m_windowAutoTileAction;
+        QAction *m_windowAutoTabbedAction;
+        QAction *m_windowAutoTileVerticalAction;
+        QAction *m_windowAutoTileHorizontalAction;
+        QAction *m_windowCloseAction;
+        QAction *m_windowCloseAllAction;
+
+        // Settings menu:
+        QMenu *m_settingsMenu;
+        QAction *m_setPreferencesAction;
+        QAction *m_bookshelfManagerAction;
+
+        // Help menu:
+        QMenu *m_helpMenu;
+        QAction *m_openHandbookAction;
+        QAction *m_bibleStudyHowtoAction;
+        QAction *m_aboutBibleTimeAction;
+        QAction *m_tipOfTheDayAction;
+
         BtActionCollection* m_actionCollection;
 
         QMenu* m_windowSaveProfileMenu;
-        QAction* m_windowSaveToNewProfile_action;
+        QAction* m_windowSaveToNewProfileAction;
         QMenu* m_windowLoadProfileMenu;
         QMenu* m_windowDeleteProfileMenu;
-        QAction* m_windowFullscreen_action;
+        QAction* m_windowFullscreenAction;
 
         /**
          * Signal mapper to map windows to menu items.
@@ -425,6 +546,20 @@ class BibleTime : public QMainWindow {
 
         // Helper function
         void syncAllModulesByType(const CSwordModuleInfo::ModuleType type, const QString& key);
+
+    private:
+        void showOrHideToolBars();
+#ifdef BT_DEBUG
+        void deleteDebugWindow();
+    private slots:
+        void slotDebugWindowClosing();
+        void slotDebugTimeout();
+        void slotShowDebugWindow(bool);
+    private:
+        QAction *m_debugWidgetAction;
+        static QLabel *m_debugWindow;
+        static QMutex m_debugWindowLock;
+#endif
 };
 
 #endif
