@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -63,19 +63,19 @@ class BibleTimeDBusAdaptor : QDBusAbstractAdaptor {
         void closeAllModuleWindows();
         /** Returns the reference used in the current window.
         * The format of the returned reference is
-        *	[Module] [Type] OSIS_Reference,
+        *    [Module] [Type] OSIS_Reference,
         * wtih type one of BIBLE/COMMENTARY/BOOK/LEXICON/UNSUPPORTED
         * If the type is BIBLE or COMMENTARY the reference is an OSIS ref
         * in the other cases it's the key name, for books /Chapter/Subsection
         * for Lexicons just the plain key, e.g. "ADAM".
         * e.g.
-        *		[KJV] [BIBLE]	Gen.1.1
-        * 		[MHC] [COMMENTARY]  Gen.1.1
-        * 		[ISBE] [LEXICON]  REDEMPTION
+        *        [KJV] [BIBLE]    Gen.1.1
+        *         [MHC] [COMMENTARY]  Gen.1.1
+        *         [ISBE] [LEXICON]  REDEMPTION
         * @return The reference displayed in the currently active module window. Empty if none is active.
         */
         QString getCurrentReference();
-        /** Seach the searchText in the specified module.
+        /** Search the searchText in the specified module.
         * @param moduleName The module to search in
         * @param searchText Search for this in the modules
         * @return The search result. It's in the format [modulename] osis_ref_of_the_found_key. For example "[KJV] Gen.1.1".
