@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -20,20 +20,21 @@
 #include <QProcess>
 #include <QtGlobal>
 #include <QToolBar>
+#include <QUrl>
 #include "backend/config/cbtconfig.h"
 #include "backend/keys/cswordversekey.h"
+#include "frontend/btaboutdialog.h"
 #include "frontend/cinfodisplay.h"
-#include "frontend/cinputdialog.h"
 #include "frontend/cmdiarea.h"
 #include "frontend/bookshelfmanager/btmodulemanagerdialog.h"
-#include "frontend/displaywindow/cbiblereadwindow.h"
+#include "frontend/displaywindow/btmodulechooserbar.h"
 #include "frontend/displaywindow/cdisplaywindow.h"
-#include "frontend/htmldialogs/btaboutdialog.h"
 #include "frontend/profile/cprofilemgr.h"
 #include "frontend/profile/cprofile.h"
 #include "frontend/profile/cprofilewindow.h"
 #include "frontend/searchdialog/csearchdialog.h"
 #include "frontend/settingsdialogs/cconfigurationdialog.h"
+#include "frontend/tips/bttipdialog.h"
 #include "util/directory.h"
 
 
@@ -60,17 +61,17 @@ void BibleTime::saveConfigSettings() {
 void BibleTime::slotSettingsChanged() {
     qDebug() << "BibleTime::slotSettingsChanged";
     const QString language = CBTConfig::get(CBTConfig::language);
-    CPointers::backend()->booknameLanguage(language);
+    CSwordBackend::instance()->booknameLanguage(language);
 
 // \todo update the bookmarks after Bible bookname language has been changed
-// 	QTreeWidgetItemIterator it(m_mainIndex);
-// 	while (*it) {
-// 		CIndexItemBase* citem = dynamic_cast<CIndexItemBase*>(*it);
-// 		if (citem) {
-// 			citem->update();
-// 		}
-// 		++it;
-// 	}
+//     QTreeWidgetItemIterator it(m_mainIndex);
+//     while (*it) {
+//         CIndexItemBase* citem = dynamic_cast<CIndexItemBase*>(*it);
+//         if (citem) {
+//             citem->update();
+//         }
+//         ++it;
+//     }
 
     refreshBibleTimeAccel();
     refreshDisplayWindows();
@@ -93,26 +94,26 @@ void BibleTime::slotWindowMenuAboutToShow() {
     Q_ASSERT(m_windowMenu);
 
     if ( m_mdi->subWindowList().isEmpty() ) {
-        m_windowCascade_action->setEnabled(false);
-        m_windowTileVertical_action->setEnabled(false);
-        m_windowTileHorizontal_action->setEnabled(false);
-        m_windowClose_action->setEnabled(false);
-        m_windowCloseAll_action->setEnabled(false);
+        m_windowCascadeAction->setEnabled(false);
+        m_windowTileVerticalAction->setEnabled(false);
+        m_windowTileHorizontalAction->setEnabled(false);
+        m_windowCloseAction->setEnabled(false);
+        m_windowCloseAllAction->setEnabled(false);
         m_openWindowsMenu->setEnabled(false);
     }
     else if (m_mdi->subWindowList().count() == 1) {
-        m_windowTileVertical_action->setEnabled(false);
-        m_windowTileHorizontal_action->setEnabled(false);
-        m_windowCascade_action->setEnabled(false);
-        m_windowClose_action->setEnabled(true);
-        m_windowCloseAll_action->setEnabled(true);
+        m_windowTileVerticalAction->setEnabled(false);
+        m_windowTileHorizontalAction->setEnabled(false);
+        m_windowCascadeAction->setEnabled(false);
+        m_windowCloseAction->setEnabled(true);
+        m_windowCloseAllAction->setEnabled(true);
         m_openWindowsMenu->setEnabled(true);
         //   m_windowMenu->insertSeparator();
     }
     else {
         slotUpdateWindowArrangementActions(0); //update the window tile/cascade states
-        m_windowClose_action->setEnabled(true);
-        m_windowCloseAll_action->setEnabled(true);
+        m_windowCloseAction->setEnabled(true);
+        m_windowCloseAllAction->setEnabled(true);
         m_openWindowsMenu->setEnabled(true);
     }
 }
@@ -132,132 +133,152 @@ void BibleTime::slotOpenWindowsMenuAboutToShow() {
     }
 }
 
-/** This slot is connected with the windowAutoTile_action object */
+/** This slot is connected with the windowAutoTileAction object */
 void BibleTime::slotUpdateWindowArrangementActions( QAction* clickedAction ) {
-    /* If a toggle action was clicked we see if it checked ot unchecked and
+    /* If a toggle action was clicked we see if it is checked or unchecked and
     * enable/disable the simple cascade and tile options accordingly
     */
-    m_windowTileVertical_action->setEnabled( m_windowManualMode_action->isChecked() );
-    m_windowTileHorizontal_action->setEnabled( m_windowManualMode_action->isChecked() );
-    m_windowCascade_action->setEnabled( m_windowManualMode_action->isChecked() );
-    m_windowTile_action->setEnabled( m_windowManualMode_action->isChecked() );
+    m_windowTileVerticalAction->setEnabled( m_windowManualModeAction->isChecked() );
+    m_windowTileHorizontalAction->setEnabled( m_windowManualModeAction->isChecked() );
+    m_windowCascadeAction->setEnabled( m_windowManualModeAction->isChecked() );
+    m_windowTileAction->setEnabled( m_windowManualModeAction->isChecked() );
 
     if (clickedAction) {
-        m_windowManualMode_action->setEnabled(
-            m_windowManualMode_action != clickedAction
-            && m_windowTileHorizontal_action != clickedAction
-            && m_windowTileVertical_action != clickedAction
-            && m_windowCascade_action != clickedAction
-            && m_windowTile_action != clickedAction
+        m_windowManualModeAction->setEnabled(
+            m_windowManualModeAction != clickedAction
+            && m_windowTileHorizontalAction != clickedAction
+            && m_windowTileVerticalAction != clickedAction
+            && m_windowCascadeAction != clickedAction
+            && m_windowTileAction != clickedAction
         );
-        m_windowAutoTileVertical_action->setEnabled( m_windowAutoTileVertical_action != clickedAction );
-        m_windowAutoTileHorizontal_action->setEnabled( m_windowAutoTileHorizontal_action != clickedAction );
-        m_windowAutoCascade_action->setEnabled( m_windowAutoCascade_action != clickedAction );
-        m_windowAutoTile_action->setEnabled( m_windowAutoTile_action != clickedAction );
+        m_windowAutoTileVerticalAction->setEnabled( m_windowAutoTileVerticalAction != clickedAction );
+        m_windowAutoTileHorizontalAction->setEnabled( m_windowAutoTileHorizontalAction != clickedAction );
+        m_windowAutoCascadeAction->setEnabled( m_windowAutoCascadeAction != clickedAction );
+        m_windowAutoTileAction->setEnabled( m_windowAutoTileAction != clickedAction );
+        m_windowAutoTabbedAction->setEnabled( m_windowAutoTabbedAction != clickedAction );
     }
 
-    if (clickedAction == m_windowManualMode_action) {
-        m_windowAutoTileVertical_action->setChecked(false);
-        m_windowAutoTileHorizontal_action->setChecked(false);
-        m_windowAutoCascade_action->setChecked(false);
-        m_windowAutoTile_action->setChecked(false);
+    if (clickedAction == m_windowManualModeAction) {
+        m_windowAutoTileVerticalAction->setChecked(false);
+        m_windowAutoTileHorizontalAction->setChecked(false);
+        m_windowAutoCascadeAction->setChecked(false);
+        m_windowAutoTileAction->setChecked(false);
+        m_windowAutoTabbedAction->setChecked(false);
         m_mdi->enableWindowMinMaxFlags(true);
         m_mdi->setMDIArrangementMode( CMDIArea::ArrangementModeManual );
     }
-    else if (clickedAction == m_windowAutoTileVertical_action) {
-        m_windowManualMode_action->setChecked(false);
-        m_windowAutoTileHorizontal_action->setChecked(false);
-        m_windowAutoCascade_action->setChecked(false);
-        m_windowAutoTile_action->setChecked(false);
+    else if (clickedAction == m_windowAutoTileVerticalAction) {
+        m_windowManualModeAction->setChecked(false);
+        m_windowAutoTileHorizontalAction->setChecked(false);
+        m_windowAutoCascadeAction->setChecked(false);
+        m_windowAutoTileAction->setChecked(false);
+        m_windowAutoTabbedAction->setChecked(false);
         m_mdi->enableWindowMinMaxFlags(false);
         m_mdi->setMDIArrangementMode( CMDIArea::ArrangementModeTileVertical );
     }
-    else if (clickedAction == m_windowAutoTileHorizontal_action) {
-        m_windowManualMode_action->setChecked(false);
-        m_windowAutoTileVertical_action->setChecked(false);
-        m_windowAutoCascade_action->setChecked(false);
-        m_windowAutoTile_action->setChecked(false);
+    else if (clickedAction == m_windowAutoTileHorizontalAction) {
+        m_windowManualModeAction->setChecked(false);
+        m_windowAutoTileVerticalAction->setChecked(false);
+        m_windowAutoCascadeAction->setChecked(false);
+        m_windowAutoTileAction->setChecked(false);
+        m_windowAutoTabbedAction->setChecked(false);
         m_mdi->enableWindowMinMaxFlags(false);
         m_mdi->setMDIArrangementMode( CMDIArea::ArrangementModeTileHorizontal );
     }
-    else if (clickedAction == m_windowAutoTile_action) {
-        m_windowManualMode_action->setChecked(false);
-        m_windowAutoTileHorizontal_action->setChecked(false);
-        m_windowAutoTileVertical_action->setChecked(false);
-        m_windowAutoCascade_action->setChecked(false);
+    else if (clickedAction == m_windowAutoTileAction) {
+        m_windowManualModeAction->setChecked(false);
+        m_windowAutoTileHorizontalAction->setChecked(false);
+        m_windowAutoTileVerticalAction->setChecked(false);
+        m_windowAutoTabbedAction->setChecked(false);
+        m_windowAutoCascadeAction->setChecked(false);
         m_mdi->enableWindowMinMaxFlags(false);
         m_mdi->setMDIArrangementMode( CMDIArea::ArrangementModeTile );
     }
-    else if (clickedAction == m_windowAutoCascade_action) {
-        m_windowManualMode_action->setChecked(false);
-        m_windowAutoTileHorizontal_action->setChecked(false);
-        m_windowAutoTileVertical_action->setChecked(false);
-        m_windowAutoTile_action->setChecked(false);
+    else if (clickedAction == m_windowAutoTabbedAction) {
+        m_windowManualModeAction->setChecked(false);
+        m_windowAutoTileHorizontalAction->setChecked(false);
+        m_windowAutoTileVerticalAction->setChecked(false);
+        m_windowAutoTileAction->setChecked(false);
+        m_windowAutoCascadeAction->setChecked(false);
+        m_mdi->enableWindowMinMaxFlags(false);
+        m_mdi->setMDIArrangementMode( CMDIArea::ArrangementModeTabbed );
+    }
+    else if (clickedAction == m_windowAutoCascadeAction) {
+        m_windowManualModeAction->setChecked(false);
+        m_windowAutoTileHorizontalAction->setChecked(false);
+        m_windowAutoTileVerticalAction->setChecked(false);
+        m_windowAutoTileAction->setChecked(false);
+        m_windowAutoTabbedAction->setChecked(false);
         m_mdi->enableWindowMinMaxFlags(false);
         m_mdi->setMDIArrangementMode( CMDIArea::ArrangementModeCascade );
     }
-    else if (clickedAction == m_windowTile_action) {
+    else if (clickedAction == m_windowTileAction) {
         m_mdi->setMDIArrangementMode( CMDIArea::ArrangementModeManual );
         m_mdi->myTile();
     }
-    else if (clickedAction == m_windowCascade_action) {
+    else if (clickedAction == m_windowCascadeAction) {
         m_mdi->setMDIArrangementMode( CMDIArea::ArrangementModeManual );
         m_mdi->myCascade();
     }
-    else if (clickedAction == m_windowTileVertical_action) {
+    else if (clickedAction == m_windowTileVerticalAction) {
         m_mdi->setMDIArrangementMode( CMDIArea::ArrangementModeManual );
         m_mdi->myTileVertical();
     }
-    else if (clickedAction == m_windowTileHorizontal_action) {
+    else if (clickedAction == m_windowTileHorizontalAction) {
         m_mdi->setMDIArrangementMode( CMDIArea::ArrangementModeManual );
         m_mdi->myTileHorizontal();
     }
 }
 
 void BibleTime::slotManualArrangementMode() {
-    slotUpdateWindowArrangementActions( m_windowManualMode_action );
+    slotUpdateWindowArrangementActions( m_windowManualModeAction );
 }
 
-/** This slot is connected with the windowAutoTile_action object */
+/** This slot is connected with the windowAutoTileAction object */
 void BibleTime::slotAutoTileHorizontal() {
-    slotUpdateWindowArrangementActions( m_windowAutoTileHorizontal_action );
+    slotUpdateWindowArrangementActions( m_windowAutoTileHorizontalAction );
 }
 
-/** This slot is connected with the windowAutoTile_action object */
+/** This slot is connected with the windowAutoTileAction object */
 void BibleTime::slotAutoTileVertical() {
-    slotUpdateWindowArrangementActions( m_windowAutoTileVertical_action );
+    slotUpdateWindowArrangementActions( m_windowAutoTileVerticalAction );
 }
 
-/** This slot is connected with the windowAutoTile_action object */
+/** This slot is connected with the windowAutoTileAction object */
 void BibleTime::slotAutoTile() {
-    slotUpdateWindowArrangementActions( m_windowAutoTile_action );
+    slotUpdateWindowArrangementActions( m_windowAutoTileAction );
+}
+
+/** This slot is connected with the windowAutoTabbedAction object */
+void BibleTime::slotAutoTabbed() {
+    slotUpdateWindowArrangementActions( m_windowAutoTabbedAction );
 }
 
 void BibleTime::slotTile() {
-    slotUpdateWindowArrangementActions( m_windowTile_action );
+    slotUpdateWindowArrangementActions( m_windowTileAction );
 }
 
 void BibleTime::slotCascade() {
-    slotUpdateWindowArrangementActions( m_windowCascade_action );
+    slotUpdateWindowArrangementActions( m_windowCascadeAction );
 }
 
 void BibleTime::slotTileVertical() {
-    slotUpdateWindowArrangementActions( m_windowTileVertical_action );
+    slotUpdateWindowArrangementActions( m_windowTileVerticalAction );
 }
 
 void BibleTime::slotTileHorizontal() {
-    slotUpdateWindowArrangementActions( m_windowTileHorizontal_action );
+    slotUpdateWindowArrangementActions( m_windowTileHorizontalAction );
 }
 
-/** This slot is connected with the windowAutoCascade_action object */
+/** This slot is connected with the windowAutoCascadeAction object */
 void BibleTime::slotAutoCascade() {
-    slotUpdateWindowArrangementActions( m_windowAutoCascade_action );
+    slotUpdateWindowArrangementActions( m_windowAutoCascadeAction );
 }
 
 /** Shows/hides the toolbar */
-void BibleTime::slotToggleToolbar() {
+void BibleTime::slotToggleMainToolbar() {
     Q_ASSERT(m_mainToolBar);
-    if (m_viewToolbar_action->isChecked()) {
+    if (m_viewToolbarAction->isChecked()) {
         m_mainToolBar->show();
     }
     else {
@@ -271,22 +292,80 @@ void BibleTime::slotToggleTextWindowHeader() {
     emit toggledTextWindowHeader(!currentState);
 }
 
-void BibleTime::slotToggleTextWindowNavigator() {
+void BibleTime::slotToggleNavigatorToolbar() {
     bool currentState = CBTConfig::get(CBTConfig::showTextWindowNavigator);
     CBTConfig::set(CBTConfig::showTextWindowNavigator, !currentState);
-    emit toggledTextWindowNavigator(!currentState);
+    showOrHideToolBars();
+    if (CBTConfig::get(CBTConfig::showToolbarsInEachWindow))
+        emit toggledTextWindowNavigator(!currentState);
+    else
+        emit toggledTextWindowNavigator(false);
 }
 
-void BibleTime::slotToggleTextWindowToolButtons() {
+void BibleTime::slotToggleToolsToolbar() {
     bool currentState = CBTConfig::get(CBTConfig::showTextWindowToolButtons);
     CBTConfig::set(CBTConfig::showTextWindowToolButtons, !currentState);
-    emit toggledTextWindowToolButtons(!currentState);
+    showOrHideToolBars();
+    if (CBTConfig::get(CBTConfig::showToolbarsInEachWindow))
+        emit toggledTextWindowToolButtons(!currentState);
+    else
+        emit toggledTextWindowToolButtons(false);
 }
 
-void BibleTime::slotToggleTextWindowModuleChooser() {
+void BibleTime::slotToggleWorksToolbar() {
     bool currentState = CBTConfig::get(CBTConfig::showTextWindowModuleSelectorButtons);
     CBTConfig::set(CBTConfig::showTextWindowModuleSelectorButtons, !currentState);
-    emit toggledTextWindowModuleChooser(!currentState);
+    showOrHideToolBars();
+    if (CBTConfig::get(CBTConfig::showToolbarsInEachWindow))
+        emit toggledTextWindowModuleChooser(!currentState);
+    else
+        emit toggledTextWindowModuleChooser(false);
+}
+
+void BibleTime::slotToggleFormatToolbar() {
+    bool currentState = CBTConfig::get(CBTConfig::showFormatToolbarButtons);
+    CBTConfig::set(CBTConfig::showFormatToolbarButtons, !currentState);
+    showOrHideToolBars();
+    if (CBTConfig::get(CBTConfig::showToolbarsInEachWindow))
+        emit toggledTextWindowFormatToolbar(!currentState);
+    else
+        emit toggledTextWindowFormatToolbar(false);
+}
+
+void BibleTime::slotToggleToolBarsInEachWindow() {
+    bool currentState = CBTConfig::get(CBTConfig::showToolbarsInEachWindow);
+    CBTConfig::set(CBTConfig::showToolbarsInEachWindow, !currentState);
+    showOrHideToolBars();
+
+    if (!currentState) {
+        emit toggledTextWindowNavigator(CBTConfig::get(CBTConfig::showTextWindowNavigator));
+        emit toggledTextWindowToolButtons(CBTConfig::get(CBTConfig::showTextWindowToolButtons));
+        emit toggledTextWindowModuleChooser(CBTConfig::get(CBTConfig::showTextWindowModuleSelectorButtons));
+        emit toggledTextWindowFormatToolbar(CBTConfig::get(CBTConfig::showFormatToolbarButtons));
+    }
+    else {
+        emit toggledTextWindowNavigator(false);
+        emit toggledTextWindowToolButtons(false);
+        emit toggledTextWindowModuleChooser(false);
+        emit toggledTextWindowFormatToolbar(false);
+    }
+
+
+}
+
+void BibleTime::showOrHideToolBars() {
+    if (CBTConfig::get(CBTConfig::showToolbarsInEachWindow)) {
+        m_navToolBar->setVisible(false);
+        m_worksToolBar->setVisible(false);
+        m_toolsToolBar->setVisible(false);
+        m_formatToolBar->setVisible(false);
+    }
+    else {
+        m_navToolBar->setVisible(CBTConfig::get(CBTConfig::showTextWindowNavigator));
+        m_worksToolBar->setVisible(CBTConfig::get(CBTConfig::showTextWindowModuleSelectorButtons));
+        m_toolsToolBar->setVisible(CBTConfig::get(CBTConfig::showTextWindowToolButtons));
+        m_formatToolBar->setVisible(CBTConfig::get(CBTConfig::showFormatToolbarButtons));
+    }
 }
 
 /** Sets the active window. */
@@ -298,7 +377,7 @@ void BibleTime::slotSetActiveSubWindow(QWidget* window) {
 
 void BibleTime::slotSearchModules() {
     //get the modules of the open windows
-    QList<CSwordModuleInfo*> modules;
+    QList<const CSwordModuleInfo*> modules;
 
     foreach(QMdiSubWindow* subWindow, m_mdi->subWindowList()) {
         if (CDisplayWindow* w = dynamic_cast<CDisplayWindow*>(subWindow->widget())) {
@@ -312,7 +391,7 @@ void BibleTime::slotSearchModules() {
  * Call CSearchDialog::openDialog with only the default bible module
  */
 void BibleTime::slotSearchDefaultBible() {
-    QList<CSwordModuleInfo*> module;
+    QList<const CSwordModuleInfo*> module;
     CSwordModuleInfo* bible = CBTConfig::get(CBTConfig::standardBible);
     if (bible) {
         module.append(bible);
@@ -335,6 +414,11 @@ void BibleTime::slotOpenAboutDialog() {
     dlg->show();
 }
 
+void BibleTime::slotOpenTipDialog() {
+    BtTipDialog* dlg = new BtTipDialog(this);
+    dlg->show();
+}
+
 /** Saves the current settings into the currently activated profile. */
 void BibleTime::saveProfile(QAction* action) {
     m_mdi->setUpdatesEnabled(false);
@@ -405,7 +489,7 @@ void BibleTime::loadProfile(CProfile* p) {
 
         QList<CSwordModuleInfo*> modules;
         for ( QStringList::Iterator it = usedModules.begin(); it != usedModules.end(); ++it ) {
-            if (CSwordModuleInfo* m = CPointers::backend()->findModuleByName(*it)) {
+            if (CSwordModuleInfo* m = CSwordBackend::instance()->findModuleByName(*it)) {
                 modules.append(m);
             }
         }
@@ -416,7 +500,7 @@ void BibleTime::loadProfile(CProfile* p) {
         //is w->isWriteWindow is false we create a write window, otherwise a read window
         CDisplayWindow* displayWindow = 0;
         if (w->writeWindowType() > 0) { //create a write window
-            displayWindow = createWriteDisplayWindow(modules.first(), key, CDisplayWindow::WriteWindowType(w->writeWindowType()) );
+            displayWindow = createWriteDisplayWindow(modules.first(), key, CWriteWindow::WriteWindowType(w->writeWindowType()) );
         }
         else { //create a read window
             displayWindow = createReadDisplayWindow(modules, key);
@@ -449,7 +533,7 @@ void BibleTime::deleteProfile(QAction* action) {
 }
 
 void BibleTime::toggleFullscreen() {
-    if (m_windowFullscreen_action->isChecked()) {
+    if (m_windowFullscreenAction->isChecked()) {
         // set full screen mode
         m_WindowWasMaximizedBeforeFullScreen = isMaximized();
         showFullScreen();
