@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -20,8 +20,6 @@
 #include <QListWidgetItem>
 #include <QStackedWidget>
 #include <QVBoxLayout>
-#include "util/directory.h"
-#include "util/tool.h"
 
 
 BtConfigDialog::BtConfigDialog(QWidget* parent)
@@ -44,14 +42,6 @@ BtConfigDialog::BtConfigDialog(QWidget* parent)
 
     m_pageLayout->addWidget(m_pageWidget);
 
-    // Horizontal line
-    QFrame* line = new QFrame();
-    line->setGeometry(QRect(1, 1, 1, 3));
-    line->setFrameShape(QFrame::HLine);
-    line->setFrameShadow(QFrame::Sunken);
-    line->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
-    m_pageLayout->addWidget(line);
-
     connect(m_contentsList,
             SIGNAL(currentRowChanged(int)),
             this, SLOT(slotChangePage(int))
@@ -62,22 +52,14 @@ BtConfigDialog::BtConfigDialog(QWidget* parent)
 BtConfigDialog::~BtConfigDialog() {}
 
 void BtConfigDialog::addPage(BtConfigPage* pageWidget) {
-    namespace DU = util::directory;
-
     // this is a friend
     pageWidget->m_parentDialog = this;
 
-    QVBoxLayout* containerLayout = new QVBoxLayout;
-    QLabel* headerLabel = util::tool::explanationLabel(pageWidget, pageWidget->header(), pageWidget->label());
-    containerLayout->addWidget(headerLabel);
-    containerLayout->addWidget(pageWidget);
-    QWidget* containerWidget = new QWidget(m_pageWidget);
-    containerWidget->setLayout(containerLayout);
-    m_pageWidget->addWidget(containerWidget);
+    m_pageWidget->addWidget(pageWidget);
 
 
     QListWidgetItem* item = new QListWidgetItem(m_contentsList);
-    item->setIcon(DU::getIcon(pageWidget->iconName()));
+    item->setIcon(pageWidget->icon());
     item->setText(pageWidget->header());
     item->setTextAlignment(Qt::AlignHCenter);
     item->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
@@ -96,11 +78,16 @@ void BtConfigDialog::addPage(BtConfigPage* pageWidget) {
 }
 
 void BtConfigDialog::addButtonBox(QDialogButtonBox* box) {
-    m_pageLayout->addWidget(box);
-}
+    // First add a horizontal ruler:
+    QFrame *line = new QFrame();
+    line->setGeometry(QRect(1, 1, 1, 3));
+    line->setFrameShape(QFrame::HLine);
+    line->setFrameShadow(QFrame::Sunken);
+    line->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
+    m_pageLayout->addWidget(line);
 
-BtConfigPage* BtConfigDialog::currentPage() {
-    return dynamic_cast<BtConfigPage*>(m_pageWidget->currentWidget());
+    // Add button box:
+    m_pageLayout->addWidget(box);
 }
 
 void BtConfigDialog::slotChangePage(int newIndex) {
@@ -113,6 +100,13 @@ void BtConfigDialog::slotChangePage(int newIndex) {
 
 
 
-BtConfigPage::BtConfigPage() {}
+BtConfigPage::BtConfigPage(QWidget *parent)
+    : QWidget(parent)
+    , m_parentDialog(0)
+{
+    setLayout(new QVBoxLayout);
+}
 
-BtConfigPage::~BtConfigPage() {}
+BtConfigPage::~BtConfigPage() {
+    // Intentionally empty
+}
