@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -10,7 +10,7 @@
 #include "frontend/bookshelfmanager/btinstallmgr.h"
 
 #include "backend/managers/cswordbackend.h"
-#include "frontend/bookshelfmanager/instbackend.h"
+#include "backend/btinstallbackend.h"
 #include <QDebug>
 #include <QList>
 #include <QObject>
@@ -25,8 +25,9 @@
 using namespace sword;
 
 BtInstallMgr::BtInstallMgr()
-        : InstallMgr(instbackend::configPath().toLatin1(), this),
-        m_firstCallOfPreStatus(true) { //use this class also as status reporter
+        : InstallMgr(BtInstallBackend::configPath().toLatin1(), this),
+        m_totalBytes(1), m_completedBytes(0), m_firstCallOfPreStatus(true)
+{ //use this class also as status reporter
     qDebug() << "BtInstallMgr::BtInstallMgr";
     this->setFTPPassive(true);
 }
