@@ -2,21 +2,18 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
 
 #include "frontend/bookshelfmanager/btmodulemanagerdialog.h"
 
-#include <QDialogButtonBox>
 #include "backend/config/cbtconfig.h"
 #include "backend/managers/cswordbackend.h"
 #include "frontend/bookshelfmanager/indexpage/btindexpage.h"
 #include "frontend/bookshelfmanager/installpage/btinstallpage.h"
 #include "frontend/bookshelfmanager/removepage/btremovepage.h"
-#include "util/cpointers.h"
-#include "util/dialogutil.h"
 
 
 static BtModuleManagerDialog *m_staticModuleManagerDialog = 0;
@@ -48,13 +45,6 @@ BtModuleManagerDialog::BtModuleManagerDialog(QWidget* parent)
 
     slotChangePage(0);
 
-    // Dialog button (Close)
-    QDialogButtonBox* bbox = new QDialogButtonBox(this);
-    bbox->addButton(QDialogButtonBox::Close);
-    util::prepareDialogBox(bbox);
-    addButtonBox(bbox);
-    connect(bbox, SIGNAL(rejected()), SLOT(close()));
-
     loadDialogSettings();
 }
 
