@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -26,20 +26,14 @@ class BtIndexPage : public BtConfigPage {
         Q_OBJECT
 
     public:
-        /**
-        * Constructor
-        */
-        BtIndexPage();
-
-        /**
-        * Destructor
-        */
+        BtIndexPage(QWidget *parent = 0);
         ~BtIndexPage();
 
-        // BtConfigPage methods
-        QString header();
-        QString iconName();
-        QString label();
+        /** Reimplemented from BtConfigPage. */
+        virtual QString header() const;
+
+        /** Reimplemented from BtConfigPage. */
+        virtual const QIcon &icon() const;
 
     public slots:
         void slotSwordSetupChanged();
@@ -63,13 +57,6 @@ class BtIndexPage : public BtConfigPage {
         */
         void deleteIndices();
 
-    public:
-        /**
-        * Deletes orphaned indices if the autoDeleteOrphanedIndices is true
-        * Always deletes indices of existing modules where hasIndex() returns false
-        */
-        static void deleteOrphanedIndices();
-
     private:
 
         QCheckBox *m_autoDeleteOrphanedIndicesBox;
