@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -15,13 +15,12 @@
 #include <QDir>
 #include <QFileDialog>
 #include <QGridLayout>
-#include <QHeaderView>
 #include <QLabel>
 #include <QPushButton>
 #include <QString>
 #include <QTreeWidget>
 #include <QTreeWidgetItem>
-#include "frontend/bookshelfmanager/instbackend.h"
+#include "backend/btinstallbackend.h"
 #include "util/dialogutil.h"
 #include "util/directory.h"
 #include "util/cresmgr.h"
@@ -47,7 +46,7 @@ BtInstallPathDialog::BtInstallPathDialog() {
                         tr("Configure bookshelf folders"), l1 + QString("<small><br/><br/>") + l2 + QString("</small>"));
     mainLayout->addWidget(mainLabel);
 
-    QString swordConfPath = instbackend::swordConfigFilename();
+    QString swordConfPath = BtInstallBackend::swordConfigFilename();
     /// \todo After releasing 2.4, change the following line to: QLabel *confPathLabel = new QLabel(tr("Configuration file for the folders is: <b>%1</b>").arg(swordConfPath), this);
     QLabel* confPathLabel = new QLabel(tr("Configuration file for the folders is: ").append("<b>%1</b>").arg(swordConfPath), this);
     confPathLabel->setWordWrap(true);
@@ -55,7 +54,7 @@ BtInstallPathDialog::BtInstallPathDialog() {
 
 
     m_swordPathListBox = new QTreeWidget(this);
-    m_swordPathListBox->header()->hide();
+    m_swordPathListBox->setHeaderHidden(true);
 
     QString rwfolderitem(tr("Folders where new works can be installed"));
     m_writableItem = new QTreeWidgetItem(m_swordPathListBox, QStringList(rwfolderitem));;
@@ -65,7 +64,7 @@ BtInstallPathDialog::BtInstallPathDialog() {
     m_nonexistingItem = new QTreeWidgetItem(m_swordPathListBox, QStringList(tr("Nonexistent folders")));;
     m_nonexistingItem->setFlags(Qt::ItemIsEnabled);
 
-    QStringList targets = instbackend::targetList();
+    QStringList targets = BtInstallBackend::targetList();
 
     foreach (QString pathname, targets)  {
         addPathToList(pathname);
@@ -76,19 +75,19 @@ BtInstallPathDialog::BtInstallPathDialog() {
 
     QVBoxLayout* buttonLayout = new QVBoxLayout();
 
-    m_addButton = new QPushButton(tr("Add..."), this);
+    m_addButton = new QPushButton(tr("&Add..."), this);
     m_addButton->setToolTip(tr("Add new folder"));
     m_addButton->setIcon(DU::getIcon(CResMgr::bookshelfmgr::paths::add_icon));
     connect(m_addButton, SIGNAL(clicked()), this, SLOT(slotAddClicked()));
     buttonLayout->addWidget(m_addButton);
 
-    m_editButton = new QPushButton(tr("Edit..."), this);
+    m_editButton = new QPushButton(tr("&Edit..."), this);
     m_editButton->setToolTip(tr("Edit the selected folder"));
     m_editButton->setIcon(DU::getIcon(CResMgr::bookshelfmgr::paths::edit_icon));
     connect(m_editButton, SIGNAL(clicked()), this, SLOT(slotEditClicked()));
     buttonLayout->addWidget(m_editButton);
 
-    m_removeButton = new QPushButton(tr("Remove"), this);
+    m_removeButton = new QPushButton(tr("&Remove"), this);
     m_removeButton->setToolTip(tr("Remove the selected folder"));
     m_removeButton->setIcon(DU::getIcon(CResMgr::bookshelfmgr::paths::remove_icon));
     connect(m_removeButton, SIGNAL(clicked()), this, SLOT(slotRemoveClicked()));
@@ -162,7 +161,7 @@ void BtInstallPathDialog::addPathToList(QString pathname) {
             i = new QTreeWidgetItem(m_readableItem, QStringList(pathname) );
         }
     }
-    if (i && QDir(pathname) == instbackend::swordDir()) {
+    if (i && QDir(pathname) == BtInstallBackend::swordDir()) {
         i->setFlags(Qt::NoItemFlags);
         i->setToolTip(0, tr("This default folder in your home directory can't be removed"));
     }
@@ -231,7 +230,7 @@ void BtInstallPathDialog::writeSwordConfig() {
         ++it;
     }
     qDebug() << "save the target list" << targets;
-    instbackend::setTargetList(targets); //creates new Sword config
+    BtInstallBackend::setTargetList(targets); //creates new Sword config
 }
 
 void BtInstallPathDialog::accept() {
