@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -22,11 +22,13 @@
 #include <QVBoxLayout>
 #include "backend/managers/cswordbackend.h"
 #include "frontend/bookshelfmanager/installpage/btinstallthread.h"
-#include "util/cpointers.h"
 
 
-BtInstallProgressDialog::BtInstallProgressDialog(QWidget* parent, QTreeWidget* selectedModulesTreeWidget, QString destination)
-        : QDialog(parent) {
+BtInstallProgressDialog::BtInstallProgressDialog(
+        const QSet<const CSwordModuleInfo*> &modules,
+        const QString &destination, QWidget *parent, Qt::WindowFlags flags)
+        : QDialog(parent, flags)
+{
     // we want this dialog to be deleted when user closes it or the downloads are completed
     setAttribute(Qt::WA_DeleteOnClose, true);
     setWindowTitle(tr("Install Progress"));
@@ -39,39 +41,34 @@ BtInstallProgressDialog::BtInstallProgressDialog(QWidget* parent, QTreeWidget* s
     m_statusWidget->header()->setMovable(false);
     //m_statusWidget->setColumnWidth(1, util::tool::mWidth(m_statusWidget, 2));
 
-    foreach (QTreeWidgetItem* sourceItem, selectedModulesTreeWidget->invisibleRootItem()->takeChildren()) {
-        // create items and threads for modules under this source
-        foreach (QTreeWidgetItem* moduleItem, sourceItem->takeChildren()) {
-            if (moduleItem->checkState(0) == Qt::Checked) {
-                // create a thread for this module
-                BtInstallThread* thread = new BtInstallThread(this, moduleItem->text(0), sourceItem->text(0), destination);
-                m_waitingThreads.insert(sourceItem->text(0), thread);
-                m_threadsByModule.insert(moduleItem->text(0), thread);
-                // progress widget/item
-                QPushButton* stopButton = new QPushButton(tr("Stop"), m_statusWidget);
-                stopButton->setFixedSize(stopButton->sizeHint());
+    Q_FOREACH(const CSwordModuleInfo *module, modules) {
+        const QString sourceName(module->property("installSourceName").toString());
+        // create a thread for this module
+        BtInstallThread* thread = new BtInstallThread(module->name(), sourceName, destination);
+        m_waitingThreads.insert(sourceName, thread);
+        m_threadsByModule.insert(module->name(), thread);
+        // progress widget/item
+        QPushButton* stopButton = new QPushButton(tr("Stop"), m_statusWidget);
+        stopButton->setFixedSize(stopButton->sizeHint());
 
-                // the item
-                QTreeWidgetItem* progressItem = new QTreeWidgetItem(m_statusWidget);
-                m_statusWidget->setColumnWidth(2, stopButton->sizeHint().width());
-                progressItem->setSizeHint(2, stopButton->sizeHint());
-                progressItem->setText(0, moduleItem->text(0));
-                progressItem->setFlags(Qt::ItemIsEnabled);
-                m_statusWidget->setItemWidget(progressItem, 2, stopButton);
-                progressItem->setText(1, tr("Waiting for turn..."));
+        // the item
+        QTreeWidgetItem* progressItem = new QTreeWidgetItem(m_statusWidget);
+        m_statusWidget->setColumnWidth(2, stopButton->sizeHint().width());
+        progressItem->setSizeHint(2, stopButton->sizeHint());
+        progressItem->setText(0, module->name());
+        progressItem->setFlags(Qt::ItemIsEnabled);
+        m_statusWidget->setItemWidget(progressItem, 2, stopButton);
+        progressItem->setText(1, tr("Waiting for turn..."));
 
-                //connect the signals between the dialog, items and threads
-                QObject::connect(stopButton, SIGNAL(clicked()), thread, SLOT(slotStopInstall()), Qt::QueuedConnection);
-                QObject::connect(thread, SIGNAL(installStopped(QString, QString)), this, SLOT(slotOneItemStopped(QString, QString)), Qt::QueuedConnection);
-                //is this needed or is statusUpdated enough?
-                QObject::connect(thread, SIGNAL(installCompleted(QString, QString, int)), this, SLOT(slotOneItemCompleted(QString, QString, int)), Qt::QueuedConnection);
-                QObject::connect(thread, SIGNAL(statusUpdated(QString, int)), this, SLOT(slotStatusUpdated(QString, int)), Qt::QueuedConnection);
-                QObject::connect(thread, SIGNAL(downloadStarted(QString)), this, SLOT(slotDownloadStarted(QString)), Qt::QueuedConnection);
+        //connect the signals between the dialog, items and threads
+        QObject::connect(stopButton, SIGNAL(clicked()), thread, SLOT(slotStopInstall()), Qt::QueuedConnection);
+        QObject::connect(thread, SIGNAL(installStopped(QString, QString)), this, SLOT(slotOneItemStopped(QString, QString)), Qt::QueuedConnection);
+        //is this needed or is statusUpdated enough?
+        QObject::connect(thread, SIGNAL(installCompleted(QString, QString, int)), this, SLOT(slotOneItemCompleted(QString, QString, int)), Qt::QueuedConnection);
+        QObject::connect(thread, SIGNAL(statusUpdated(QString, int)), this, SLOT(slotStatusUpdated(QString, int)), Qt::QueuedConnection);
+        QObject::connect(thread, SIGNAL(downloadStarted(QString)), this, SLOT(slotDownloadStarted(QString)), Qt::QueuedConnection);
 
-                QObject::connect(thread, SIGNAL(preparingInstall(QString, QString)), this, SLOT(slotInstallStarted(QString, QString)), Qt::QueuedConnection);
-
-            }
-        }
+        QObject::connect(thread, SIGNAL(preparingInstall(QString, QString)), this, SLOT(slotInstallStarted(QString, QString)), Qt::QueuedConnection);
     }
 
     m_statusWidget->setMinimumWidth(m_statusWidget->size().width());
@@ -93,22 +90,22 @@ void BtInstallProgressDialog::startThreads() {
     // remove all the updated modules from the backend module list at once
     //foreach (QString mName, m_threadsByModule.keys()) {
     //}
-    //QList<CSwordModuleInfo*> CPointers::backend()->takeModulesFromList(m_threadsByModule.keys());
+    //QList<CSwordModuleInfo*> CSwordBackend::instance()()->takeModulesFromList(m_threadsByModule.keys());
     qDebug() << "start threads...";
     //loop through the multimap of the waiting threads, start at most 3 threads for each source
     QMultiMap<QString, BtInstallThread*>::iterator threadIterator = m_waitingThreads.end();
 // concurrency is disabled for now
-// 	while (threadIterator != m_waitingThreads.end()) {
-// 		QString sourceName = threadIterator.key();
-// 		qDebug() << sourceName;
-// 		if (m_runningThreads.values(sourceName).count() < 3) {
-// 			BtInstallThread* t = threadIterator.value();
-// 			m_runningThreads.insert(sourceName, t);
-// 			threadIterator = m_waitingThreads.erase(threadIterator);
-// 			t->start();
-// 		}
-// 		else ++threadIterator;
-// 	}
+//     while (threadIterator != m_waitingThreads.end()) {
+//         QString sourceName = threadIterator.key();
+//         qDebug() << sourceName;
+//         if (m_runningThreads.values(sourceName).count() < 3) {
+//             BtInstallThread* t = threadIterator.value();
+//             m_runningThreads.insert(sourceName, t);
+//             threadIterator = m_waitingThreads.erase(threadIterator);
+//             t->start();
+//         }
+//         else ++threadIterator;
+//     }
     //non-concurrent
     if (threadIterator != m_waitingThreads.begin()) {
         // go to the last item which is actually the first in the visible list
@@ -157,16 +154,16 @@ void BtInstallProgressDialog::oneItemStoppedOrCompleted(QString module, QString
     m_waitingThreads.remove(source, m_threadsByModule.value(module));
 
 //concurrency is disabled for now
-// 	//start a waiting thread if there are any
-// 	QList<BtInstallThread*> threadsForSource = m_waitingThreads.values(source);
-// 	qDebug() << threadsForSource;
-// 	if (!threadsForSource.isEmpty()) {
-// 		qDebug() << "Threads are waiting for turn";
-// 		BtInstallThread* thread = threadsForSource.at(0);
-// 		m_waitingThreads.remove(source, thread);
-// 		m_runningThreads.insert(source, thread);
-// 		thread->start();
-// 	}
+//     //start a waiting thread if there are any
+//     QList<BtInstallThread*> threadsForSource = m_waitingThreads.values(source);
+//     qDebug() << threadsForSource;
+//     if (!threadsForSource.isEmpty()) {
+//         qDebug() << "Threads are waiting for turn";
+//         BtInstallThread* thread = threadsForSource.at(0);
+//         m_waitingThreads.remove(source, thread);
+//         m_runningThreads.insert(source, thread);
+//         thread->start();
+//     }
 
     //non-concurrent
     QMultiMap<QString, BtInstallThread*>::iterator threadIterator = m_waitingThreads.end();
@@ -238,7 +235,7 @@ void BtInstallProgressDialog::closeEvent(QCloseEvent* event) {
         return;
     }
     // other parts of the UI/engine must be updated
-    CPointers::backend()->reloadModules(CSwordBackend::AddedModules);
+    CSwordBackend::instance()->reloadModules(CSwordBackend::AddedModules);
 }
 
 bool BtInstallProgressDialog::threadsDone() {
