@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -17,13 +17,16 @@
 
 
 class BtInstallThread;
+class CSwordModuleInfo;
 class QTreeWidget;
 class QTreeWidgetItem;
 
 class BtInstallProgressDialog : public QDialog {
         Q_OBJECT
     public:
-        BtInstallProgressDialog(QWidget* parent, QTreeWidget* selectedModulesTreeWidget, QString destination);
+        BtInstallProgressDialog(const QSet<const CSwordModuleInfo*> &modules,
+                                const QString &destination, QWidget *parent = 0,
+                                Qt::WindowFlags flags = 0);
 
         ~BtInstallProgressDialog();
 
@@ -43,7 +46,7 @@ class BtInstallProgressDialog : public QDialog {
         virtual void closeEvent(QCloseEvent* event);
 
 //signals:
-//	void swordSetupChanged();
+//    void swordSetupChanged();
 
     private:
 
