@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -16,14 +16,14 @@
 #include <QThread>
 #include "backend/managers/cswordbackend.h"
 #include "frontend/bookshelfmanager/btinstallmgr.h"
-#include "frontend/bookshelfmanager/instbackend.h"
-#include "util/cpointers.h"
+#include "backend/btinstallbackend.h"
 
 // Sword includes:
 #include <filemgr.h>
 
 
-BtInstallThread::BtInstallThread(QObject* parent, QString moduleName, QString sourceName, QString destinationName)
+BtInstallThread::BtInstallThread(const QString &moduleName, const QString &sourceName,
+                                 const QString &destinationName, QObject *parent)
         : QThread(parent),
         done(false),
         m_module(moduleName),
@@ -45,8 +45,8 @@ void BtInstallThread::run() {
     emit preparingInstall(m_module, m_source);
     //This is 0 before set here - remember when using the value when cancelling
     // the installation before this has been run
-    m_installSource.reset(new sword::InstallSource(instbackend::source(m_source)));
-    m_backendForSource.reset(instbackend::backend(*m_installSource));
+    m_installSource = QSharedPointer<sword::InstallSource>(new sword::InstallSource(BtInstallBackend::source(m_source)));
+    m_backendForSource = QSharedPointer<CSwordBackend>(BtInstallBackend::backend(*m_installSource));
 
     //make sure target/mods.d and target/modules exist
     /// \todo move this to some common precondition
@@ -74,9 +74,9 @@ void BtInstallThread::run() {
     // manager for the destination path
     sword::SWMgr lMgr( m_destination.toLatin1() );
 
-    if (instbackend::isRemote(*m_installSource)) {
+    if (BtInstallBackend::isRemote(*m_installSource)) {
         qDebug() << "calling install";
-        int status = m_iMgr->installModule(&lMgr, 0, m_module.toLatin1(), m_installSource.get());
+        int status = m_iMgr->installModule(&lMgr, 0, m_module.toLatin1(), m_installSource.data());
         if (status != 0) {
             qWarning() << "Error with install: " << status << "module:" << m_module;
         }
@@ -123,7 +123,7 @@ void BtInstallThread::slotStopInstall() {
         qDebug() << "BtInstallThread::slotStopInstall 3";
         // cleanup: remove the module, remove the temp files
         // if installation has already started
-        if (m_installSource.get() != 0) {
+        if (m_installSource.data() != 0) {
             qDebug() << "BtInstallThread::slotStopInstall 4";
             // remove the installed module, just to be sure because mgr may
             // have been terminated when copying files
@@ -148,9 +148,9 @@ void BtInstallThread::slotDownloadStarted() {
 void BtInstallThread::removeModule() {
     qDebug() << "BtInstallThread::removeModule start";
     CSwordModuleInfo* m;
-    m = CPointers::backend()->findModuleByName(m_module);
+    m = CSwordBackend::instance()->findModuleByName(m_module);
     if (!m) {
-        m = instbackend::backend(instbackend::source(m_destination.toLatin1()))->findModuleByName(m_module);
+        m = BtInstallBackend::backend(BtInstallBackend::source(m_destination.toLatin1()))->findModuleByName(m_module);
     }
     if (m) { //module found?
         qDebug() << "BtInstallThread::removeModule, module" << m_module << "found";
@@ -164,7 +164,7 @@ void BtInstallThread::removeModule() {
             prefixPath.remove( prefixPath.indexOf(dataPath), dataPath.length() );
         }
         else {
-            prefixPath = QString::fromLatin1(CPointers::backend()->prefixPath);
+            prefixPath = QString::fromLatin1(CSwordBackend::instance()->prefixPath);
         }
 
         sword::SWMgr mgr(prefixPath.toLatin1());
@@ -182,8 +182,8 @@ void BtInstallThread::removeTempFiles() {
     // (take the remote conf file for this module, take DataPath,
     // take the absolute path of the InstallMgr)
 
-    //sword::InstallSource is = instbackend::source(m_source);
-    if (instbackend::isRemote(*m_installSource)) {
+    //sword::InstallSource is = BtInstallBackend::source(m_source);
+    if (BtInstallBackend::isRemote(*m_installSource)) {
         // get the path for the module temp files
         CSwordModuleInfo* mInfo = m_backendForSource->findModuleByName(m_module);
         QString dataPath = mInfo->config(CSwordModuleInfo::AbsoluteDataPath);
