@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 2007 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -44,6 +44,9 @@ const BookmarkItem& BTMimeData::bookmark() const {
     return m_bookmarkList.first();
 }
 
-/** Creates a new bookmark item. */
-BookmarkItem::BookmarkItem(QString module, QString key, QString description)
-        : m_moduleName(module), m_key(key), m_description(description) {}
+BookmarkItem::BookmarkItem(const QString &module, const QString &key,
+                           const QString &description)
+        : m_moduleName(module), m_key(key), m_description(description)
+{
+    // Intentionally empty
+}
