@@ -2,14 +2,14 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
 
 #include "frontend/cinfodisplay.h"
 
-#include <boost/scoped_ptr.hpp>
+#include <QSharedPointer>
 #include <QAction>
 #include <QDebug>
 #include <QLabel>
@@ -18,6 +18,7 @@
 #include <QSize>
 #include <QVBoxLayout>
 #include <QtAlgorithms>
+#include <QMenu>
 
 #include "backend/config/cbtconfig.h"
 #include "backend/drivers/cswordmoduleinfo.h"
@@ -47,9 +48,18 @@ CInfoDisplay::CInfoDisplay(QWidget *parent) : QWidget(parent) {
     m_htmlPart->setMouseTracking(false); //we don't want strong/lemma/note mouse infos
     m_htmlPart->view()->setAcceptDrops(false);
 
-    m_copyAction = new QAction(tr("Copy"), this);
-    m_copyAction->setShortcut( QKeySequence(Qt::CTRL + Qt::Key_C) );
-    QObject::connect(m_copyAction, SIGNAL(triggered()), m_htmlPart->connectionsProxy(), SLOT(copySelection()) );
+    QAction* selectAllAction = new QAction(QIcon(), tr("Select all"), this);
+    selectAllAction->setShortcut(QKeySequence::SelectAll);
+    QObject::connect(selectAllAction, SIGNAL(triggered()), this, SLOT(selectAll()) );
+
+    QAction* copyAction = new QAction(tr("Copy"), this);
+    copyAction->setShortcut( QKeySequence(Qt::CTRL + Qt::Key_C) );
+    QObject::connect(copyAction, SIGNAL(triggered()), m_htmlPart->connectionsProxy(), SLOT(copySelection()) );
+
+    QMenu* menu = new QMenu();
+    menu->addAction(selectAllAction);
+    menu->addAction(copyAction);
+    m_htmlPart->installPopup(menu);
 
     connect(
         m_htmlPart->connectionsProxy(),
@@ -59,7 +69,7 @@ CInfoDisplay::CInfoDisplay(QWidget *parent) : QWidget(parent) {
 
     layout->addWidget(m_htmlPart->view());
 
-    CDisplayTemplateMgr *mgr(CPointers::displayTemplateManager());
+    CDisplayTemplateMgr *mgr = CDisplayTemplateMgr::instance();
     CDisplayTemplateMgr::Settings settings;
     settings.pageCSS_ID = "infodisplay";
     QString divText("<div class=\"infodisplay\">%1</div>");
@@ -78,20 +88,19 @@ CInfoDisplay::CInfoDisplay(QWidget *parent) : QWidget(parent) {
 
 
 CInfoDisplay::~CInfoDisplay() {
-    delete m_copyAction;
 }
 
 void CInfoDisplay::lookupInfo(const QString &mod_name, const QString &key_text) {
     qDebug() << "CInfoDisplay::lookup";
     qDebug() <<  mod_name <<  key_text;
-    CSwordModuleInfo* m = CPointers::backend()->findModuleByName(mod_name);
+    CSwordModuleInfo* m = CSwordBackend::instance()->findModuleByName(mod_name);
     Q_ASSERT(m);
     if (!m)
         return;
-    boost::scoped_ptr<CSwordKey> key( CSwordKey::createInstance(m) );
-    key->key( key_text );
+    QSharedPointer<CSwordKey> key( CSwordKey::createInstance(m) );
+    key->setKey(key_text);
 
-    CDisplayTemplateMgr* mgr = CPointers::displayTemplateManager();
+    CDisplayTemplateMgr *mgr = CDisplayTemplateMgr::instance();
     CDisplayTemplateMgr::Settings settings;
     settings.pageCSS_ID = "infodisplay";
 
@@ -163,7 +172,7 @@ void CInfoDisplay::setInfo(const ListInfoData& list) {
         };
     }
 
-    CDisplayTemplateMgr* mgr = CPointers::displayTemplateManager();
+    CDisplayTemplateMgr *mgr = CDisplayTemplateMgr::instance();
     CDisplayTemplateMgr::Settings settings;
     settings.pageCSS_ID = "infodisplay";
     //  settings.langAbbrev = "";
@@ -175,6 +184,9 @@ void CInfoDisplay::setInfo(const ListInfoData& list) {
     m_htmlPart->setText(content);
 }
 
+void CInfoDisplay::selectAll() {
+    m_htmlPart->selectAll();
+}
 
 const QString CInfoDisplay::decodeAbbreviation( const QString& data ) {
     //  QStringList strongs = QStringList::split("|", data);
@@ -199,11 +211,11 @@ const QString CInfoDisplay::decodeCrossReference( const QString& data ) {
 
     //  qWarning("setting crossref %s", data.latin1());
 
-    CSwordBackend::DisplayOptions dispOpts;
+    DisplayOptions dispOpts;
     dispOpts.lineBreaks  = false;
     dispOpts.verseNumbers = true;
 
-    CSwordBackend::FilterOptions filterOpts;
+    FilterOptions filterOpts;
     filterOpts.headings    = false;
     filterOpts.strongNumbers  = false;
     filterOpts.morphTags    = false;
@@ -228,7 +240,7 @@ const QString CInfoDisplay::decodeCrossReference( const QString& data ) {
     if (pos > 0) {
         const QString moduleName = data.left(pos);
         //     qWarning("found module %s", moduleName.latin1());
-        module = CPointers::backend()->findModuleByName(moduleName);
+        module = CSwordBackend::instance()->findModuleByName(moduleName);
         if (!module) {
             module = CBTConfig::get(CBTConfig::standardBible);
         }
@@ -300,8 +312,8 @@ const QString CInfoDisplay::decodeCrossReference( const QString& data ) {
 }
 
 /*!
-	\fn CInfoDisplay::decodeFootnote( const QString& data )
-	*/
+    \fn CInfoDisplay::decodeFootnote( const QString& data )
+    */
 const QString CInfoDisplay::decodeFootnote( const QString& data ) {
     QStringList list = data.split("/");
     Q_ASSERT(list.count() >= 3);
@@ -309,7 +321,7 @@ const QString CInfoDisplay::decodeFootnote( const QString& data ) {
         return QString::null;
     }
 
-    CSwordBackend::FilterOptions filterOpts;
+    FilterOptions filterOpts;
     filterOpts.headings    = false;
     filterOpts.strongNumbers  = false;
     filterOpts.morphTags    = false;
@@ -318,7 +330,7 @@ const QString CInfoDisplay::decodeFootnote( const QString& data ) {
     // turn scripRefs off, so that they do not show up as footnotes in the OSIS filter's EntryAttributes
     filterOpts.scriptureReferences = false;
 
-    CPointers::backend()->setFilterOptions(filterOpts);
+    CSwordBackend::instance()->setFilterOptions(filterOpts);
 
     const QString modulename = list.first();
     const QString swordFootnote = list.last();
@@ -328,13 +340,13 @@ const QString CInfoDisplay::decodeFootnote( const QString& data ) {
     list.pop_front();
     const QString keyname = list.join("/");
 
-    CSwordModuleInfo* module = CPointers::backend()->findModuleByName(modulename);
+    CSwordModuleInfo* module = CSwordBackend::instance()->findModuleByName(modulename);
     if (!module) {
         return QString::null;
     }
 
-    boost::scoped_ptr<CSwordKey> key( CSwordKey::createInstance(module) );
-    key->key(keyname);
+    QSharedPointer<CSwordKey> key( CSwordKey::createInstance(module) );
+    key->setKey(keyname);
     key->renderedText(CSwordKey::ProcessEntryAttributesOnly); //force entryAttributes
 
     const char* note =
@@ -369,8 +381,8 @@ const QString CInfoDisplay::decodeStrongs( const QString& data ) {
 
         QString text;
         if (module) {
-            boost::scoped_ptr<CSwordKey> key( CSwordKey::createInstance(module) );
-            key->key( (*it).mid(1) ); //skip H or G (language sign), will have to change later if we have better modules
+            QSharedPointer<CSwordKey> key( CSwordKey::createInstance(module) );
+            key->setKey((*it).mid(1)); // skip H or G (language sign), will have to change later if we have better modules
             text = key->renderedText();
         }
         //if the module could not be found just display an empty lemma info
@@ -405,7 +417,7 @@ const QString CInfoDisplay::decodeMorph( const QString& data ) {
         if (valStart > -1) {
             valueClass = morph.mid(0, valStart);
             //qDebug() << "valueClass: " << valueClass;
-            module = CPointers::backend()->findModuleByName( valueClass );
+            module = CSwordBackend::instance()->findModuleByName( valueClass );
         }
         value = morph.mid(valStart + 1); //works for prepended module and without (-1 +1 == 0).
 
@@ -443,15 +455,15 @@ const QString CInfoDisplay::decodeMorph( const QString& data ) {
         QString text;
         //Q_ASSERT(module);
         if (module) {
-            boost::scoped_ptr<CSwordKey> key( CSwordKey::createInstance(module) );
+            QSharedPointer<CSwordKey> key( CSwordKey::createInstance(module) );
 
             //skip H or G (language sign) if we have to skip it
-            const bool isOk = key->key( skipFirstChar ? value.mid(1) : value );
+            const bool isOk = key->setKey(skipFirstChar ? value.mid(1) : value);
             //Q_ASSERT(isOk);
             if (!isOk) { //try to use the other morph lexicon, because this one failed with the current morph code
-                key->module(CBTConfig::get
-                            (CBTConfig::standardHebrewMorphLexicon));
-                key->key( skipFirstChar ? value.mid(1) : value );
+                key->setModule(CBTConfig::get
+                               (CBTConfig::standardHebrewMorphLexicon));
+                key->setKey(skipFirstChar ? value.mid(1) : value);
             }
 
             text = key->renderedText();
@@ -479,8 +491,8 @@ const QString CInfoDisplay::getWordTranslation( const QString& data ) {
         return QString::null;
     }
 
-    boost::scoped_ptr<CSwordKey> key( CSwordKey::createInstance(module) );
-    key->key( data );
+    QSharedPointer<CSwordKey> key( CSwordKey::createInstance(module) );
+    key->setKey(data);
     if (key->key().toUpper() != data.toUpper()) { //key not present in the lexicon
         return QString::null;
     }
@@ -494,12 +506,8 @@ const QString CInfoDisplay::getWordTranslation( const QString& data ) {
     return ret;
 }
 
-
-/*!
-	\fn CInfoDisplay::clearInfo()
-	*/
 void CInfoDisplay::clearInfo() {
-    CDisplayTemplateMgr* tmgr = CPointers::displayTemplateManager();
+    CDisplayTemplateMgr *tmgr = CDisplayTemplateMgr::instance();
     CDisplayTemplateMgr::Settings settings;
     settings.pageCSS_ID = "infodisplay";
 
