@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -58,10 +58,10 @@ class CInfoDisplay : public QWidget {
 
     protected slots:
         void lookupInfo(const QString &, const QString &);
+        void selectAll();
 
     private:
         CReadDisplay* m_htmlPart;
-        QAction* m_copyAction;
 };
 
 } //end of InfoDisplay namespace
