@@ -2,25 +2,39 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
 
 #include "bibletime.h"
 #include "frontend/cmdiarea.h"
+#include "frontend/displaywindow/btmodulechooserbar.h"
 
 #include <QEvent>
 #include <QMdiSubWindow>
 #include <QTimer>
+#include <QToolBar>
 #include <QWindowStateChangeEvent>
 #include <QMenu>
 
 
 CMDIArea::CMDIArea(BibleTime *parent)
-        : QMdiArea(parent), m_mdiArrangementMode(ArrangementModeManual) {
+        : QMdiArea(parent), m_mdiArrangementMode(ArrangementModeManual), m_activeWindow(0), m_bibleTime(parent) {
     Q_ASSERT(parent != 0);
 
+    #if QT_VERSION >= 0x040500
+    // Set document-style tabs (for Mac):
+    setDocumentMode(true);
+    #endif
+
+    /*
+      Activate windows based on the history of activation, e.g. when one has window A
+      activated, and activates window B and then closes window B, then window A is activated.
+    */
+    setActivationOrder(QMdiArea::ActivationHistoryOrder);
+
+    // Show scrollbars only when needed:
     setHorizontalScrollBarPolicy(Qt::ScrollBarAsNeeded);
     setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
 
@@ -30,21 +44,24 @@ CMDIArea::CMDIArea(BibleTime *parent)
 
 static const int moveSize = 30;
 
-QMdiSubWindow* CMDIArea::addSubWindow(QWidget * widget, Qt::WindowFlags windowFlags) {
-    QMdiSubWindow* subWindow = QMdiArea::addSubWindow(widget, windowFlags);
-    subWindow->installEventFilter(this);
-
-    // Change Qt QMdiSubWindow Close action to have no shortcut
+void CMDIArea::fixSystemMenu(QMdiSubWindow* subWindow) {
+    // Change Qt QMdiSubWindow Close action to have no shortcuts
     // This makes our closeWindow actions with Ctrl-W work correctly
     QList<QAction*> actions = subWindow->systemMenu()->actions();
     for (int i=0; i<actions.count(); i++) {
         QAction* action = actions.at(i);
         QString text = action->text();
         if (text.contains("Close")) {
-            action->setShortcut(QKeySequence());
+            action->setShortcuts(QList<QKeySequence>());
             break;
         }
     }
+}
+
+QMdiSubWindow* CMDIArea::addSubWindow(QWidget * widget, Qt::WindowFlags windowFlags) {
+    QMdiSubWindow* subWindow = QMdiArea::addSubWindow(widget, windowFlags);
+    subWindow->installEventFilter(this);
+    fixSystemMenu(subWindow);
 
     // Manual arrangement mode
     enableWindowMinMaxFlags(true);
@@ -84,13 +101,29 @@ QMdiSubWindow* CMDIArea::addSubWindow(QWidget * widget, Qt::WindowFlags windowFl
 
 void CMDIArea::setMDIArrangementMode( const MDIArrangementMode newArrangementMode ) {
     m_mdiArrangementMode = newArrangementMode;
-    triggerWindowUpdate();
+    switch (m_mdiArrangementMode) {
+        case ArrangementModeManual:
+            setViewMode(QMdiArea::SubWindowView);
+            break;
+        case ArrangementModeTile:
+            setViewMode(QMdiArea::SubWindowView);
+            tileSubWindows();
+            break;
+        case ArrangementModeTabbed:
+            setViewMode(QMdiArea::TabbedView);
+            break;
+        default:
+            setViewMode(QMdiArea::SubWindowView);
+            triggerWindowUpdate();
+            break;
+    }
 }
 
 void CMDIArea::myTileVertical() {
     if (!updatesEnabled() || !usableWindowList().count() ) {
         return;
     }
+    setViewMode(QMdiArea::SubWindowView);
 
     QList<QMdiSubWindow*> windows = usableWindowList();
     setUpdatesEnabled(false);
@@ -117,6 +150,7 @@ void CMDIArea::myTileHorizontal() {
     if (!updatesEnabled() || !usableWindowList().count() ) {
         return;
     }
+    setViewMode(QMdiArea::SubWindowView);
 
     QList<QMdiSubWindow*> windows = usableWindowList();
     setUpdatesEnabled(false);
@@ -138,10 +172,12 @@ void CMDIArea::myTileHorizontal() {
     emitWindowCaptionChanged();
 }
 
+// Tile the windows, tiling implemented by Qt
 void CMDIArea::myTile() {
     if (!updatesEnabled() || !usableWindowList().count() ) {
         return;
     }
+    setViewMode(QMdiArea::SubWindowView);
     tileSubWindows();
     emitWindowCaptionChanged();
 }
@@ -150,6 +186,7 @@ void CMDIArea::myCascade() {
     if (!updatesEnabled() || !usableWindowList().count() ) {
         return;
     }
+    setViewMode(QMdiArea::SubWindowView);
 
     QList<QMdiSubWindow*> windows = usableWindowList();
 
@@ -193,7 +230,7 @@ void CMDIArea::emitWindowCaptionChanged() {
         emit sigSetToplevelCaption(activeSubWindow()->windowTitle());
     }
     else {
-        emit sigSetToplevelCaption(QString());
+        emit sigSetToplevelCaption(QString::null);
     }
 }
 
@@ -211,22 +248,34 @@ QList<QMdiSubWindow*> CMDIArea::usableWindowList() {
 }
 
 void CMDIArea::slotSubWindowActivated(QMdiSubWindow* client) {
-    if (!client || !updatesEnabled()) {
+    if (subWindowList().count() == 0)
+        m_bibleTime->clearMdiToolBars();
+
+    if (!client) {
         return;
     }
     emit sigSetToplevelCaption( client->windowTitle().trimmed() );
+
+    // Notify child window it is active
+    CDisplayWindow* activeWindow = qobject_cast<CDisplayWindow*>(client->widget());
+    if (activeWindow != 0 && activeWindow != m_activeWindow) {
+        m_activeWindow = activeWindow;
+        activeWindow->windowActivated();
+    }
 }
 
 void CMDIArea::resizeEvent(QResizeEvent* e) {
     /*
-      Do not call QMdiArea::resizeEvent(e) unless we are in manual arrangement
-      mode, since this would mess up our layout. The manual arrangement mode
-      should be handled exactly as in QMdiArea.
+      Do not call QMdiArea::resizeEvent(e) if we are in manual arrangement
+      mode, since this would mess up our layout. Also, don't call it for the
+      automatic arrangement modes that we implement. Call it only for those
+      modes implemented by Qt
     */
-    if (m_mdiArrangementMode == ArrangementModeManual) {
+    if (m_mdiArrangementMode == ArrangementModeTabbed) {
         QMdiArea::resizeEvent(e);
     }
     else if (updatesEnabled()) {
+        // Handle resize for automatic modes that we implement
         triggerWindowUpdate();
     }
 }
@@ -236,7 +285,8 @@ bool CMDIArea::eventFilter(QObject *o, QEvent *e) {
     QMdiSubWindow *w(qobject_cast<QMdiSubWindow*>(o));
 
     // Let the event be handled by other filters:
-    if (w == 0) return QMdiArea::eventFilter(o, e);
+    if (w == 0)
+        return QMdiArea::eventFilter(o, e);
 
     switch (e->type()) {
         case QEvent::WindowStateChange: {
@@ -268,6 +318,7 @@ bool CMDIArea::eventFilter(QObject *o, QEvent *e) {
             if (o == activeSubWindow()) {
                 emit sigSetToplevelCaption(w->windowTitle());
             }
+            return QMdiArea::eventFilter(o, e);
             break;
         default:
             break;
@@ -285,12 +336,12 @@ void CMDIArea::triggerWindowUpdate() {
             case ArrangementModeTileHorizontal:
                 QTimer::singleShot(0, this, SLOT(myTileHorizontal()));
                 break;
-            case ArrangementModeCascade:
-                QTimer::singleShot(0, this, SLOT(myCascade()));
-                break;
             case ArrangementModeTile:
                 QTimer::singleShot(0, this, SLOT(myTile()));
                 break;
+            case ArrangementModeCascade:
+                QTimer::singleShot(0, this, SLOT(myCascade()));
+                break;
             default:
                 break;
         }
@@ -310,8 +361,6 @@ void CMDIArea::enableWindowMinMaxFlags(bool enable)
             flags &= ~Qt::WindowMaximizeButtonHint;
         }
         subWindow->setWindowFlags(flags);
-        subWindow->hide();
-        subWindow->show();
     }
 }
 
