@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -16,6 +16,7 @@
 
 class BibleTime;
 class CSwordModuleInfo;
+class CDisplayWindow;
 
 /**
   A custom MDI area widget.
@@ -33,7 +34,8 @@ class CMDIArea: public QMdiArea {
             ArrangementModeTileHorizontal = 2,
             ArrangementModeCascade = 3,
             ArrangementModeManual = 4,
-            ArrangementModeTile = 5
+            ArrangementModeTile = 5,
+            ArrangementModeTabbed = 6
         };
 
         /**
@@ -69,7 +71,7 @@ class CMDIArea: public QMdiArea {
         */
         QList<QMdiSubWindow*> usableWindowList();
 
-        /** 
+        /**
           Show or hide the sub-window min/max buttons.
         */
         void enableWindowMinMaxFlags(bool enable);
@@ -82,6 +84,7 @@ class CMDIArea: public QMdiArea {
                 arranging the subwindows into a tile automatically.
         */
         void myTile();
+
         /**
           Our own cascade version which, if only one subwindow is left, shows it
           maximized.
@@ -111,7 +114,7 @@ class CMDIArea: public QMdiArea {
 
     signals:
         /**
-        * Emits a signal to set the acption of the toplevel widget.
+        * Emits a signal to set the caption of the toplevel widget.
         */
         void sigSetToplevelCaption(const QString&);
 
@@ -129,6 +132,7 @@ class CMDIArea: public QMdiArea {
         bool eventFilter(QObject *o, QEvent *e);
 
         void emitWindowCaptionChanged();
+        void fixSystemMenu(QMdiSubWindow* subWindow);
 
     protected slots:
         /**
@@ -138,6 +142,10 @@ class CMDIArea: public QMdiArea {
 
     protected:
         MDIArrangementMode m_mdiArrangementMode;
+
+    private:
+        CDisplayWindow* m_activeWindow;
+        BibleTime* m_bibleTime;
 };
 
 #endif
