@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2009 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -15,15 +15,18 @@
 #include <QWebPage>
 #include "backend/keys/cswordversekey.h"
 #include "backend/managers/cdisplaytemplatemgr.h"
-#include "util/cpointers.h"
 
 
 namespace Printing {
 
-CPrinter::CPrinter(QObject*, CSwordBackend::DisplayOptions displayOptions, CSwordBackend::FilterOptions filterOptions)
-        :	QObject(0),
-        CDisplayRendering(displayOptions, filterOptions),
-        m_htmlPage(new QWebPage()) {
+/// \todo WHY IS parent NOT USED!?
+CPrinter::CPrinter(QObject *,
+                   const DisplayOptions &displayOptions,
+                   const FilterOptions &filterOptions)
+        : QObject(0),
+          CDisplayRendering(displayOptions, filterOptions),
+          m_htmlPage(new QWebPage())
+{
     m_htmlPage->setParent(this);
 
     //override the filteroptions set in the c-tor of CDisplayRendering
@@ -49,11 +52,13 @@ void CPrinter::printKeyTree( KeyTree& tree ) {
     }
 }
 
-const QString CPrinter::entryLink(const KeyTreeItem& item, CSwordModuleInfo* module) {
+const QString CPrinter::entryLink(const KeyTreeItem &item,
+                                  const CSwordModuleInfo *module)
+{
     Q_ASSERT(module);
     if (module->type() == CSwordModuleInfo::Bible) {
         CSwordVerseKey vk(module);
-        vk.key(item.key());
+        vk.setKey(item.key());
         switch (item.settings().keyRenderingFace) {
             case KeyTreeItem::Settings::CompleteShort:
                 return QString::fromUtf8(vk.getShortText());
@@ -94,7 +99,7 @@ const QString CPrinter::renderEntry( const KeyTreeItem& i, CSwordKey* ) {
 }
 
 const QString CPrinter::finishText(const QString& text, KeyTree& tree) {
-    QList<CSwordModuleInfo*> modules = collectModules(&tree);
+    QList<const CSwordModuleInfo*> modules = collectModules(&tree);
     Q_ASSERT(modules.count() > 0);
 
     const CLanguageMgr::Language* const lang = modules.first()->language();
@@ -114,7 +119,7 @@ const QString CPrinter::finishText(const QString& text, KeyTree& tree) {
         settings.pageDirection = ( modules.first()->textDirection() == CSwordModuleInfo::LeftToRight ) ? "ltr" : "rtl";
     }
 
-    CDisplayTemplateMgr* tMgr = CPointers::displayTemplateManager();
+    CDisplayTemplateMgr *tMgr = CDisplayTemplateMgr::instance();
     return tMgr->fillTemplate(CBTConfig::get(CBTConfig::displayStyle), text, settings);
 }
 
