@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2009 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -26,12 +26,17 @@ namespace Printing {
 class CPrinter : public QObject, public Rendering::CDisplayRendering {
         Q_OBJECT
     public:
-        CPrinter(QObject* parent, CSwordBackend::DisplayOptions displayOptions, CSwordBackend::FilterOptions filterOptions);
+        CPrinter(QObject *parent,
+                 const DisplayOptions &displayOptions,
+                 const FilterOptions &filterOptions);
+
         virtual ~CPrinter();
         void printKeyTree( KeyTree& );
 
     protected:
-        virtual const QString entryLink(const KeyTreeItem& item, CSwordModuleInfo* const module);
+        virtual const QString entryLink(const KeyTreeItem &item,
+                                        const CSwordModuleInfo *module);
+
         virtual const QString renderEntry( const KeyTreeItem&, CSwordKey* = 0 );
         virtual const QString finishText(const QString& arg1, KeyTree& tree);
 
