@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2009 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -16,23 +16,27 @@
 
 namespace InfoDisplay {
 
-CrossRefRendering::CrossRefRendering( CSwordBackend::DisplayOptions displayOptions,
-                                      CSwordBackend::FilterOptions filterOptions
-                                    )
-        : CHTMLExportRendering(Settings(), displayOptions, filterOptions) {}
+CrossRefRendering::CrossRefRendering(const DisplayOptions &displayOptions,
+                                     const FilterOptions &filterOptions)
+        : CHTMLExportRendering(Settings(), displayOptions, filterOptions)
+{
+    // Intentionally empty
+}
 
 const QString CrossRefRendering::finishText( const QString& text, KeyTree& ) {
     //   qDebug() << "CrossRefRendering::finishText";
     return text;
 }
 
-const QString CrossRefRendering::entryLink( const KeyTreeItem& item, CSwordModuleInfo*  module ) {
+const QString CrossRefRendering::entryLink(const KeyTreeItem &item,
+                                           const CSwordModuleInfo *module)
+{
     QString linkText;
 
     const bool isBible = module && (module->type() == CSwordModuleInfo::Bible);
     CSwordVerseKey vk(module); //only valid for bible modules, i.e. isBible == true
     if (isBible) {
-        vk.key(item.key());
+        vk.setKey(item.key());
     }
 
     switch (item.settings().keyRenderingFace) {
