@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -20,11 +20,13 @@ class CrossRefRendering : public Rendering::CHTMLExportRendering {
         friend class CInfoDisplay;
 
         CrossRefRendering(
-            CSwordBackend::DisplayOptions displayOptions = CBTConfig::getDisplayOptionDefaults(),
-            CSwordBackend::FilterOptions filterOptions = CBTConfig::getFilterOptionDefaults()
+            const DisplayOptions &displayOptions = CBTConfig::getDisplayOptionDefaults(),
+            const FilterOptions &filterOptions = CBTConfig::getFilterOptionDefaults()
         );
 
-        virtual const QString entryLink( const KeyTreeItem& item, CSwordModuleInfo* module );
+        virtual const QString entryLink(const KeyTreeItem &item,
+                                        const CSwordModuleInfo *module);
+
         virtual const QString finishText( const QString&, KeyTree& tree );
 };
 
