@@ -2,14 +2,14 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2009 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
 
 #include "frontend/display/bthtmlreaddisplay.h"
 
-#include <boost/scoped_ptr.hpp>
+#include <QSharedPointer>
 #include <QMenu>
 #include <QString>
 #include "backend/config/cbtconfig.h"
@@ -19,9 +19,9 @@
 #include "frontend/cinfodisplay.h"
 #include "frontend/display/bthtmljsobject.h"
 #include "frontend/displaywindow/cdisplaywindow.h"
+#include "frontend/displaywindow/cdisplaywindowfactory.h"
 #include "frontend/displaywindow/creadwindow.h"
 #include "util/directory.h"
-#include "util/cpointers.h"
 
 
 using namespace InfoDisplay;
@@ -35,7 +35,7 @@ BtHtmlReadDisplay::BtHtmlReadDisplay(CReadWindow* readWindow, QWidget* parentWid
 
 {
     settings()->setAttribute(QWebSettings::JavascriptEnabled, true);
-    m_view = new BtHtmlReadDisplayView(this, parentWidget ? parentWidget : readWindow);
+    m_view = new BtHtmlReadDisplayView(this, parentWidget ? parentWidget : readWindow, readWindow);
     m_view->setAcceptDrops(true);
     m_view->setPage(this);
     setParent(m_view);
@@ -87,7 +87,7 @@ const QString BtHtmlReadDisplay::text( const CDisplay::TextType format, const CD
             else {
                 CDisplayWindow* window = parentWindow();
                 CSwordKey* const key = window->key();
-                CSwordModuleInfo* module = key->module();
+                const CSwordModuleInfo *module = key->module();
                 //This is never used for Bibles, so it is not implemented for
                 //them.  If it should be, see CReadDisplay::print() for example
                 //code.
@@ -98,7 +98,7 @@ const QString BtHtmlReadDisplay::text( const CDisplay::TextType format, const CD
                         module->type() == CSwordModuleInfo::Commentary ||
                         module->type() == CSwordModuleInfo::GenericBook) {
                     /// \todo This is a BAD HACK, we have to fnd a better solution to manage the settings now
-                    CSwordBackend::FilterOptions filterOptions;
+                    FilterOptions filterOptions;
                     filterOptions.footnotes = false;
                     filterOptions.strongNumbers = false;
                     filterOptions.morphTags = false;
@@ -106,7 +106,7 @@ const QString BtHtmlReadDisplay::text( const CDisplay::TextType format, const CD
                     filterOptions.scriptureReferences = false;
                     filterOptions.textualVariants = false;
 
-                    CPointers::backend()->setFilterOptions(filterOptions);
+                    CSwordBackend::instance()->setFilterOptions(filterOptions);
 
                     return QString(key->strippedText()).append("\n(")
                            .append(key->key())
@@ -122,7 +122,7 @@ const QString BtHtmlReadDisplay::text( const CDisplay::TextType format, const CD
                 return QString::null;
             }
             else if (format == HTMLText) {
-                //	\todo It does not appear this is ever called
+                //    \todo It does not appear this is ever called
             }
             else { //plain text requested
                 return selectedText();
@@ -144,9 +144,9 @@ const QString BtHtmlReadDisplay::text( const CDisplay::TextType format, const CD
             ReferenceManager::Type type;
             ReferenceManager::decodeHyperlink(activeAnchor(), moduleName, keyName, type);
 
-            if (CSwordModuleInfo* module = backend()->findModuleByName(moduleName)) {
-                boost::scoped_ptr<CSwordKey> key( CSwordKey::createInstance(module) );
-                key->key( keyName );
+            if (CSwordModuleInfo *module = CSwordBackend::instance()->findModuleByName(moduleName)) {
+                QSharedPointer<CSwordKey> key( CSwordKey::createInstance(module) );
+                key->setKey(keyName);
 
                 return key->strippedText();
             }
@@ -159,12 +159,12 @@ const QString BtHtmlReadDisplay::text( const CDisplay::TextType format, const CD
             ReferenceManager::Type type;
             ReferenceManager::decodeHyperlink(activeAnchor(), moduleName, keyName, type);
 
-            if (CSwordModuleInfo* module = backend()->findModuleByName(moduleName)) {
-                boost::scoped_ptr<CSwordKey> key( CSwordKey::createInstance(module) );
-                key->key( keyName );
+            if (CSwordModuleInfo *module = CSwordBackend::instance()->findModuleByName(moduleName)) {
+                QSharedPointer<CSwordKey> key( CSwordKey::createInstance(module) );
+                key->setKey(keyName);
 
                 /// \todo This is a BAD HACK, we have to fnd a better solution to manage the settings now
-                CSwordBackend::FilterOptions filterOptions;
+                FilterOptions filterOptions;
                 filterOptions.footnotes = false;
                 filterOptions.strongNumbers = false;
                 filterOptions.morphTags = false;
@@ -172,7 +172,7 @@ const QString BtHtmlReadDisplay::text( const CDisplay::TextType format, const CD
                 filterOptions.scriptureReferences = false;
                 filterOptions.textualVariants = false;
 
-                CPointers::backend()->setFilterOptions(filterOptions);
+                CSwordBackend::instance()->setFilterOptions(filterOptions);
 
                 return QString(key->strippedText()).append("\n(")
                        .append(key->key())
@@ -180,16 +180,16 @@ const QString BtHtmlReadDisplay::text( const CDisplay::TextType format, const CD
                        .append(key->module()->name())
                        .append(")");
                 /*    ("%1\n(%2, %3)")
-                	.arg()
-                	.arg(key->key())
-                	.arg(key->module()->name());*/
+                    .arg()
+                    .arg(key->key())
+                    .arg(key->module()->name());*/
             }
             return QString::null;
         }
         default:
             return QString::null;
     }
-    return QString();
+    return QString::null;
 }
 
 // Puts html text and javascript into QWebView
@@ -198,11 +198,11 @@ void BtHtmlReadDisplay::setText( const QString& newText ) {
     QString jsText = newText;
 
     jsText.replace(
-		QString("</body>"),
-		QString("<script  type=\"text/javascript\">").append(javascript).append("</script></body>")
-	);
+        QString("</body>"),
+        QString("<script  type=\"text/javascript\">").append(javascript).append("</script></body>")
+    );
 
-    // Disconnect any previous connect and connect to slot that loads the javascript object
+    // Disconnect any previous connections and connect to slot that loads the javascript object
     QWebFrame* frame = mainFrame();
     disconnect(frame, SIGNAL(javaScriptWindowObjectCleared()), 0, 0);
     bool ok = connect(frame, SIGNAL(javaScriptWindowObjectCleared()), this, SLOT(loadJSObject()));
@@ -211,11 +211,11 @@ void BtHtmlReadDisplay::setText( const QString& newText ) {
     // Send text to the html viewer
     m_view->setHtml(jsText);
 
-	this->currentSource = jsText;
+    this->currentSource = jsText;
 }
 
 QString BtHtmlReadDisplay::getCurrentSource( ) {
-	return this->currentSource;
+    return this->currentSource;
 }
 
 // See if any text is selected
@@ -233,10 +233,7 @@ QWidget* BtHtmlReadDisplay::view() {
 
 // Select all text in the viewer
 void BtHtmlReadDisplay::selectAll() {
-    m_jsObject->setBodyEditable(true);
-    m_view->triggerPageAction( QWebPage::MoveToStartOfDocument, true );
-    m_view->triggerPageAction( QWebPage::SelectEndOfDocument,   true );
-    m_jsObject->setBodyEditable(false);
+    m_view->triggerPageAction( QWebPage::SelectAll, true );
 }
 
 // Scroll QWebView to the correct location as specified by the anchor
@@ -276,8 +273,8 @@ void BtHtmlReadDisplay::javaScriptConsoleMessage (const QString& message, int li
 
 // ----------------- BtHtmlReadDisplayView -------------------------------------
 
-BtHtmlReadDisplayView::BtHtmlReadDisplayView(BtHtmlReadDisplay* displayWidget, QWidget* parent)
-        : QWebView(parent), m_display(displayWidget) {
+BtHtmlReadDisplayView::BtHtmlReadDisplayView(BtHtmlReadDisplay* displayWidget, QWidget* parent, CReadWindow* readWindow)
+        : QWebView(parent), m_display(displayWidget), m_readWindow(readWindow) {
 }
 
 BtHtmlReadDisplayView::~BtHtmlReadDisplayView() {
@@ -307,17 +304,48 @@ void BtHtmlReadDisplayView::dropEvent( QDropEvent* e ) {
         }
     };
     //don't accept the action!
-    e->ignore();
+//    e->ignore();
 }
 
 // Reimplementation from QWebView
 void BtHtmlReadDisplayView::dragEnterEvent( QDragEnterEvent* e ) {
-    if (e->mimeData()->hasFormat("BibleTime/Bookmark")) {
-        e->acceptProposedAction();
+    if ( ! e->mimeData()->hasFormat("BibleTime/Bookmark"))
         return;
+
+    const QMimeData* mimedata = e->mimeData();
+    if (mimedata == 0)
+        return;
+
+    const BTMimeData* btmimedata = qobject_cast<const BTMimeData*>(mimedata);
+    if (btmimedata == 0)
+        return;
+
+    BookmarkItem item = (qobject_cast<const BTMimeData*>(e->mimeData()))->bookmark();
+    QString moduleName = item.module();
+    CSwordModuleInfo *m = CSwordBackend::instance()->findModuleByName(moduleName);
+    Q_ASSERT(m);
+    if (m == 0)
+        return;
+
+    CSwordModuleInfo::ModuleType bookmarkType = m->type();
+    CSwordModuleInfo::ModuleType windowType = CDisplayWindowFactory::getModuleType(m_readWindow);
+
+    // Is bible reference bookmark compatible with the window type?
+    if ((bookmarkType == CSwordModuleInfo::Bible ||
+        bookmarkType == CSwordModuleInfo::Commentary)) {
+            if (windowType == CSwordModuleInfo::Bible ||
+                windowType == CSwordModuleInfo::Commentary)
+                e->acceptProposedAction();
+            return;
     }
-    //don't accept the action!
-    e->ignore();
+
+    // Is reference type compatible with window type
+    if (bookmarkType == windowType) {
+            e->acceptProposedAction();
+            return;
+    }
+
+    return;
 }
 
 // Reimplementation from QWebView
