@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2009 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -104,17 +104,18 @@ class BtHtmlReadDisplay : public QWebPage, public CReadDisplay {
 };
 
 
-class BtHtmlReadDisplayView : public QWebView, public CPointers {
+class BtHtmlReadDisplayView : public QWebView {
         Q_OBJECT
     protected:
         friend class BtHtmlReadDisplay;
         void contextMenuEvent(QContextMenuEvent* event);
-        BtHtmlReadDisplayView(BtHtmlReadDisplay* display, QWidget* parent);
+        BtHtmlReadDisplayView(BtHtmlReadDisplay* display, QWidget* parent, CReadWindow* readWindow);
         ~BtHtmlReadDisplayView();
         bool event(QEvent* e);
 
     private:
         BtHtmlReadDisplay* m_display;
+        CReadWindow* m_readWindow;
         void dropEvent( QDropEvent* e );
         void dragEnterEvent( QDragEnterEvent* e );
         void dragMoveEvent( QDragMoveEvent* e );
