@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -59,15 +59,18 @@ void CDisplayConnections::copyAll() {
 
 /** No descriptions */
 void CDisplayConnections::copySelection() {
-    qWarning("copyign the selected text");
     m_display->copy(CDisplay::PlainText, CDisplay::SelectedText);
 }
 
-void CDisplayConnections::printAll(CSwordBackend::DisplayOptions displayOptions, CSwordBackend::FilterOptions filterOptions) {
+void CDisplayConnections::printAll(const DisplayOptions &displayOptions,
+                                   const FilterOptions &filterOptions)
+{
     m_display->print(CDisplay::Document, displayOptions, filterOptions);
 }
 
-void CDisplayConnections::printAnchorWithText(CSwordBackend::DisplayOptions displayOptions, CSwordBackend::FilterOptions filterOptions) {
+void CDisplayConnections::printAnchorWithText(const DisplayOptions &displayOptions,
+                                              const FilterOptions &filterOptions)
+{
     m_display->print(CDisplay::AnchorWithText, displayOptions, filterOptions);
 }
 
@@ -177,7 +180,7 @@ void CDisplay::emitReferenceDropped( const QString& reference ) {
     m_connections->emitReferenceDropped(key);
 }
 
-/** Returns the connections obect used for signas and slots. */
+/** Returns the connections object used for signals and slots. */
 CDisplayConnections* CDisplay::connectionsProxy() const {
     return m_connections;
 }
