@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -10,8 +10,6 @@
 #ifndef CDISPLAY_H
 #define CDISPLAY_H
 
-#include "util/cpointers.h"
-
 #include <QMap>
 #include "backend/managers/cswordbackend.h"
 
@@ -27,7 +25,7 @@ class QMenu;
 /** The base class for all display widgets.
   * @author The BibleTime team
   */
-class CDisplay : public CPointers {
+class CDisplay {
     public:
         enum WriteDisplayType {
             HTMLDisplay = 0,
@@ -84,15 +82,17 @@ class CDisplay : public CPointers {
         */
         virtual void selectAll() = 0;
         /**
-        * Returns the connections obect used for signas and slots.
+        * Returns the connections object used for signals and slots.
         */
         virtual CDisplayConnections* connectionsProxy() const;
         /**
         * Returns the parent window used for this display widget.
         */
         CDisplayWindow* parentWindow() const;
-        virtual void print( const CDisplay::TextPart, CSwordBackend::DisplayOptions displayOptions,
-                            CSwordBackend::FilterOptions filterOptions) = 0;
+
+        virtual void print(const CDisplay::TextPart,
+                           const DisplayOptions &displayOptions,
+                           const FilterOptions &filterOptions) = 0;
         /**
         * Installs the popup which should be opened when the right mouse button was pressed.
         */
@@ -151,9 +151,11 @@ class CDisplayConnections : public QObject {
         void saveAsHTML();
         void saveAnchorWithText();
 
-        void printAll(CSwordBackend::DisplayOptions displayOptions, CSwordBackend::FilterOptions filterOptions);
-        void printAnchorWithText(CSwordBackend::DisplayOptions displayOptions,
-                                 CSwordBackend::FilterOptions filterOptions);
+        void printAll(const DisplayOptions &displayOptions,
+                      const FilterOptions &filterOptions);
+
+        void printAnchorWithText(const DisplayOptions &displayOptions,
+                                 const FilterOptions &filterOptions);
 
         void copySelection();
         void copyAll();
