@@ -2,14 +2,14 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
 
 #include "frontend/display/cplainwritedisplay.h"
 
-#include <boost/scoped_ptr.hpp>
+#include <QSharedPointer>
 #include <QDragEnterEvent>
 #include <QDragMoveEvent>
 #include <QDropEvent>
@@ -42,7 +42,7 @@ void CPlainWriteDisplay::selectAll() {
 void CPlainWriteDisplay::setText( const QString& newText ) {
     //make sure the text has been converted to show \n instead of <br/>
     QString text = newText;
-// 	text.replace("\n<br /><!-- BT newline -->\n", "\n");
+//     text.replace("\n<br /><!-- BT newline -->\n", "\n");
     text.replace("<br />", "\n"); //inserted by BT or the Qt textedit widget
 
     QTextEdit::setText(text);
@@ -62,9 +62,6 @@ const QString CPlainWriteDisplay::text( const CDisplay::TextType /*format*/, con
     return QString::null;
 }
 
-void CPlainWriteDisplay::print( const CDisplay::TextPart, CSwordBackend::DisplayOptions, CSwordBackend::FilterOptions) {
-}
-
 /** Sets the current status of the edit widget. */
 void CPlainWriteDisplay::setModified( const bool modified ) {
     document()->setModified(modified);
@@ -86,16 +83,6 @@ const QString CPlainWriteDisplay::plainText() {
     return ret;
 }
 
-/** Reimplementation from QTextEdit. Provides an popup menu for the given position. */
-QMenu* CPlainWriteDisplay::createPopupMenu( const QPoint& /*pos*/ ) {
-    return installedPopup();
-}
-//
-///** Reimplementation from QTextEdit. Provides an popup menu for the given position. */
-//QMenu* CPlainWriteDisplay::createPopupMenu( ) {
-//	return installedPopup();
-//}
-
 /** Creates the necessary action objects and puts them on the toolbar. */
 void CPlainWriteDisplay::setupToolbar(QToolBar*, BtActionCollection*) {}
 
@@ -138,9 +125,9 @@ void CPlainWriteDisplay::dropEvent( QDropEvent* e ) {
         BTMimeData::ItemList::iterator it;
         for (it = items.begin(); it != items.end(); ++it) {
 
-            CSwordModuleInfo* module = backend()->findModuleByName((*it).module());
-            boost::scoped_ptr<CSwordKey> key( CSwordKey::createInstance(module) );
-            key->key( (*it).key() );
+            CSwordModuleInfo *module = CSwordBackend::instance()->findModuleByName((*it).module());
+            QSharedPointer<CSwordKey> key( CSwordKey::createInstance(module) );
+            key->setKey((*it).key());
             QString moduleText = key->strippedText();
 
             const QString text = QString::fromLatin1("%1\n(%2, %3)\n").arg(moduleText).arg((*it).key()).arg((*it).module());
