@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -44,7 +44,14 @@ class CPlainWriteDisplay : public QTextEdit, public CWriteDisplay  {
         */
         virtual QWidget* view();
         virtual const QString text( const CDisplay::TextType format = CDisplay::HTMLText, const CDisplay::TextPart part = CDisplay::Document );
-        virtual void print( const CDisplay::TextPart, CSwordBackend::DisplayOptions displayOptions, CSwordBackend::FilterOptions filterOptions );
+
+        /**
+          Reimplemented from CDisplay.
+        */
+        virtual inline void print(const CDisplay::TextPart,
+                                  const DisplayOptions &,
+                                  const FilterOptions &) {}
+
         /**
         * Reimplementation (CWriteDisplay).
         */
@@ -68,14 +75,7 @@ class CPlainWriteDisplay : public QTextEdit, public CWriteDisplay  {
 
         CPlainWriteDisplay(CWriteWindow* parentWindow, QWidget* parent);
         virtual ~CPlainWriteDisplay();
-        /**
-        * Reimplementation from QTextEdit. Provides an popup menu for the given position.
-        */
-        virtual QMenu* createPopupMenu( const QPoint& pos );
-//	/**
-//	* Reimplementation from QTextEdit. Provides an popup menu.
-//	*/
-//	virtual QMenu* createPopupMenu();
+
         /**
         * Reimplementation from QTextEdit to manage drops of our drag and drop objects.
         */
