@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -46,10 +46,14 @@ bool CReadDisplay::hasActiveAnchor() {
 }
 
 
-void CReadDisplay::print(const CDisplay::TextPart type, CSwordBackend::DisplayOptions displayOptions, CSwordBackend::FilterOptions filterOptions) {
+void CReadDisplay::print(const CDisplay::TextPart type,
+                         const DisplayOptions &displayOptions,
+                         const FilterOptions &filterOptions)
+{
+    typedef CSwordBibleModuleInfo CSBiMI;
     CDisplayWindow* window = parentWindow();
     CSwordKey* const key = window->key();
-    CSwordModuleInfo* module = key->module();
+    const CSwordModuleInfo *module = key->module();
 
     const CDisplayWindow *displayWindow = parentWindow();
     CExportManager mgr(QObject::tr("Print keys"), false, QString::null, displayWindow->filterOptions(), displayWindow->displayOptions());
@@ -64,7 +68,7 @@ void CReadDisplay::print(const CDisplay::TextPart type, CSwordBackend::DisplayOp
 
                 CSwordVerseKey stopKey(*vk);
 
-                CSwordBibleModuleInfo* bible = dynamic_cast<CSwordBibleModuleInfo*>(module);
+                const CSBiMI *bible = dynamic_cast<const CSBiMI*>(module);
                 if (bible) {
                     stopKey.Verse( bible->verseCount( bible->bookNumber(startKey.book()), startKey.Chapter() ) );
                 }
