@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -33,8 +33,10 @@ class CReadDisplay :  public CDisplay {
         * Moves the widget to the given anchor.
         */
         virtual void moveToAnchor( const QString& ) = 0;
-        virtual void print(const CDisplay::TextPart, CSwordBackend::DisplayOptions displayOptions,
-                           CSwordBackend::FilterOptions filterOptions);
+
+        virtual void print(const CDisplay::TextPart,
+                           const DisplayOptions &displayOptions,
+                           const FilterOptions &filterOptions);
 
         void setMouseTracking(const bool trackingEnabled) {
             m_useMouseTracking = trackingEnabled;
