@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2009 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -48,6 +48,8 @@ class CBibleReadWindow : public CLexiconReadWindow  {
         virtual void initToolbars();
         virtual void initConnections();
         virtual void initView();
+        /** Called to add actions to mainWindow toolbars */
+        virtual void setupMainWindowToolBars();
         /**
         * Reimplementation.
         */
