@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2009 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -13,6 +13,7 @@
 #include <QMenu>
 #include <QSplitter>
 #include <QToolBar>
+#include "bibletime.h"
 #include "backend/config/cbtconfig.h"
 #include "backend/keys/cswordtreekey.h"
 #include "frontend/display/cdisplay.h"
@@ -91,29 +92,27 @@ void CBookReadWindow::initConnections() {
 /** Init the view */
 void CBookReadWindow::initView() {
     QSplitter* splitter = new QSplitter(this);
+    m_treeChooser = new CBookTreeChooser(modules(), history(), key(), splitter);
+    setDisplayWidget( CDisplay::createReadInstance(this, splitter) );
+    m_treeChooser->hide();
 
+    // Create Navigation toolbar
     setMainToolBar( new QToolBar(this) );
     mainToolBar()->setAllowedAreas(Qt::TopToolBarArea);
     mainToolBar()->setFloatable(false);
-
     addToolBar(mainToolBar());
+    setKeyChooser( CKeyChooser::createInstance(modules(), history(), key(), mainToolBar()) );
 
-    m_treeChooser = new CBookTreeChooser(modules(), key(), splitter);
-    setDisplayWidget( CDisplay::createReadInstance(this, splitter) );
-
-    setKeyChooser( CKeyChooser::createInstance(modules(), key(), mainToolBar()) );
-
-    setModuleChooserBar( new BtModuleChooserBar(getModuleList(), modules().first()->type(), this) );
+    // Create the Works toolbar
+    setModuleChooserBar( new BtModuleChooserBar(this));
+    moduleChooserBar()->setModules(getModuleList(), modules().first()->type(), this);
     addToolBar(moduleChooserBar());
 
+    // Create the Tools toolbar
     setButtonsToolBar( new QToolBar(this) );
     buttonsToolBar()->setAllowedAreas(Qt::TopToolBarArea);
     buttonsToolBar()->setFloatable(false);
-
-    setDisplaySettingsButton(new BtDisplaySettingsButton(buttonsToolBar()));
-
     addToolBar(buttonsToolBar());
-    m_treeChooser->hide();
 
     setCentralWidget( splitter );
     setWindowIcon(util::tool::getIconForModule(modules().first()));
@@ -125,18 +124,44 @@ void CBookReadWindow::initToolbars() {
 
     mainToolBar()->addAction(m_actions.backInHistory);
     mainToolBar()->addAction(m_actions.forwardInHistory);
-
     mainToolBar()->addWidget(keyChooser());
 
-    buttonsToolBar()->addAction(m_treeAction);
+    // Tools toolbar
+    buttonsToolBar()->addAction(m_treeAction);  // Tree
     m_treeAction->setChecked(false);
-
-    buttonsToolBar()->addWidget(displaySettingsButton());
-
+    BtDisplaySettingsButton* button = new BtDisplaySettingsButton(buttonsToolBar());
+    setDisplaySettingsButton(button);
+    buttonsToolBar()->addWidget(button);  // Display settings
     QAction* action = qobject_cast<QAction*>(actionCollection()->action(
                           CResMgr::displaywindows::general::search::actionName ));
     if (action) {
-        buttonsToolBar()->addAction(action);
+        buttonsToolBar()->addAction(action);  // Search
+    }
+}
+
+void CBookReadWindow::setupMainWindowToolBars() {
+    // Navigation toolbar
+    btMainWindow()->navToolBar()->addAction(m_actions.backInHistory); //1st button
+    btMainWindow()->navToolBar()->addAction(m_actions.forwardInHistory); //2nd button
+    CKeyChooser* keyChooser = CKeyChooser::createInstance(modules(), history(), key(), btMainWindow()->navToolBar() );
+    btMainWindow()->navToolBar()->addWidget(keyChooser);
+    bool ok = connect(keyChooser, SIGNAL(keyChanged(CSwordKey*)), this, SLOT(lookupSwordKey(CSwordKey*)));
+    Q_ASSERT(ok);
+    ok = connect(this, SIGNAL(sigKeyChanged(CSwordKey*)), keyChooser, SLOT(updateKey(CSwordKey*)) );
+    Q_ASSERT(ok);
+
+    // Works toolbar
+    btMainWindow()->worksToolBar()->setModules(getModuleList(), modules().first()->type(), this);
+
+    // Tools toolbar
+    btMainWindow()->toolsToolBar()->addAction(m_treeAction);  // Tree
+    BtDisplaySettingsButton* button = new BtDisplaySettingsButton(buttonsToolBar());
+    setDisplaySettingsButton(button);
+    btMainWindow()->toolsToolBar()->addWidget(button);  // Display settings
+    QAction* action = qobject_cast<QAction*>(actionCollection()->action(
+                          CResMgr::displaywindows::general::search::actionName ));
+    if (action) {
+        btMainWindow()->toolsToolBar()->addAction(action);  // Search
     }
 }
 
