@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -35,30 +35,34 @@ using namespace Profile;
 
 CDisplayWindow::CDisplayWindow(QList<CSwordModuleInfo*> modules, CMDIArea *parent)
         : QMainWindow(parent),
+        m_actionCollection(0),
         m_mdi(parent),
-        m_displaySettingsButton(0),
         m_keyChooser(0),
         m_swordKey(0),
         m_isReady(false),
         m_moduleChooserBar(0),
         m_mainToolBar(0),
+        m_buttonsToolBar(0),
+        m_formatToolBar(0),
+        m_headerBar(0),
         m_popupMenu(0),
-        m_displayWidget(0) {
+        m_displayWidget(0),
+        m_history(0) {
     qDebug() << "CDisplayWindow::CDisplayWindow";
     setAttribute(Qt::WA_DeleteOnClose); //we want to destroy this window when it is closed
-    parent->addSubWindow(this);
     m_actionCollection = new BtActionCollection(this);
     setModules(modules);
 
     // Connect this to the backend module list changes
-    connect(CPointers::backend(),
+    connect(CSwordBackend::instance(),
             SIGNAL(sigSwordSetupChanged(CSwordBackend::SetupChangedReason)),
             SLOT(reload(CSwordBackend::SetupChangedReason)));
-    BibleTime* mainwindow = dynamic_cast<BibleTime*>(m_mdi->parent());
+    BibleTime* mainwindow = btMainWindow();
     connect(mainwindow, SIGNAL(toggledTextWindowHeader(bool)), SLOT(slotShowHeader(bool)) );
     connect(mainwindow, SIGNAL(toggledTextWindowNavigator(bool)), SLOT(slotShowNavigator(bool)) );
     connect(mainwindow, SIGNAL(toggledTextWindowToolButtons(bool)), SLOT(slotShowToolButtons(bool)) );
     connect(mainwindow, SIGNAL(toggledTextWindowModuleChooser(bool)), SLOT(slotShowModuleChooser(bool)) );
+    connect(mainwindow, SIGNAL(toggledTextWindowFormatToolbar(bool)), SLOT(slotShowFormatToolBar(bool)) );
 }
 
 CDisplayWindow::~CDisplayWindow() {
@@ -66,6 +70,33 @@ CDisplayWindow::~CDisplayWindow() {
     m_swordKey = 0;
 }
 
+BibleTime* CDisplayWindow::btMainWindow() {
+    return dynamic_cast<BibleTime*>(m_mdi->parent());
+}
+
+void CDisplayWindow::setToolBarsHidden() {
+    // Hide current window toolbars
+    if (mainToolBar())
+        mainToolBar()->setHidden(true);
+    if (buttonsToolBar())
+        buttonsToolBar()->setHidden(true);
+    if (moduleChooserBar())
+        moduleChooserBar()->setHidden(true);
+    if (formatToolBar())
+        formatToolBar()->setHidden(true);
+}
+void CDisplayWindow::clearMainWindowToolBars() {
+    // Clear main window toolbars, except for works toolbar
+    btMainWindow()->navToolBar()->clear();
+    btMainWindow()->toolsToolBar()->clear();
+    btMainWindow()->formatToolBar()->clear();
+}
+
+void CDisplayWindow::windowActivated() {
+    clearMainWindowToolBars();
+    setupMainWindowToolBars();
+}
+
 /** Returns the right window caption. */
 const QString CDisplayWindow::windowCaption() {
     if (!m_modules.count()) {
@@ -76,10 +107,10 @@ const QString CDisplayWindow::windowCaption() {
 }
 
 /** Returns the used modules as a pointer list */
-QList<CSwordModuleInfo*> CDisplayWindow::modules() {
+const QList<const CSwordModuleInfo*> CDisplayWindow::modules() const {
     //qDebug() << "CDisplayWindow::modules";
 
-    return CPointers::backend()->getPointerList(m_modules);
+    return CSwordBackend::instance()->getConstPointerList(m_modules);
 }
 
 void CDisplayWindow::insertKeyboardActions( BtActionCollection* a ) {
@@ -188,7 +219,7 @@ void CDisplayWindow::reload(CSwordBackend::SetupChangedReason) {
     //first make sure all used Sword modules are still present
     QMutableStringListIterator it(m_modules);
     while (it.hasNext()) {
-        if (!backend()->findModuleByName(it.next())) {
+        if (!CSwordBackend::instance()->findModuleByName(it.next())) {
             it.remove();
         }
     }
@@ -234,13 +265,15 @@ void CDisplayWindow::slotRemoveModule(int index) {
 }
 
 /** Sets the new display options for this window. */
-void CDisplayWindow::setDisplayOptions(const CSwordBackend::DisplayOptions &displayOptions) {
+void CDisplayWindow::setDisplayOptions(const DisplayOptions &displayOptions) {
     m_displayOptions = displayOptions;
+    emit sigDisplayOptionsChanged(m_displayOptions);
 }
 
 /** Sets the new filter options of this window. */
-void CDisplayWindow::setFilterOptions(const CSwordBackend::FilterOptions &filterOptions) {
+void CDisplayWindow::setFilterOptions(const FilterOptions &filterOptions) {
     m_filterOptions = filterOptions;
+    emit sigFilterOptionsChanged(m_filterOptions);
 }
 
 /** Set the ready status */
@@ -264,6 +297,12 @@ void CDisplayWindow::setKey( CSwordKey* key ) {
     m_swordKey = key;
 }
 
+BTHistory* CDisplayWindow::history() {
+    if (m_history == 0)
+        m_history = new BTHistory(this);
+    return m_history;
+}
+
 void CDisplayWindow::modulesChanged() {
     // this would only set the stringlist again
     //if (moduleChooserBar()) { //necessary for write windows
@@ -273,11 +312,8 @@ void CDisplayWindow::modulesChanged() {
         close();
     }
     else {
-        if (displaySettingsButton()) {
-            displaySettingsButton()->setModules(modules());
-        }
-
-        key()->module(modules().first());
+        emit sigModulesChanged(modules());
+        key()->setModule(modules().first());
         keyChooser()->setModules(modules());
     }
 }
@@ -298,7 +334,7 @@ void CDisplayWindow::setModuleChooserBar( BtModuleChooserBar* bar ) {
     }
 }
 
-/** Sets the module header of text area. */
+/** Setup the module header of text area. */
 void CDisplayWindow::setHeaderBar( QToolBar* header ) {
     m_headerBar = header;
     header->setMovable(false);
@@ -328,73 +364,92 @@ bool CDisplayWindow::init() {
     parentWidget()->setFocusPolicy(Qt::ClickFocus);
     initActions();
     initToolbars();
+    if ( ! CBTConfig::get(CBTConfig::showToolbarsInEachWindow))
+        setToolBarsHidden();
+    btMainWindow()->clearMdiToolBars();
+    clearMainWindowToolBars();
     initConnections();
     setupPopupMenu();
 
     m_filterOptions = CBTConfig::getFilterOptionDefaults();
     m_displayOptions = CBTConfig::getDisplayOptionDefaults();
-    if (displaySettingsButton()) {
-        displaySettingsButton()->setFilterOptions(m_filterOptions, false);
-        displaySettingsButton()->setDisplayOptions(m_displayOptions, false);
-        displaySettingsButton()->setModules(modules());
-    }
+    emit sigDisplayOptionsChanged(m_displayOptions);
+    emit sigFilterOptionsChanged(m_filterOptions);
+    emit sigModulesChanged(modules());
 
     setReady(true);
     return true;
 }
 
-/** Sets the main toolbar. */
-void CDisplayWindow::setMainToolBar( QToolBar* bar ) {
-    m_mainToolBar = bar;
+static void prepareToolBar(QToolBar* bar, const QString& title, bool visible) {
     bar->setAllowedAreas(Qt::TopToolBarArea);
     bar->setFloatable(false);
-    bar->setWindowTitle(tr("Navigation"));
-    bar->setVisible(CBTConfig::get(CBTConfig::showTextWindowNavigator));
+    bar->setWindowTitle(title);
+    bar->setVisible(visible);
 }
 
-/** Sets the main toolbar. */
+/** Setup the Navigation toolbar. */
+void CDisplayWindow::setMainToolBar( QToolBar* bar ) {
+    prepareToolBar(bar, tr("Navigation"), CBTConfig::get(CBTConfig::showTextWindowNavigator) );
+    m_mainToolBar = bar;
+}
+
+/** Setup the Tools toolbar. */
 void CDisplayWindow::setButtonsToolBar( QToolBar* bar ) {
+    prepareToolBar(bar, tr("Tool"), CBTConfig::get(CBTConfig::showTextWindowToolButtons) );
     m_buttonsToolBar = bar;
-    bar->setAllowedAreas(Qt::TopToolBarArea);
-    bar->setFloatable(false);
-    bar->setWindowTitle(tr("Tools"));
-    bar->setVisible( CBTConfig::get(CBTConfig::showTextWindowToolButtons) );
+}
+
+/** Setup the Format toolbar. */
+void CDisplayWindow::setFormatToolBar( QToolBar* bar ) {
+    prepareToolBar(bar, tr("Format"), true );
+    m_formatToolBar = bar;
 }
 
 /** Sets the display settings button. */
-void CDisplayWindow::setDisplaySettingsButton( BtDisplaySettingsButton* button ) {
-    if (m_displaySettingsButton) {
-        m_displaySettingsButton->disconnect(this);
-    }
-
-    m_displaySettingsButton = button;
+void CDisplayWindow::setDisplaySettingsButton(BtDisplaySettingsButton *button) {
+    connect(this, SIGNAL(sigDisplayOptionsChanged(const DisplayOptions&)),
+        button, SLOT(setDisplayOptions(const DisplayOptions&)));
+    connect(this, SIGNAL(sigFilterOptionsChanged(const FilterOptions&)),
+        button, SLOT(setFilterOptions(const FilterOptions&)));
+    connect(this, SIGNAL(sigModulesChanged(const QList<const CSwordModuleInfo*>&)),
+        button, SLOT(setModules(const QList<const CSwordModuleInfo*>&)));
 
     button->setDisplayOptions(displayOptions(), false);
     button->setFilterOptions(filterOptions(), false);
     button->setModules(modules());
 
-    connect(button, SIGNAL(sigFilterOptionsChanged(CSwordBackend::FilterOptions)),
-            this, SLOT(setFilterOptions(CSwordBackend::FilterOptions)));
-    connect(button, SIGNAL(sigDisplayOptionsChanged(CSwordBackend::DisplayOptions)),
-            this, SLOT(setDisplayOptions(CSwordBackend::DisplayOptions)));
+    connect(button, SIGNAL(sigFilterOptionsChanged(const FilterOptions&)),
+            this, SLOT(setFilterOptions(const FilterOptions&)));
+    connect(button, SIGNAL(sigDisplayOptionsChanged(const DisplayOptions&)),
+            this, SLOT(setDisplayOptions(const DisplayOptions&)));
     connect(button, SIGNAL(sigChanged()),
             this, SLOT(lookup()));
 }
 
 void CDisplayWindow::slotShowHeader(bool show) {
-    headerBar()->setVisible(show);
+    if (headerBar())
+        headerBar()->setVisible(show);
 }
 
 void CDisplayWindow::slotShowNavigator(bool show) {
-    mainToolBar()->setVisible(show);
+    if (mainToolBar())
+        mainToolBar()->setVisible(show);
 }
 
 void CDisplayWindow::slotShowToolButtons(bool show) {
-    buttonsToolBar()->setVisible(show);
+    if (buttonsToolBar())
+        buttonsToolBar()->setVisible(show);
 }
 
 void CDisplayWindow::slotShowModuleChooser(bool show) {
-    moduleChooserBar()->setVisible(show);
+    if (moduleChooserBar())
+        moduleChooserBar()->setVisible(show);
+}
+
+void CDisplayWindow::slotShowFormatToolBar(bool show) {
+    if (formatToolBar())
+        formatToolBar()->setVisible(show);
 }
 
 /** Lookup the current key. Used to refresh the display. */
@@ -407,25 +462,25 @@ void CDisplayWindow::lookupModKey( const QString& moduleName, const QString& key
         return;
     }
 
-    CSwordModuleInfo* m = backend()->findModuleByName(moduleName);
-    Q_ASSERT(m);
+    CSwordModuleInfo *m = CSwordBackend::instance()->findModuleByName(moduleName);
     if (!m) {
-        return;
+        return; /// \todo check if this is correct behavior
     }
 
     /// \todo check for containsRef compat
     if (m && modules().contains(m)) {
-        key()->key(keyName);
+        key()->setKey(keyName);
         keyChooser()->setKey(key()); //the key chooser does send an update signal
+        emit sigKeyChanged(key());
     }
-    else { 	//given module not displayed in this window
+    else {     //given module not displayed in this window
         //if the module is displayed in another display window we assume a wrong drop
         //create a new window for the given module
         QList<CSwordModuleInfo*> mList;
         mList.append(m);
 
-        Q_ASSERT(qobject_cast<BibleTime*>(mdi()->parent()) != 0);
-        BibleTime *mainWindow(static_cast<BibleTime*>(mdi()->parent()));
+        BibleTime *mainWindow = btMainWindow();
+        Q_ASSERT(mainWindow != 0);
         mainWindow->createReadDisplayWindow(mList, keyName);
     }
 }
