@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2009 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -25,24 +25,29 @@
 
 CReadWindow* CDisplayWindowFactory::createReadInstance(QList<CSwordModuleInfo*> modules, CMDIArea* parent) {
     qDebug() << "CDisplayWindowFactory::createReadInstance";
+    CReadWindow* win = 0;
     switch (modules.first()->type()) {
         case CSwordModuleInfo::Bible:
-            return new CBibleReadWindow(modules, parent);
+            win = new CBibleReadWindow(modules, parent);
+        break;
         case CSwordModuleInfo::Commentary:
-            return new CCommentaryReadWindow(modules, parent);
+            win = new CCommentaryReadWindow(modules, parent);
+        break;
         case CSwordModuleInfo::Lexicon:
-            return new CLexiconReadWindow(modules, parent);
+            win = new CLexiconReadWindow(modules, parent);
+        break;
         case CSwordModuleInfo::GenericBook:
-            return new CBookReadWindow(modules, parent);
+            win = new CBookReadWindow(modules, parent);
+        break;
         default:
             qWarning("unknown module type");
             break;
     }
-    return 0;
+    return win;
 }
 
-CWriteWindow* CDisplayWindowFactory::createWriteInstance(QList<CSwordModuleInfo*> modules, CMDIArea* parent, const CDisplayWindow::WriteWindowType type) {
-    if (type == CDisplayWindow::HTMLWindow) {
+CWriteWindow* CDisplayWindowFactory::createWriteInstance(QList<CSwordModuleInfo*> modules, CMDIArea* parent, const CWriteWindow::WriteWindowType type) {
+    if (type == CWriteWindow::HTMLWindow) {
         return new CHTMLWriteWindow(modules, parent);
     }
     else {
@@ -50,3 +55,15 @@ CWriteWindow* CDisplayWindowFactory::createWriteInstance(QList<CSwordModuleInfo*
     }
     return 0;
 }
+
+const CSwordModuleInfo::ModuleType CDisplayWindowFactory::getModuleType(QObject* widget) {
+    if (qobject_cast<CBibleReadWindow*>(widget) != 0 )
+        return CSwordModuleInfo::Bible;
+    if (qobject_cast<CCommentaryReadWindow*>(widget) != 0 )
+        return CSwordModuleInfo::Commentary;
+    if (qobject_cast<CBookReadWindow*>(widget) != 0 )
+        return CSwordModuleInfo::GenericBook;
+    if (qobject_cast<CLexiconReadWindow*>(widget) != 0 )
+        return CSwordModuleInfo::Lexicon;
+    return CSwordModuleInfo::Unknown;
+}
