@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -15,7 +15,11 @@
 
 class QAction;
 
-/** The WYSIWYG implementation of the editor.
+/** 
+ * The write window class which offers a WYSIWYG text editor for creating a personal commentary.
+  *
+  * Inherits CPlainWriteWindow.
+  *
   * @author The BibleTime team
   */
 class CHTMLWriteWindow : public CPlainWriteWindow  {
@@ -28,11 +32,15 @@ class CHTMLWriteWindow : public CPlainWriteWindow  {
         * Store the settings of this window in the given CProfileWindow object.
         */
         virtual void storeProfileSettings( Profile::CProfileWindow* );
+
         /**
         * Store the settings of this window in the given profile window.
         */
         virtual void applyProfileSettings( Profile::CProfileWindow* );
 
+        /**
+         * Returns true if the sync toolbar is enabled.
+         */
         virtual bool syncAllowed() const;
 
     protected:
@@ -42,9 +50,20 @@ class CHTMLWriteWindow : public CPlainWriteWindow  {
         virtual void initView();
         virtual void initConnections();
         virtual void initToolbars();
-        virtual CDisplayWindow::WriteWindowType writeWindowType() {
-            return CDisplayWindow::HTMLWindow;
+        virtual void initActions();
+
+        /**
+        * Insert the keyboard accelerators of this window into the given KAccel object.
+        */
+        static void insertKeyboardActions( BtActionCollection* const a );
+
+        virtual CWriteWindow::WriteWindowType writeWindowType() {
+            return CWriteWindow::HTMLWindow;
         }
+        /** 
+         * Called to add actions to mainWindow toolbars 
+         */
+        virtual void setupMainWindowToolBars();
 
     protected slots:
         /**
@@ -59,14 +78,6 @@ class CHTMLWriteWindow : public CPlainWriteWindow  {
         * Saves the text for the current key. Directly writes the changed text into the module.
         */
         virtual void saveCurrentText( const QString& );
-    private:
-        struct {
-            QAction* saveText;
-            QAction* restoreText;
-            QAction* deleteEntry;
-            QAction* syncWindow;
-        }
-        m_actions;
 };
 
 #endif
