@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -17,7 +17,12 @@ class BtActionCollection;
 class QAction;
 class QString;
 
-/** The write window class which offers a plain editor for source code editing.
+/** The write window class which offers a plain text editor for creating a personal commentary.
+  *
+  * Inherits CWriteWindow.
+  *
+  * Inherited by CHTMLWriteWindow.
+  *
   * @author The BibleTime team
   */
 class CPlainWriteWindow : public CWriteWindow  {
@@ -39,6 +44,10 @@ class CPlainWriteWindow : public CWriteWindow  {
          * Setups the popup menu of this display widget.
          */
         virtual void setupPopupMenu();
+
+        /**
+         * Returns true if the sync toolbar is enabled.
+         */
         virtual bool syncAllowed() const;
 
     protected: // Protected methods
@@ -48,10 +57,12 @@ class CPlainWriteWindow : public CWriteWindow  {
         virtual void initView();
         virtual void initConnections();
         virtual void initToolbars();
-        virtual CDisplayWindow::WriteWindowType writeWindowType() {
-            return CDisplayWindow::PlainTextWindow;
+        virtual CWriteWindow::WriteWindowType writeWindowType() {
+            return CWriteWindow::PlainTextWindow;
         };
 
+        /** Called to add actions to mainWindow toolbars */
+        virtual void setupMainWindowToolBars();
         /**
          * Initializes the intern keyboard actions.
          */
@@ -61,15 +72,6 @@ class CPlainWriteWindow : public CWriteWindow  {
         */
         static void insertKeyboardActions( BtActionCollection* const a );
 
-    private:
-        struct {
-            QAction* saveText;
-            QAction* deleteEntry;
-            QAction* restoreText;
-            QAction* syncWindow;
-        }
-        m_actions;
-
     protected slots: // Protected slots
         /**
         * Saves the text for the current key. Directly writes the changed text into the module.
