@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -83,13 +83,13 @@ void CReadWindow::lookupSwordKey( CSwordKey* newKey ) {
 
     using namespace Rendering;
 
-//	Q_ASSERT(isReady() && newKey && modules().first());
+//    Q_ASSERT(isReady() && newKey && modules().first());
     if (!isReady() || !newKey || modules().empty() || !modules().first()) {
         return;
     }
 
     if (key() != newKey) {
-        key()->key(newKey->key());
+        key()->setKey(newKey->key());
     }
 
     /// \todo next-TODO how about options?
@@ -146,11 +146,8 @@ void CReadWindow::storeProfileSettings(CProfileWindow * const settings) {
     }
 
     QStringList mods;
-
-    QList<CSwordModuleInfo*> allMods = modules();
-    QList<CSwordModuleInfo*>::iterator end_it = allMods.end();
-    for (QList<CSwordModuleInfo*>::iterator it(allMods.begin()); it != end_it; ++it) {
-        mods.append((*it)->name());
+    Q_FOREACH (const CSwordModuleInfo *module, modules()) {
+        mods.append(module->name());
     }
     settings->setModules(mods);
 }
@@ -191,7 +188,7 @@ void CReadWindow::resizeEvent(QResizeEvent* /*e*/) {
 }
 
 void CReadWindow::openSearchStrongsDialog() {
-//	qWarning("looking for lemma %s",  displayWidget()->getCurrentNodeInfo()[CDisplay::Lemma].latin1() );
+//    qWarning("looking for lemma %s",  displayWidget()->getCurrentNodeInfo()[CDisplay::Lemma].latin1() );
     QString searchText = QString::null;
 
     if (displayWidget()->getCurrentNodeInfo()[CDisplay::Lemma] != QString::null) {
