@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -20,12 +20,18 @@ class BtActionCollection;
 class QResizeEvent;
 
 /** The base class for all read-only display windows.
+  *
+  * Inherits CDisplayWindow.
+  *
+  * Inherited by CLexiconReadWindow
+  *
   * @author The BibleTime team
   */
 class CReadWindow : public CDisplayWindow  {
         Q_OBJECT
     public:
 
+        /** Insert the keyboard accelerators of this window into the given actioncollection.*/
         static void insertKeyboardActions( BtActionCollection* const a );
 
         CReadWindow(QList<CSwordModuleInfo*> modules, CMDIArea* parent);
@@ -35,7 +41,7 @@ class CReadWindow : public CDisplayWindow  {
         */
         virtual void storeProfileSettings(Profile::CProfileWindow * const settings);
         /**
-        * Store the settings of this window in the given CProfileWindow object.
+        * Load the settings the given CProfileWindow object into this window.
         */
         virtual void applyProfileSettings(Profile::CProfileWindow * const settings);
 
@@ -45,9 +51,13 @@ class CReadWindow : public CDisplayWindow  {
         */
         virtual void setDisplayWidget( CDisplay* newDisplay );
         /**
+         * Reimplemented Qt function for resize of window.
          */
         virtual void resizeEvent(QResizeEvent* e);
 
+        /** Called to add actions to mainWindow toolbars.*/
+        virtual void setupMainWindowToolBars() = 0;
+
     protected slots:
         /**
         * Load the text using the key
@@ -62,8 +72,8 @@ class CReadWindow : public CDisplayWindow  {
         * Update the status of the popup menu entries.
         */
         virtual void copyDisplayedText();
-        /** Open the search dialog with the strong info of the last clicked word.
-         *
+        /** 
+         * Open the search dialog with the strong info of the last clicked word.
         */
         void openSearchStrongsDialog();
 
