@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -65,10 +65,8 @@ void CWriteWindow::storeProfileSettings(CProfileWindow * const settings) {
     }
 
     QStringList mods;
-    QList<CSwordModuleInfo*> allMods = modules();
-    QList<CSwordModuleInfo*>::iterator end_it = allMods.end();
-    for (QList<CSwordModuleInfo*>::iterator it(allMods.begin()); it != end_it; ++it) {
-        mods.append((*it)->name());
+    Q_FOREACH(const CSwordModuleInfo *m, modules()) {
+        mods.append(m->name());
     }
     settings->setModules(mods);
 }
@@ -103,7 +101,7 @@ void CWriteWindow::lookupSwordKey( CSwordKey* newKey ) {
         return;
 
     if (key() != newKey) { //set passage of newKey to key() if they're different, otherwise we'd get mixed up if we look up newkey which may have a different module set
-        key()->key(newKey->key());
+        key()->setKey(newKey->key());
     }
 
     if ( modules().count() ) {
