@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -18,11 +18,22 @@ class CWriteDisplay;
 class QString;
 
 /** The base class for all write-only display windows.
+  *
+  * Inherits CDisplayWindow.
+  *
+  * Inherited by CPlainWriteWindow.
+  *
   *@author The BibleTime team
   */
 class CWriteWindow : public CDisplayWindow  {
         Q_OBJECT
     public:
+        enum WriteWindowType {
+            HTMLWindow = 1,
+            PlainTextWindow = 2
+        };
+
+        /** Insert the keyboard accelerators of this window into the given actioncollection.*/
         static void insertKeyboardActions( BtActionCollection* const a );
 
         CWriteWindow(QList<CSwordModuleInfo*> modules, CMDIArea* parent);
@@ -32,10 +43,14 @@ class CWriteWindow : public CDisplayWindow  {
         */
         virtual void storeProfileSettings(Profile::CProfileWindow * const settings);
         /**
-        * Store the settings of this window in the given CProfileWindow object.
+        * Load the settings the given CProfileWindow object into this window.
         */
         virtual void applyProfileSettings(Profile::CProfileWindow * const settings);
+
+        /** Initializes the signal / slot connections of this display window.*/
         virtual void initConnections();
+
+        /** Initializes the internel keyboard actions.*/
         virtual void initActions();
 
     public slots:
@@ -47,14 +62,22 @@ class CWriteWindow : public CDisplayWindow  {
 
     protected: // Protected methods
         /**
-        * Saves the given text as text of the given key. Use this function
-        * as backend in each write window implementation.
+        * Set the displayWidget which is a subclass of QWebPage.
         */
         void setDisplayWidget( CDisplay* display );
-        virtual CDisplayWindow::WriteWindowType writeWindowType() = 0;
+
+        /** Returns the type of the write window.*/
+        virtual CWriteWindow::WriteWindowType writeWindowType() = 0;
+
+        /** Returns true if the window may be closed.*/
         virtual bool queryClose();
+
+        /** Saves the text for the current key. Directly writes the changed text into the module. */
         virtual void saveCurrentText( const QString& key ) = 0;
 
+        /** Called to add actions to mainWindow toolbars */
+        virtual void setupMainWindowToolBars() = 0;
+
     protected slots:
         /** Save text to the module
         */
