@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -12,7 +12,6 @@
 #include <QApplication>
 #include <QDebug>
 #include <QHBoxLayout>
-#include <QHeaderView>
 #include <QTreeWidget>
 #include <QTreeWidgetItem>
 #include "backend/config/cbtconfig.h"
@@ -21,8 +20,9 @@
 #include "frontend/keychooser/bthistory.h"
 
 
-CBookTreeChooser::CBookTreeChooser(QList<CSwordModuleInfo*> modules, CSwordKey *key, QWidget *parent)
-        : CKeyChooser(modules, key, parent),
+CBookTreeChooser::CBookTreeChooser(const QList<const CSwordModuleInfo*> &modules,
+                                   BTHistory* historyPtr, CSwordKey *key, QWidget *parent)
+        : CKeyChooser(modules, historyPtr, key, parent),
         m_key( dynamic_cast<CSwordTreeKey*>(key) ) {
 
     setModules(modules, false);
@@ -40,7 +40,7 @@ CBookTreeChooser::CBookTreeChooser(QList<CSwordModuleInfo*> modules, CSwordKey *
     layout->setSpacing(0);
     layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(m_treeView);
-    m_treeView->header()->hide();
+    m_treeView->setHeaderHidden(true);
 
     //when user selects the item whe must react
     connect(m_treeView, SIGNAL(currentItemChanged ( QTreeWidgetItem*, QTreeWidgetItem*)), SLOT(itemActivated(QTreeWidgetItem*)));
@@ -50,8 +50,6 @@ CBookTreeChooser::CBookTreeChooser(QList<CSwordModuleInfo*> modules, CSwordKey *
     connect(this, SIGNAL(keyChanged(CSwordKey*)), history(), SLOT(add(CSwordKey*)) );
 }
 
-CBookTreeChooser::~CBookTreeChooser() {}
-
 /** Sets a new key to this keychooser. Inherited from ckeychooser. */
 void CBookTreeChooser::setKey(CSwordKey* key) {
     setKey(key, false);
@@ -86,20 +84,16 @@ void CBookTreeChooser::setKey(CSwordKey* newKey, const bool emitSignal) {
     }
 }
 
-/** Returns the key of this keychooser. Inherited from ckeychooser.*/
-CSwordKey*  CBookTreeChooser::key() {
-    return m_key;
-}
-
-/** Sets another module to this keychooser. Inherited from ckeychooser (therefore
-the list of modules instead of one). */
-void CBookTreeChooser::setModules(const QList<CSwordModuleInfo*>& modules, const bool refresh) {
+void CBookTreeChooser::setModules(const QList<const CSwordModuleInfo*> &modules,
+                                  bool refresh)
+{
+    typedef CSwordBookModuleInfo CSBMI;
 
     //Add given modules into private list
     m_modules.clear();
-    QList<CSwordModuleInfo*>::const_iterator end_it = modules.end();
-    for (QList<CSwordModuleInfo*>::const_iterator it(modules.begin()); it != end_it; ++it) {
-        if (CSwordBookModuleInfo* book = dynamic_cast<CSwordBookModuleInfo*>(*it)) {
+    Q_FOREACH (const CSwordModuleInfo *m, modules) {
+        const CSBMI *book = dynamic_cast<const CSBMI*>(m);
+        if (book != 0) {
             m_modules.append(book);
         }
     }
@@ -139,7 +133,7 @@ void CBookTreeChooser::itemActivated( QTreeWidgetItem* item ) {
     qDebug() << "CBookTreeChooser::itemActivated";
     //Sometimes Qt calls this function with a null pointer.
     if (item) {
-        m_key->key(item->text(1));
+        m_key->setKey(item->text(1));
         //tell possible listeners about the change
         emit keyChanged(m_key);
     }
@@ -193,6 +187,6 @@ void CBookTreeChooser::addKeyChildren(CSwordTreeKey* key, QTreeWidgetItem* item)
 }
 
 void CBookTreeChooser::setKey(QString& newKey) {
-    m_key->key(newKey);
+    m_key->setKey(newKey);
     setKey(m_key);
 }
