@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -127,7 +127,7 @@ void CKeyChooserWidget::reset(const int count, int index, bool do_emit) {
     //This prevents the widget from resetting during application load, which
     //produces undesirable behavior.
     //if (!updatesEnabled())
-    //	return;
+    //    return;
 
     m_list.clear();
     for (int i = 1; i <= count; i++) { /// \todo CHECK
@@ -137,18 +137,18 @@ void CKeyChooserWidget::reset(const int count, int index, bool do_emit) {
     reset(&m_list, index, do_emit);
 }
 
-void CKeyChooserWidget::reset(QStringList& list, int index, bool do_emit) {
+void CKeyChooserWidget::reset(const QStringList &list, int index, bool do_emit) {
     //This prevents the widget from resetting during application load, which
     //produces undesirable behavior.
     //if (!updatesEnabled())
-    //	return;
+    //    return;
 
     m_list = list;
     reset(&m_list, index, do_emit);
 }
 
 
-void CKeyChooserWidget::reset(QStringList *list, int index, bool do_emit) {
+void CKeyChooserWidget::reset(const QStringList *list, int index, bool do_emit) {
     //if (isResetting || !updatesEnabled())
     if (isResetting)
         return;
@@ -239,7 +239,7 @@ void CKeyChooserWidget::slotReturnPressed( /*const QString& text*/) {
     QString text = comboBox()->lineEdit()->text();
     for (int index = 0; index < comboBox()->count(); ++index) {
         if (comboBox()->itemText(index) == text) {
-//			emit changed(index);
+//            emit changed(index);
             emit focusOut(index); // a workaround because focusOut is not checked, the slot connected to changed to check
             break;
         }
