@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -63,15 +63,15 @@ class CKCComboBox : public QComboBox {
   */
 class CKeyChooserWidget : public QWidget  {
         Q_OBJECT
+
     public:
-        /**
-        * the constructor
-        */
-        CKeyChooserWidget(QStringList *list = 0, const bool useNextPrevSignals = false, QWidget *parent = 0 );
-        /**
-        * the constructor
-        */
-        CKeyChooserWidget(int count = 0, const bool useNextPrevSignals = false, QWidget *parent = 0 );
+        CKeyChooserWidget(QStringList *list = 0,
+                          const bool useNextPrevSignals = false,
+                          QWidget *parent = 0);
+
+        CKeyChooserWidget(int count = 0, const bool useNextPrevSignals = false,
+                          QWidget *parent = 0);
+
         /**
         * This function does clear the combobox, then fill in
         * the StringList, set the ComboBox' current item to index
@@ -82,8 +82,9 @@ class CKeyChooserWidget : public QWidget  {
         * @param do_emit should we emit @ref #changed(int)
         */
         void reset(const int count, int index, bool do_emit);
-        void reset(QStringList& list, int index, bool do_emit);
-        void reset(QStringList *list, int index, bool do_emit);
+        void reset(const QStringList &list, int index, bool do_emit);
+        void reset(const QStringList *list, int index, bool do_emit);
+
         /**
         * Initializes this widget. We need this function because
         * we have more than one constructor.
