@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -48,7 +48,7 @@ const QList<CProfile*>& CProfileMgr::profiles() {
 }
 
 /** Creates a new profile with the name "name" (first parameter).  @return The profile object */
-CProfile* CProfileMgr::create( const QString name ) {
+CProfile *CProfileMgr::create(const QString &name) {
     CProfile* p = new CProfile(QString::null, name);
     m_profiles.append(p);
 
