@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -15,8 +15,12 @@
 #include <QColor>
 #include <QHash>
 #include <QMap>
+#include "backend/cswordmodulesearch.h"
 #include "frontend/searchdialog/analysis/csearchanalysisitem.h"
 
+// Sword includes
+#include <listkey.h>
+
 
 class CSwordModuleInfo;
 
@@ -39,16 +43,14 @@ class CSearchAnalysisScene : public QGraphicsScene {
         * This should be called only once because
         * QCanvas handles the updates automatically.
         */
-        void analyse(QList<CSwordModuleInfo*> modules);
+        void analyse(const CSwordModuleSearch::Results &results);
+
         /**
         * This function returns a color for each module
         * @return The color at position index in the list
         */
         static QColor getColor(int index);
-        /**
-        * This function returns a pointer to the list of AnalysisItems
-        */
-        QHash<QString, CSearchAnalysisItem*>* getSearchAnalysisItemList();
+
         void reset();
         /**
          * resize the height of the scene
@@ -65,17 +67,17 @@ class CSearchAnalysisScene : public QGraphicsScene {
         void slotResized();
 
     protected:
-        void setModules(QList<CSwordModuleInfo*> modules);
+        void setResults(const CSwordModuleSearch::Results &results);
 
     private:
         /**
         * Returns the count of the book in the module
         */
-        unsigned int getCount( const QString book, CSwordModuleInfo* module );
+        unsigned int getCount(const QString &book, const CSwordModuleInfo *module);
 
-        QList<CSwordModuleInfo*> m_moduleList;
+        CSwordModuleSearch::Results m_results;
         QHash<QString, CSearchAnalysisItem*> m_itemList;
-        QMap<CSwordModuleInfo*, unsigned int> m_lastPosList;
+        QMap<const CSwordModuleInfo*, unsigned int> m_lastPosList;
         int m_maxCount;
         double m_scaleFactor;
         CSearchAnalysisLegendItem* m_legend;
