@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -12,6 +12,7 @@
 #include <QApplication>
 #include <QDebug>
 #include <QFrame>
+#include <QMenu>
 #include <QProgressDialog>
 #include <QPushButton>
 #include <QSize>
@@ -22,8 +23,6 @@
 #include "backend/keys/cswordversekey.h"
 #include "backend/rendering/cdisplayrendering.h"
 #include "frontend/display/cdisplay.h"
-#include "frontend/display/creaddisplay.h"
-#include "frontend/searchdialog/analysis/csearchanalysisdialog.h"
 #include "frontend/searchdialog/cmoduleresultview.h"
 #include "frontend/searchdialog/csearchdialog.h"
 #include "frontend/searchdialog/csearchresultview.h"
@@ -40,10 +39,6 @@ BtSearchResultArea::BtSearchResultArea(QWidget *parent)
     qDebug() << "BtSearchResultArea::BtSearchResultArea end";
 }
 
-BtSearchResultArea::~BtSearchResultArea() {
-    saveDialogSettings();
-}
-
 void BtSearchResultArea::initView() {
     QVBoxLayout *mainLayout;
     QWidget *resultListsWidget;
@@ -54,32 +49,32 @@ void BtSearchResultArea::initView() {
     int mWidth = util::tool::mWidth(this, 1);
     this->setMinimumSize(QSize(mWidth*40, mWidth*15));
     mainLayout = new QVBoxLayout(this);
-    mainSplitter = new QSplitter(this);
-    mainSplitter->setOrientation(Qt::Horizontal);
+    m_mainSplitter = new QSplitter(this);
+    m_mainSplitter->setOrientation(Qt::Horizontal);
 
-    resultListsWidget = new QWidget(mainSplitter);
+    resultListsWidget = new QWidget(m_mainSplitter);
 
     resultListsWidgetLayout = new QVBoxLayout(resultListsWidget);
     resultListsWidgetLayout->setContentsMargins(0, 0, 0, 0);
 
     //Splitter for two result lists
-    resultListSplitter = new QSplitter(resultListsWidget);
-    resultListSplitter->setOrientation(Qt::Vertical);
-    m_moduleListBox = new CModuleResultView(resultListSplitter);
-    resultListSplitter->addWidget(m_moduleListBox);
-    m_resultListBox = new CSearchResultView(resultListSplitter);
-    resultListSplitter->addWidget(m_resultListBox);
-    resultListsWidgetLayout->addWidget(resultListSplitter);
+    m_resultListSplitter = new QSplitter(resultListsWidget);
+    m_resultListSplitter->setOrientation(Qt::Vertical);
+    m_moduleListBox = new CModuleResultView(m_resultListSplitter);
+    m_resultListSplitter->addWidget(m_moduleListBox);
+    m_resultListBox = new CSearchResultView(m_resultListSplitter);
+    m_resultListSplitter->addWidget(m_resultListBox);
+    resultListsWidgetLayout->addWidget(m_resultListSplitter);
 
-    mainSplitter->addWidget(resultListsWidget);
+    m_mainSplitter->addWidget(resultListsWidget);
 
     //Preview ("info") area
-    m_displayFrame = new QFrame(mainSplitter);
+    m_displayFrame = new QFrame(m_mainSplitter);
     m_displayFrame->setFrameShape(QFrame::NoFrame);
     m_displayFrame->setFrameShadow(QFrame::Plain);
-    mainSplitter->addWidget(m_displayFrame);
+    m_mainSplitter->addWidget(m_displayFrame);
 
-    mainLayout->addWidget(mainSplitter);
+    mainLayout->addWidget(m_mainSplitter);
 
     QVBoxLayout* frameLayout = new QVBoxLayout(m_displayFrame);
     frameLayout->setContentsMargins(0, 0, 0, 0);
@@ -87,20 +82,38 @@ void BtSearchResultArea::initView() {
     m_previewDisplay->view()->setToolTip(tr("Text of the selected search result item"));
     frameLayout->addWidget(m_previewDisplay->view());
 
+    QAction* selectAllAction = new QAction(QIcon(), tr("Select all"), this);
+    selectAllAction->setShortcut(QKeySequence::SelectAll);
+    QObject::connect(selectAllAction, SIGNAL(triggered()), this, SLOT(selectAll()) );
+
+    QAction* copyAction = new QAction(tr("Copy"), this);
+    copyAction->setShortcut( QKeySequence(Qt::CTRL + Qt::Key_C) );
+    QObject::connect(copyAction, SIGNAL(triggered()), this, SLOT(copySelection()) );
+
+    QMenu* menu = new QMenu();
+    menu->addAction(selectAllAction);
+    menu->addAction(copyAction);
+    m_previewDisplay->installPopup(menu);
+
     loadDialogSettings();
 }
 
-void BtSearchResultArea::setSearchResult(QList<CSwordModuleInfo*> modules) {
+void BtSearchResultArea::setSearchResult(
+        const CSwordModuleSearch::Results &results)
+{
     const QString searchedText = CSearchDialog::getSearchDialog()->searchText();
     reset(); //clear current modules
 
-    m_modules = modules;
-    //pre-select the first module in the list
-    //this will pre-select and display the first hit of that module
-    m_moduleListBox->setupTree(modules, searchedText);
+    m_results = results;
+
+    // Populate listbox:
+    m_moduleListBox->setupTree(results, searchedText);
+
+    // Pre-select the first module in the list:
     m_moduleListBox->setCurrentItem(m_moduleListBox->topLevelItem(0), 0);
 
-    qobject_cast<CSearchDialog*>(parent())->m_analyseButton->setEnabled(true);
+    Q_ASSERT(qobject_cast<CSearchDialog*>(parent()) != 0);
+    static_cast<CSearchDialog*>(parent())->m_analyseButton->setEnabled(true);
 }
 
 void BtSearchResultArea::reset() {
@@ -108,7 +121,6 @@ void BtSearchResultArea::reset() {
     m_resultListBox->clear();
     m_previewDisplay->setText("<html><head/><body></body></html>");
     qobject_cast<CSearchDialog*>(parent())->m_analyseButton->setEnabled(false);
-    m_modules.clear();
 }
 
 void BtSearchResultArea::clearPreview() {
@@ -125,7 +137,7 @@ void BtSearchResultArea::updatePreview(const QString& key) {
         QString text;
         CDisplayRendering render;
 
-        QList<CSwordModuleInfo*> modules;
+        QList<const CSwordModuleInfo*> modules;
         modules.append(module);
 
         CTextRendering::KeyTreeItem::Settings settings;
@@ -134,7 +146,7 @@ void BtSearchResultArea::updatePreview(const QString& key) {
         if (module->type() == CSwordModuleInfo::Bible) {
             CSwordVerseKey vk(module);
             vk.Headings(1);
-            vk.key(key);
+            vk.setKey(key);
 
             ((sword::VerseKey*)(module->module()->getKey()))->Headings(1); //HACK: enable headings for VerseKeys
 
@@ -152,7 +164,7 @@ void BtSearchResultArea::updatePreview(const QString& key) {
 
             const QString startKey = vk.key();
 
-            vk.key(key);
+            vk.setKey(key);
 
             vk.next(CSwordVerseKey::UseVerse);
             vk.next(CSwordVerseKey::UseVerse);
@@ -165,7 +177,7 @@ void BtSearchResultArea::updatePreview(const QString& key) {
         else if (module->type() == CSwordModuleInfo::Commentary) {
             CSwordVerseKey vk(module);
             vk.Headings(1);
-            vk.key(key);
+            vk.setKey(key);
 
             ((sword::VerseKey*)(module->module()->getKey()))->Headings(1); //HACK: enable headings for VerseKeys
 
@@ -178,7 +190,7 @@ void BtSearchResultArea::updatePreview(const QString& key) {
             }
             const QString startKey = vk.key();
 
-            vk.key(key);
+            vk.setKey(key);
             const QString endKey = vk.key();
 
             settings.keyRenderingFace = CTextRendering::KeyTreeItem::Settings::NoKey;
@@ -193,7 +205,7 @@ void BtSearchResultArea::updatePreview(const QString& key) {
     }
 }
 
-QStringList BtSearchResultArea::QueryParser(const QString& queryString) {
+QStringList BtSearchResultArea::queryParser(const QString& queryString) {
     QString token;
     QStringList tokenList;
     int cnt, pos;
@@ -226,13 +238,13 @@ QStringList BtSearchResultArea::QueryParser(const QString& queryString) {
         }
         // wild card - treat as a special token break
         //else if (queryString[cnt] == '*') {
-        //	token = token + queryString[cnt];
-        //	token = token.simplified();
-        //	if ((token != "*") && (token != ""))
-        //		tokenList.append(token);
-        //	// start next token with wildcard (kin*m -> kin* *m)
-        //	token = "*";
-        //	cnt++;
+        //    token = token + queryString[cnt];
+        //    token = token.simplified();
+        //    if ((token != "*") && (token != ""))
+        //        tokenList.append(token);
+        //    // start next token with wildcard (kin*m -> kin* *m)
+        //    token = "*";
+        //    cnt++;
         //}
         // the ! token is also a token break
         else if (queryString[cnt] == '!') {
@@ -423,20 +435,20 @@ QString BtSearchResultArea::highlightSearchedText(const QString& content, const
     //char buf8[1000];
     //standard::WhitespaceAnalyzer analyzer;
     //lucene_utf8towcs(m_wcharBuffer, searchedText.utf8(), MAX_CONV_SIZE);
-    //boost::scoped_ptr<Query> q( QueryParser::parse(m_wcharBuffer, _T("content"), &analyzer) );
+    //QSharedPointer<Query> q( QueryParser::parse(m_wcharBuffer, _T("content"), &analyzer) );
     //StringReader reader(m_wcharBuffer);
     //TokenStream* tokenStream = analyzer.tokenStream( _T("field"), &reader);
     //Token token;
     //while(tokenStream->next(&token) != 0) {
-    //	lucene_wcstoutf8(buf8, token.termText(), 1000);
-    //	printf("%s\n", buf8);
+    //    lucene_wcstoutf8(buf8, token.termText(), 1000);
+    //    printf("%s\n", buf8);
     //}
 
     //===========================================================
     // since I could not figure out the lucene query parser, I
     // made a simple parser.
     //===========================================================
-    QStringList words = QueryParser(newSearchText);
+    QStringList words = queryParser(newSearchText);
     qDebug() << "btsearchresultarea.cpp: " << __LINE__ << ": " <<  words << '\n';
     foreach (QString word, words) { //search for every word in the list
         QRegExp findExp;
@@ -481,18 +493,15 @@ QString BtSearchResultArea::highlightSearchedText(const QString& content, const
 void BtSearchResultArea::initConnections() {
     connect(m_resultListBox, SIGNAL(keySelected(const QString&)), this, SLOT(updatePreview(const QString&)));
     connect(m_resultListBox, SIGNAL(keyDeselected()), this, SLOT(clearPreview()));
-    connect(m_moduleListBox, SIGNAL(moduleSelected(CSwordModuleInfo*)), m_resultListBox, SLOT(setupTree(CSwordModuleInfo*)));
+    connect(m_moduleListBox,
+            SIGNAL(moduleSelected(const CSwordModuleInfo*, const sword::ListKey&)),
+            m_resultListBox,
+            SLOT(setupTree(const CSwordModuleInfo*, const sword::ListKey&)));
     connect(m_moduleListBox, SIGNAL(moduleChanged()), m_previewDisplay->connectionsProxy(), SLOT(clear()));
 
     // connect the strongs list
-    connect(m_moduleListBox, SIGNAL(strongsSelected(CSwordModuleInfo*, QStringList*)),
-            m_resultListBox, SLOT(setupStrongsTree(CSwordModuleInfo*, QStringList*)));
-}
-
-/** Shows a dialog with the search analysis of the current search. */
-void BtSearchResultArea::showAnalysis() {
-    CSearchAnalysisDialog dlg(m_modules, this);
-    dlg.exec();
+    connect(m_moduleListBox, SIGNAL(strongsSelected(CSwordModuleInfo*, const QStringList&)),
+            m_resultListBox, SLOT(setupStrongsTree(CSwordModuleInfo*, const QStringList&)));
 }
 
 /**
@@ -501,127 +510,97 @@ void BtSearchResultArea::showAnalysis() {
 void BtSearchResultArea::loadDialogSettings() {
     QList<int> mainSplitterSizes = CBTConfig::get(CBTConfig::searchMainSplitterSizes);
     if (mainSplitterSizes.count() > 0) {
-        mainSplitter->setSizes(mainSplitterSizes);
+        m_mainSplitter->setSizes(mainSplitterSizes);
     }
     else {
         int w = this->size().width();
         int w2 = m_moduleListBox->sizeHint().width();
         mainSplitterSizes << w2 << w - w2;
-        mainSplitter->setSizes(mainSplitterSizes);
+        m_mainSplitter->setSizes(mainSplitterSizes);
     }
     QList<int> resultSplitterSizes = CBTConfig::get(CBTConfig::searchResultSplitterSizes);
-    if (resultSplitterSizes.count() > 0) resultListSplitter->setSizes(resultSplitterSizes);
+    if (resultSplitterSizes.count() > 0) m_resultListSplitter->setSizes(resultSplitterSizes);
 }
 
 /**
 * Save the settings to the resource file
 */
 void BtSearchResultArea::saveDialogSettings() {
-    CBTConfig::set(CBTConfig::searchMainSplitterSizes, mainSplitter->sizes());
-    CBTConfig::set(CBTConfig::searchResultSplitterSizes, resultListSplitter->sizes());
+    CBTConfig::set(CBTConfig::searchMainSplitterSizes, m_mainSplitter->sizes());
+    CBTConfig::set(CBTConfig::searchResultSplitterSizes, m_resultListSplitter->sizes());
 }
 
-StrongsResult::StrongsResult() {
-}
+/******************************************************************************
+* StrongsResultList:
+******************************************************************************/
 
-StrongsResult::StrongsResult(const QString& text, const QString &keyName)
-        : text(text) {
-    //keyNameList.clear();
-    keyNameList.append(keyName);
-}
-
-QString StrongsResult::keyText() const {
-    return text;
-}
-
-int StrongsResult::keyCount() const {
-    return keyNameList.count();
-}
-
-void StrongsResult::addKeyName(const QString& keyName) {
-    if (keyNameList.indexOf(keyName) == -1)
-        keyNameList.append(keyName);
-}
-
-QStringList* StrongsResult::getKeyList() {
-    return & keyNameList;
-}
-
-
-
-/********************************************
-************  StrongsResultClass *************
-********************************************/
-void StrongsResultClass::initStrongsResults(void) {
+StrongsResultList::StrongsResultList(const CSwordModuleInfo *module,
+                                     const sword::ListKey &results,
+                                     const QString &strongsNumber)
+{
     using namespace Rendering;
 
-    CDisplayRendering render;
-    QList<CSwordModuleInfo*> modules;
-    CTextRendering::KeyTreeItem::Settings settings;
-    QString rText, lText, key;
-    bool found;
-    int sIndex;
-    int count;
-    int index;
-    QString text;
+    /// \warning This is a workaround for Sword constness
+    sword::ListKey result = results;
 
-    modules.append(srModule);
-    sword::ListKey& result = srModule->searchResult();
-
-    count = result.Count();
+    int count = result.Count();
     if (!count)
         return;
-    qApp->processEvents( QEventLoop::AllEvents, 1 ); //1 ms only
-    srList.clear();
+
+    CTextRendering::KeyTreeItem::Settings settings;
+    QList<const CSwordModuleInfo*> modules;
+    modules.append(module);
+    clear();
+
     // for whatever reason the text "Parsing...translations." does not appear.
     // this is not critical but the text is necessary to get the dialog box
     // to be wide enough.
-    QProgressDialog* progress = new QProgressDialog(QObject::tr("Parsing Strong's Numbers"), 0, 0, count);
+    QProgressDialog progress(QObject::tr("Parsing Strong's Numbers"), 0, 0, count);
     //0, "progressDialog", tr("Parsing Strong's Numbers"), tr("Parsing Strong's numbers for translations."), true);
-
     //progress->setAllowCancel(false);
     //progress->setMinimumDuration(0);
-    progress->show();
-    progress->raise();
-    for (index = 0; index < count; index++) {
-        progress->setValue( index );
-        qApp->processEvents(QEventLoop::AllEvents, 1 ); //1 ms only
+    progress.show();
+    progress.raise();
 
-        key = QString::fromUtf8(result.GetElement(index)->getText());
-        text = render.renderSingleKey(key, modules, settings);
-        sIndex = 0;
-        while ((rText = getStrongsNumberText(text, &sIndex)) != "") {
-            StrongsResultList::iterator it;
-            found = FALSE;
-            for ( it = srList.begin(); it != srList.end(); ++it ) {
-                lText = (*it).keyText();
-                if (lText == rText) {
-                    found = TRUE;
+    qApp->processEvents(QEventLoop::AllEvents, 1); //1 ms only
+
+    for (int index = 0; index < count; index++) {
+        progress.setValue(index);
+        qApp->processEvents(QEventLoop::AllEvents, 1); //1 ms only
+
+        QString key = QString::fromUtf8(result.GetElement(index)->getText());
+        QString text = CDisplayRendering().renderSingleKey(key, modules, settings);
+        for (int sIndex = 0;;) {
+            continueloop:
+            QString rText = getStrongsNumberText(text, sIndex, strongsNumber);
+            if (rText.isEmpty()) break;
+
+            for (iterator it = begin(); it != end(); ++it) {
+                if ((*it).keyText() == rText) {
                     (*it).addKeyName(key);
-                    break;
+                    goto continueloop; // break, then continue
                 }
             }
-            if (found == FALSE)
-                srList.append( StrongsResult(rText, key) );
+            append(StrongsResult(rText, key));
         }
     }
-    delete progress;
-    progress = 0;
-    //qHeapSort(srList);
 }
 
-QString StrongsResultClass::getStrongsNumberText(const QString& verseContent, int *startIndex) {
+QString StrongsResultList::getStrongsNumberText(const QString &verseContent,
+                                                int &startIndex,
+                                                const QString &lemmaText)
+{
     // get the strongs text
     int idx1, idx2, index;
     QString sNumber, strongsText;
     //const bool cs = CSwordModuleSearch::caseSensitive;
     const Qt::CaseSensitivity cs = Qt::CaseInsensitive;
 
-    if (*startIndex == 0) {
+    if (startIndex == 0) {
         index = verseContent.indexOf("<body");
     }
     else {
-        index = *startIndex;
+        index = startIndex;
     }
 
     // find all the "lemma=" inside the the content
@@ -639,7 +618,7 @@ QString StrongsResultClass::getStrongsNumberText(const QString& verseContent, in
             idx2  = verseContent.indexOf("<", index, cs);
             strongsText = verseContent.mid(index, idx2 - index);
             index = idx2;
-            *startIndex = index;
+            startIndex = index;
 
             return(strongsText);
         }
