@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -16,13 +16,14 @@
 #include <QWidget>
 #include "backend/managers/cswordbackend.h"
 #include "backend/cswordmodulesearch.h"
+#include "frontend/display/creaddisplay.h"
+#include "frontend/searchdialog/analysis/csearchanalysisdialog.h"
 
 
 namespace Search {
 class CModuleResultView;
 class CSearchResultView;
 }
-class CReadDisplay;
 class CSwordModuleInfo;
 class QFrame;
 class QHBoxLayout;
@@ -44,73 +45,45 @@ namespace Search {
 *   To add a new verse to a strongs text result use addKeyName.
 */
 class StrongsResult {
-    public:
-        StrongsResult();
-        StrongsResult(const QString& text, const QString &keyName);
+    public: /* Methods: */
+        inline StrongsResult() {}
+        inline StrongsResult(const QString &text,
+                             const QString &keyName)
+            : m_text(text)
+        {
+            m_keyNameList.append(keyName);
+        }
 
-        QString keyText() const;
-        int keyCount() const;
-        void addKeyName(const QString& keyName);
-        QStringList* getKeyList();
+        const QString &keyText() const { return m_text; }
+        inline int keyCount() const { return m_keyNameList.count(); }
+        inline void addKeyName(const QString &keyName) {
+            if (m_keyNameList.contains(keyName)) return;
+            m_keyNameList.append(keyName);
+        }
 
-        /* ????
-        bool operator==(const StrongsResult &l, const StrongsResult &r)
-        	{ return (l.keyText() == r.keyText()); }
+        inline const QStringList &getKeyList() const { return m_keyNameList; }
 
-        bool operator<(const StrongsResult &l, const StrongsResult &r)
-        	{ return (l->keyText() < r->keyText()); }
-
-        bool operator>(const StrongsResult &l, const StrongsResult &r)
-        	{ return (l->keyText() > r->keyText()); }
-        */
-    private:
-        QString text;
-        QStringList keyNameList;
+    private: /* Fields: */
+        QString m_text;
+        QStringList m_keyNameList;
 };
 
-typedef QList<StrongsResult> StrongsResultList;
-
 /**
+* \todo Fix comment!
 * This class is used to keep track of the text strongs results.
 * It keeps track of all instances of all strongs text results.
 * This class makes use of the above class StrongsResult.
-*
-*    The functions of the class are:
-*       - Store an instance of a strongs text result.
-*       - Each strongs text result will contain a list of verses (keyNames).
-*       - The number of verses (keyNames) is returned by keyCount().
-*       - The text for the strongs text result is returned by keyText().
-*       - The list of verses (keyNames) is returned by getKeyList() [as QStringList].
-*
-*   To add a new verse to a strongs text result use addKeyName.
 */
-class StrongsResultClass {
-    public:
-        StrongsResultClass(CSwordModuleInfo* module, const QString& strongsNumber)
-                : srModule(module), lemmaText(strongsNumber) {
-            initStrongsResults();
-        }
+class StrongsResultList: public QList<StrongsResult> {
+    public: /* Methods: */
+        StrongsResultList(const CSwordModuleInfo *module,
+                          const sword::ListKey &results,
+                          const QString &strongsNumber);
 
-        QString keyText(int index) const {
-            return srList[index].keyText();
-        }
-        int keyCount(int index) const {
-            return srList[index].keyCount();
-        }
-        QStringList* getKeyList(int index) {
-            return srList[index].getKeyList();
-        }
-        int Count() const {
-            return srList.count();
-        }
-
-    private:
-        void initStrongsResults(void);
-        QString getStrongsNumberText(const QString& verseContent, int *startIndex);
-
-        StrongsResultList srList;
-        CSwordModuleInfo* srModule;
-        QString lemmaText;
+    private: /* Methods: */
+        QString getStrongsNumberText(const QString &verseContent,
+                                     int &startIndex,
+                                     const QString &lemmaText);
 };
 
 
@@ -119,18 +92,27 @@ class StrongsResultClass {
   */
 class BtSearchResultArea : public QWidget {
         Q_OBJECT
-    public:
+    public: /* Methods: */
         BtSearchResultArea(QWidget *parent = 0);
-        ~BtSearchResultArea();
+        inline ~BtSearchResultArea() { saveDialogSettings(); }
+
         /**
         * Sets the modules which contain the result of each.
         */
-        void setSearchResult(QList<CSwordModuleInfo*> modules);
+        void setSearchResult(
+            const CSwordModuleSearch::Results &results);
 
-        QSize sizeHint() const {
+        /**
+          Reimplemented from QWidget::sizeHint().
+        */
+        virtual QSize sizeHint() const {
             return baseSize();
         }
-        QSize minimumSizeHint() const {
+
+        /**
+          Reimplemented from QWidget::minimumSizeHint().
+        */
+        virtual QSize minimumSizeHint() const {
             return minimumSize();
         }
 
@@ -140,19 +122,22 @@ class BtSearchResultArea : public QWidget {
         */
         void reset();
 
-    protected:
+    protected: /* Methods: */
         /**
         * Initializes the view of this widget.
         */
         void initView();
+
         /**
         * Initializes the signal slot conections of the child widgets
         */
         void initConnections();
+
         /**
         * This function breakes the queryString into clucene tokens
         */
-        QStringList QueryParser(const QString& queryString);
+        QStringList queryParser(const QString& queryString);
+
         /**
         * This function highlights the searched text in the content using the search type given by search flags
         */
@@ -162,6 +147,7 @@ class BtSearchResultArea : public QWidget {
         * Load the settings from the resource file
         */
         void loadDialogSettings();
+
         /**
         * Save the settings to the resource file
         */
@@ -172,16 +158,33 @@ class BtSearchResultArea : public QWidget {
         * Update the preview of the selected key.
         */
         void updatePreview(const QString& key);
+
         /**
          * Clear the preview of the selected key.
          */
         void clearPreview();
+
         /**
         * Shows a dialog with the search analysis of the current search.
         */
-        void showAnalysis();
+        inline void showAnalysis() {
+            CSearchAnalysisDialog(m_results, this).exec();
+        }
 
-    private:
+        /**
+        * Select all text
+        */
+        inline void selectAll() { m_previewDisplay->selectAll(); }
+
+        /**
+        * Copy selected text
+        */
+        inline void copySelection() {
+            m_previewDisplay->connectionsProxy()->copySelection();
+        }
+
+    private: /* Fields: */
+        CSwordModuleSearch::Results m_results;
 
         CModuleResultView* m_moduleListBox;
         CSearchResultView* m_resultListBox;
@@ -189,10 +192,8 @@ class BtSearchResultArea : public QWidget {
         QFrame *m_displayFrame;
         CReadDisplay* m_previewDisplay;
 
-        QList<CSwordModuleInfo*> m_modules;
-
-        QSplitter *mainSplitter;
-        QSplitter *resultListSplitter;
+        QSplitter *m_mainSplitter;
+        QSplitter *m_resultListSplitter;
 };
 
 } //namespace Search
