@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -38,8 +38,7 @@ CModuleResultView::CModuleResultView(QWidget* parent)
 }
 
 CModuleResultView::~CModuleResultView() {
-    qDeleteAll(strongsResults);
-    strongsResults.clear();
+    qDeleteAll(m_strongsResults);
 }
 
 
@@ -98,32 +97,31 @@ void CModuleResultView::initConnections() {
             this, SLOT(executed(QTreeWidgetItem*, QTreeWidgetItem*)));
 }
 
-/** Setups the tree using the given list of modules. */
-void CModuleResultView::setupTree( QList<CSwordModuleInfo*> modules, const QString& searchedText ) {
+void CModuleResultView::setupTree(
+        const CSwordModuleSearch::Results &results,
+        const QString &searchedText)
+{
     clear();
+
+    m_results = results;
+
     /// \todo this class is for sorting
     //util::CSortListViewItem* item = 0;
     //util::CSortListViewItem* oldItem = 0;
     QTreeWidgetItem* item = 0;
-    QTreeWidgetItem* oldItem = 0;
 
-    sword::ListKey result;
-
-    qDeleteAll(strongsResults);
-    strongsResults.clear();
+    qDeleteAll(m_strongsResults);
+    m_strongsResults.clear();
 
     bool strongsAvailable = false;
 
-    QList<CSwordModuleInfo*>::iterator end_it = modules.end();
-    for (QList<CSwordModuleInfo*>::iterator it(modules.begin()); it != end_it; ++it) {
-        //   for (modules.first(); modules.current(); modules.next()) {
-        result = (*it)->searchResult();
+    Q_FOREACH(const CSwordModuleInfo *m, results.keys()) {
+        sword::ListKey result = results.value(m);
 
-        item = new QTreeWidgetItem(this, QStringList((*it)->name()) << QString::number(result.Count()) );
+        item = new QTreeWidgetItem(this, QStringList(m->name()) << QString::number(result.Count()) );
         /// \todo item->setColumnSorting(1, util::CSortListViewItem::Number);
 
-        item->setIcon(0, util::tool::getIconForModule(*it) );
-        oldItem = item;
+        item->setIcon(0, util::tool::getIconForModule(m) );
         //----------------------------------------------------------------------
         // we need to make a decision here.  Either don't show any Strong's
         // number translations, or show the first one in the search text, or
@@ -142,7 +140,7 @@ void CModuleResultView::setupTree( QList<CSwordModuleInfo*> modules, const QStri
             sTokenIndex = searchedText.indexOf(" ", sstIndex);
             sNumber = searchedText.mid(sstIndex, sTokenIndex - sstIndex);
 
-            setupStrongsResults((*it), item, sNumber);
+            setupStrongsResults(m, results[m], item, sNumber);
 
             /// \todo item->setOpen(true);
             strongsAvailable = true;
@@ -153,53 +151,50 @@ void CModuleResultView::setupTree( QList<CSwordModuleInfo*> modules, const QStri
     setRootIsDecorated( strongsAvailable );
 }
 
-void CModuleResultView::setupStrongsResults(CSwordModuleInfo* module, QTreeWidgetItem* parent,
-        const QString& sNumber) {
-    QString lText;
-    /// \todo
-    //util::CSortListViewItem* item = 0;
-    QTreeWidgetItem* item = 0;
+void CModuleResultView::setupStrongsResults(const CSwordModuleInfo *module,
+                                            const sword::ListKey &results,
+                                            QTreeWidgetItem *parent,
+                                            const QString &sNumber)
+{
+    StrongsResultList *m = new StrongsResultList(module, results, sNumber);
+    m_strongsResults[module] = m;
 
-    strongsResults[module] = new StrongsResultClass(module, sNumber);
-
-    for (int cnt = 0; cnt < strongsResults[module]->Count(); ++cnt) {
-        lText = strongsResults[module]->keyText(cnt);
-
-        item = new QTreeWidgetItem(parent, QStringList(lText) << QString::number(strongsResults[module]->keyCount(cnt)));
-        /// \todo
-        //item->setColumnSorting(1, util::CSortListViewItem::Number);
+    for (int cnt = 0; cnt < m->count(); ++cnt) {
+        QStringList columns(m->at(cnt).keyText());
+        columns.append(QString::number(m->at(cnt).keyCount()));
+        new QTreeWidgetItem(parent, columns);
     }
 }
 
 /// \todo
 /** Is executed when an item was selected in the list. */
 void CModuleResultView::executed( QTreeWidgetItem* i, QTreeWidgetItem*) {
-    QString itemText, lText;
+    QString itemText;
 
     if (!i) {
         //Clear list
         emit moduleChanged();
         return;
     }
-    if (CSwordModuleInfo* m = CPointers::backend()->findModuleByName(i->text(0))) {
+    if (CSwordModuleInfo *m = CSwordBackend::instance()->findModuleByName(i->text(0))) {
         emit moduleChanged();
-        emit moduleSelected(m);
+        emit moduleSelected(m, m_results.value(m));
         return;
     }
 
-    StrongsResultClass* strongsResult = strongsResults[activeModule()];
+    StrongsResultList *strongsResult = m_strongsResults[activeModule()];
 
     if (!strongsResult) {
         return;
     }
 
     itemText = i->text(0);
-    for (int cnt = 0; cnt < strongsResult->Count(); cnt++) {
-        lText = strongsResult->keyText(cnt);
-        if (lText == itemText) {
+    for (int cnt = 0; cnt < strongsResult->count(); cnt++) {
+        if (strongsResult->at(cnt).keyText() == itemText) {
             //clear the verses list
             emit moduleChanged();
-            emit strongsSelected(activeModule(), strongsResult->getKeyList(cnt));
+            emit strongsSelected(activeModule(),
+                                 strongsResult->at(cnt).getKeyList());
             return;
         }
     }
@@ -221,7 +216,7 @@ CSwordModuleInfo* CModuleResultView::activeModule() {
     }
 
     if (item) {
-        return CPointers::backend()->findModuleByName(item->text(0));
+        return CSwordBackend::instance()->findModuleByName(item->text(0));
     }
 
     return 0;
@@ -236,46 +231,57 @@ void CModuleResultView::contextMenuEvent( QContextMenuEvent * event ) {
 
 /** Copies the whole search result into the clipboard. */
 void CModuleResultView::copyResult() {
-    if (CSwordModuleInfo* m = activeModule()) {
-        sword::ListKey result = m->searchResult();
-        CExportManager mgr(tr("Copy search result..."), true, tr("Copying search result"));
-        mgr.copyKeyList(&result, m, CExportManager::Text, false);
+    CSwordModuleInfo *m = activeModule();
+    if (m != 0) {
+        CExportManager mgr(tr("Copy search result..."), true,
+                           tr("Copying search result"));
+
+        mgr.copyKeyList(m_results[m], m, CExportManager::Text, false);
     };
 }
 
 /** Copies the whole search result with the text into the clipboard. */
 void CModuleResultView::copyResultWithText() {
-    if (CSwordModuleInfo* m = activeModule()) {
-        sword::ListKey result = m->searchResult();
-        CExportManager mgr(tr("Copy search result..."), true, tr("Copying search result"));
-        mgr.copyKeyList(&result, m, CExportManager::Text, true);
+    CSwordModuleInfo *m = activeModule();
+    if (m != 0) {
+        CExportManager mgr(tr("Copy search result..."), true,
+                           tr("Copying search result"));
+
+        mgr.copyKeyList(m_results[m], m, CExportManager::Text, true);
     };
 }
 
 /** Saves the search result keys. */
 void CModuleResultView::saveResult() {
-    if (CSwordModuleInfo* m = activeModule()) {
-        sword::ListKey result = m->searchResult();
-        CExportManager mgr(tr("Save search result..."), true, tr("Saving search result"));
-        mgr.saveKeyList(&result, m, CExportManager::Text, false);
+    CSwordModuleInfo *m = activeModule();
+    if (m != 0) {
+        CExportManager mgr(tr("Save search result..."), true,
+                           tr("Saving search result"));
+
+        mgr.saveKeyList(m_results[m], m, CExportManager::Text, false);
     };
 }
 
 /** Saves the search result with it's text. */
 void CModuleResultView::saveResultWithText() {
-    if (CSwordModuleInfo* m = activeModule()) {
-        sword::ListKey result = m->searchResult();
-        CExportManager mgr(tr("Save search result..."), true, tr("Saving search result"));
-        mgr.saveKeyList(&result, m, CExportManager::Text, true);
+    CSwordModuleInfo *m = activeModule();
+    if (m != 0) {
+        CExportManager mgr(tr("Save search result..."), true,
+                           tr("Saving search result"));
+
+        mgr.saveKeyList(m_results[m], m, CExportManager::Text, true);
     };
 }
 
 /** Appends the whole search result to the printer queue. */
 void CModuleResultView::printResult() {
-    if (CSwordModuleInfo* m = activeModule()) {
-        sword::ListKey result = m->searchResult();
-        CExportManager mgr(tr("Print search result..."), true, tr("Printing search result"));
-        mgr.printKeyList(&result, m, CBTConfig::getDisplayOptionDefaults(), CBTConfig::getFilterOptionDefaults());
+    CSwordModuleInfo *m = activeModule();
+    if (m != 0) {
+        CExportManager mgr(tr("Print search result..."), true,
+                           tr("Printing search result"));
+
+        mgr.printKeyList(m_results[m], m, CBTConfig::getDisplayOptionDefaults(),
+                         CBTConfig::getFilterOptionDefaults());
     };
 }
 
