@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -11,6 +11,7 @@
 
 #include <QDebug>
 #include <QDialogButtonBox>
+#include <QLabel>
 #include <QLineEdit>
 #include <QPushButton>
 #include <QSettings>
@@ -24,7 +25,7 @@
 #include "backend/cswordmodulesearch.h"
 #include "backend/keys/cswordkey.h"
 #include "backend/keys/cswordversekey.h"
-#include "frontend/cmoduleindexdialog.h"
+#include "frontend/btmoduleindexdialog.h"
 #include "frontend/searchdialog/btsearchoptionsarea.h"
 #include "frontend/searchdialog/btsearchresultarea.h"
 #include "util/cresmgr.h"
@@ -36,7 +37,9 @@ namespace Search {
 
 static CSearchDialog* m_staticDialog = 0;
 
-void CSearchDialog::openDialog(const QList<CSwordModuleInfo*> modules, const QString& searchText, QWidget* parentDialog) {
+void CSearchDialog::openDialog(const QList<const CSwordModuleInfo*> modules,
+                               const QString &searchText, QWidget *parentDialog)
+{
     if (!m_staticDialog) {
         m_staticDialog = new CSearchDialog(parentDialog);
     };
@@ -81,7 +84,7 @@ CSearchDialog::CSearchDialog(QWidget *parent)
     setWindowIcon(DU::getIcon(CResMgr::searchdialog::icon));
     setWindowTitle(tr("Search"));
     setAttribute(Qt::WA_DeleteOnClose);
-    m_searcher.connectFinished( this, SLOT(searchFinished()));
+
     initView();
     initConnections();
 }
@@ -91,10 +94,9 @@ CSearchDialog::~CSearchDialog() {
     m_staticDialog = 0;
 }
 
-/** Starts the search with the set modules and the set search text. */
 void CSearchDialog::startSearch() {
+    typedef QList<const CSwordModuleInfo*> ML;
     QString originalSearchText(m_searchOptionsArea->searchText());
-    QString searchText("");
 
     // first check the search string for errors
     {
@@ -104,50 +106,72 @@ void CSearchDialog::startSearch() {
             return;
         }
     }
-
-    searchText = prepareSearchText(originalSearchText);
+    QString searchText = prepareSearchText(originalSearchText);
 
     // Insert search text into history list of combobox
     m_searchOptionsArea->addToHistory(originalSearchText);
 
-    // check that we have the indices we need for searching
-    if (!m_searcher.modulesHaveIndices( modules() ) )	{
-        int result = util::showQuestion(this, tr("Missing indices"),
-                                        tr("One or more works need indexing before they can be searched.\n"
-                                           "This could take a long time. Proceed with indexing?"),
-                                        QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes);
-        // In SuSE 10.0 the result is the logical or of the button type, just like it is
-        // inputed into the QMessageBox.
-        if ( (result == (QMessageBox::Yes | QMessageBox::Default)) ||
-                (result == QMessageBox::Yes) || (result == QMessageBox::Default) ) {
-            CModuleIndexDialog* dlg = CModuleIndexDialog::getInstance();
-            dlg->indexUnindexedModules( modules() );
+    // Check that we have the indices we need for searching
+    ML unindexedModules = CSwordModuleSearch::unindexedModules(modules());
+    if (unindexedModules.size() > 0) {
+        // Build the list of module names:
+        QStringList moduleNameList;
+        Q_FOREACH (const CSwordModuleInfo *m, unindexedModules) {
+            moduleNameList.append(m->name());
         }
-        else {
+        QString moduleNames("<br><center>");
+        moduleNames.append(moduleNameList.join(", "));
+        moduleNames.append("</center><br>");
+
+        // Ask the user about unindexed modules:
+        int result = util::showQuestion(
+                this, tr("Missing indices"),
+                tr("The following modules need to be indexed before they can be"
+                   " searched in:") + moduleNames + tr("Indexing could take a l"
+                   "ong time. Click \"Yes\" to index the modules and start the "
+                   "search, or \"No\" to cancel the search."),
+                QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes);
+
+        // User didn't press "Yes":
+        if ((result & (QMessageBox::Yes | QMessageBox::Default)) == 0x0) {
+            return;
+        }
+
+        // Show indexing dialog, and index the modules:
+        if (!BtModuleIndexDialog::indexAllModules(unindexedModules)) {
+            // Failed or user cancelled.
             return;
         }
     }
 
+    // Set the search options:
+    m_searcher.setSearchedText(searchText);
+    m_searcher.setModules(modules());
     if (m_searchOptionsArea->hasSearchScope()) {
-        m_searcher.setSearchScope( m_searchOptionsArea->searchScope() );
-    }
-    else {
+        m_searcher.setSearchScope(m_searchOptionsArea->searchScope());
+    } else {
         m_searcher.resetSearchScope();
     }
 
-    m_searcher.setModules( modules() );
-    m_searcher.setSearchedText(searchText);
-
-
-    //Just to be sure that it can't be clicked again, if the search happens to be a bit slow.
-    m_searchOptionsArea->searchButton()->setEnabled(false);
-    m_searchOptionsArea->m_searchTextCombo->setEnabled(false);
+    // Disable the dialog:
+    setEnabled(false);
+    setCursor(Qt::WaitCursor);
 
+    // Execute search:
     m_searcher.startSearch();
 
-    m_searchOptionsArea->searchButton()->setEnabled(true);
-    m_searchOptionsArea->m_searchTextCombo->setEnabled(true);
-    m_searchOptionsArea->m_searchTextCombo->setFocus();
+    // Display the search results:
+    if (m_searcher.foundItems() > 0) {
+        m_searchResultArea->setSearchResult(m_searcher.results());
+    } else {
+        m_searchResultArea->reset();
+    }
+    m_staticDialog->raise();
+    m_staticDialog->activateWindow();
+
+    // Re-enable the dialog:
+    setEnabled(true);
+    setCursor(Qt::ArrowCursor);
 }
 
 QString CSearchDialog::prepareSearchText(const QString& orig) {
@@ -179,8 +203,9 @@ QString CSearchDialog::prepareSearchText(const QString& orig) {
     return text;
 }
 
-/** Starts the search with the given module list and given search text. */
-void CSearchDialog::startSearch( const QList<CSwordModuleInfo*> modules, const QString& searchText) {
+void CSearchDialog::startSearch(const QList<const CSwordModuleInfo*> modules,
+                                const QString &searchText)
+{
     m_searchResultArea->reset();
     m_searchOptionsArea->reset();
     setModules(modules);
@@ -189,27 +214,8 @@ void CSearchDialog::startSearch( const QList<CSwordModuleInfo*> modules, const Q
     startSearch();
 }
 
-/** Returns the list of used modules. */
-QList<CSwordModuleInfo*> CSearchDialog::modules() const {
-    return m_searchOptionsArea->modules();
-}
-
-/** Sets the list of modules for the search. */
-void CSearchDialog::setModules( const QList<CSwordModuleInfo*> modules ) {
-    m_searchOptionsArea->setModules(modules);
-}
-
-/** Returns the search text which is set currently. */
-QString CSearchDialog::searchText() const {
-    return m_searchOptionsArea->searchText();
-}
-
-sword::ListKey CSearchDialog::searchScope() {
-    return m_searchOptionsArea->searchScope();
-}
-
 /** Sets the search text which is used for the search. */
-void CSearchDialog::setSearchText( const QString searchText ) {
+void CSearchDialog::setSearchText( const QString &searchText ) {
     m_searchOptionsArea->setSearchText(searchText);
 }
 
@@ -224,12 +230,16 @@ void CSearchDialog::initView() {
     verticalLayout->addWidget(m_searchOptionsArea);
 
     m_searchResultArea = new BtSearchResultArea(this);
+    m_searchResultArea->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
     verticalLayout->addWidget(m_searchResultArea);
 
+    QLabel* hint = new QLabel(tr("Drag any verse reference onto an open Bible window"), this);
+    verticalLayout->addWidget(hint);
+
     QHBoxLayout* horizontalLayout = new QHBoxLayout();
 
     m_analyseButton = new QPushButton(tr("&Analyze results..."), 0);
-    m_analyseButton->setToolTip(tr("Show a graphical analyzis of the search result"));
+    m_analyseButton->setToolTip(tr("Show a graphical analysis of the search result"));
     QSpacerItem* spacerItem = new QSpacerItem(1, 1, QSizePolicy::Expanding, QSizePolicy::Minimum);
     horizontalLayout->addWidget(m_analyseButton);
     horizontalLayout->addItem(spacerItem);
@@ -244,17 +254,6 @@ void CSearchDialog::initView() {
     loadDialogSettings();
 }
 
-void CSearchDialog::searchFinished() {
-    if ( m_searcher.foundItems() ) {
-        m_searchResultArea->setSearchResult(modules());
-    }
-    else {
-        m_searchResultArea->reset();
-    }
-    m_staticDialog->raise();
-    m_staticDialog->activateWindow();
-}
-
 void CSearchDialog::showModulesSelector() {
     m_searchOptionsArea->chooseModules();
 }
