@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -93,13 +93,16 @@ void CSearchResultView::initConnections() {
 }
 
 /** Setups the list with the given module. */
-void CSearchResultView::setupTree(CSwordModuleInfo* m) {
+void CSearchResultView::setupTree(const CSwordModuleInfo *m,
+                                  const sword::ListKey &results)
+{
     clear();
 
     if (!m) return;
 
     m_module = m;
-    sword::ListKey& result = m->searchResult();
+    /// \warning This is a workaround for Sword constness
+    sword::ListKey &result = const_cast<sword::ListKey&>(results);
     const int count = result.Count();
     if (!count) return;
 
@@ -118,24 +121,20 @@ void CSearchResultView::setupTree(CSwordModuleInfo* m) {
     this->setCurrentItem(this->topLevelItem(0), 0);
 }
 
-void CSearchResultView::setupStrongsTree(CSwordModuleInfo* m, QStringList* vList) {
+void CSearchResultView::setupStrongsTree(CSwordModuleInfo* m, const QStringList &vList) {
     clear();
-    if (!m) {
-        return;
-    }
+    if (!m) return;
 
     m_module = m;
 
-    if (vList->count() <= 0) {
-        return;
-    }
+    if (vList.empty()) return;
 
     setUpdatesEnabled(false);
 
     QTreeWidgetItem* oldItem = 0;
     QTreeWidgetItem* item = 0;
 
-    foreach (QString s, *vList) {
+    foreach (QString s, vList) {
         item = new QTreeWidgetItem(this, oldItem);
         item->setText(0, (s));
         oldItem = item;
@@ -180,13 +179,13 @@ void CSearchResultView::printItems() {
 void CSearchResultView::saveItems() {
     CExportManager mgr(tr("Save search result..."), true, tr("Saving search result"));
 
-    CSwordModuleInfo* m = module();
+    const CSwordModuleInfo *m = module();
     CSwordKey* k = 0;
     QList<QTreeWidgetItem*> items = selectedItems();
     QList<CSwordKey*> keys;
     foreach (QTreeWidgetItem* i, items) {
         k = CSwordKey::createInstance( m );
-        k->key(i->text(0));
+        k->setKey(i->text(0));
         keys.append( k );
     }
     mgr.saveKeyList( keys, CExportManager::Text, false);
@@ -198,13 +197,13 @@ void CSearchResultView::saveItems() {
 void CSearchResultView::saveItemsWithText() {
     CExportManager mgr(tr("Save search result..."), true, tr("Saving search result"));
 
-    CSwordModuleInfo* m = module();
+    const CSwordModuleInfo *m = module();
     CSwordKey* k = 0;
     QList<QTreeWidgetItem*> items = selectedItems();
     QList<CSwordKey*> keys;
     foreach (QTreeWidgetItem* i, items) {
         k = CSwordKey::createInstance( m );
-        k->key(i->text(0));
+        k->setKey(i->text(0));
         keys.append( k );
     };
     mgr.saveKeyList( keys, CExportManager::Text, true);
@@ -216,13 +215,13 @@ void CSearchResultView::saveItemsWithText() {
 void CSearchResultView::copyItems() {
     CExportManager mgr(tr("Copy search result..."), true, tr("Copying search result"));
 
-    CSwordModuleInfo* m = module();
+    const CSwordModuleInfo *m = module();
     CSwordKey* k = 0;
     QList<QTreeWidgetItem*> items = selectedItems();
     QList<CSwordKey*> keys;
     foreach (QTreeWidgetItem* i, items) {
         k = CSwordKey::createInstance( m );
-        k->key(i->text(0));
+        k->setKey(i->text(0));
         keys.append( k );
     };
     mgr.copyKeyList( keys, CExportManager::Text, false);
@@ -234,13 +233,13 @@ void CSearchResultView::copyItems() {
 void CSearchResultView::copyItemsWithText() {
     CExportManager mgr(tr("Copy search result..."), true, tr("Copying search result"));
 
-    CSwordModuleInfo* m = module();
+    const CSwordModuleInfo *m = module();
     CSwordKey* k = 0;
     QList<QTreeWidgetItem*> items = selectedItems();
     QList<CSwordKey*> keys;
     foreach (QTreeWidgetItem* i, items) {
         k = CSwordKey::createInstance( m );
-        k->key(i->text(0));
+        k->setKey(i->text(0));
         keys.append( k );
     };
     mgr.copyKeyList( keys, CExportManager::Text, true);
@@ -249,25 +248,21 @@ void CSearchResultView::copyItemsWithText() {
     keys.clear(); //delete all the keys we created
 }
 
-CSwordModuleInfo* CSearchResultView::module() {
-    return m_module;
-}
-
 /// \todo port this to the new d'n'd
 // Q3DragObject* CSearchResultView::dragObject() {
-// 	//return a valid DragObject to make DnD possible!
+//     //return a valid DragObject to make DnD possible!
 //
-// 	/*
-// 	* First get all selected items and fill with them the dndItems list. The return the QDragObject we got from CDRagDropMgr
-// 	*/
-// 	CDragDropMgr::ItemList dndItems;
+//     /*
+//     * First get all selected items and fill with them the dndItems list. The return the QDragObject we got from CDRagDropMgr
+//     */
+//     CDragDropMgr::ItemList dndItems;
 //
-// 	Q3PtrList<Q3ListViewItem> items = selectedItems();
-// 	for (items.first(); items.current(); items.next()) {
-// 		dndItems.append( CDragDropMgr::Item(m_module->name(), items.current()->text(0), QString::null) ); //no description
-// 	};
+//     Q3PtrList<Q3ListViewItem> items = selectedItems();
+//     for (items.first(); items.current(); items.next()) {
+//         dndItems.append( CDragDropMgr::Item(m_module->name(), items.current()->text(0), QString::null) ); //no description
+//     };
 //
-// 	return CDragDropMgr::dragObject(dndItems, viewport());
+//     return CDragDropMgr::dragObject(dndItems, viewport());
 // }
 
 
