@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -22,11 +22,14 @@ class QWebView;
 class CDisplaySettingsPage : public BtConfigPage {
         Q_OBJECT
     public:
-        CDisplaySettingsPage(QWidget* parent);
+        CDisplaySettingsPage(QWidget *parent = 0);
         void save();
-        QString iconName();
-        QString label();
-        QString header();
+
+        /** Reimplemented from BtConfigPage. */
+        virtual const QIcon &icon() const;
+
+        /** Reimplemented from BtConfigPage. */
+        virtual QString header() const;
 
     protected slots:
         /** Update the style preview widget. */
