@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2009 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -21,16 +21,18 @@
 #include <QWidget>
 #include "backend/config/cbtconfig.h"
 #include "util/cresmgr.h"
+#include "util/directory.h"
 #include "util/tool.h"
-#include "util/cpointers.h"
 
 
-CSwordSettingsPage::CSwordSettingsPage(QWidget* /*parent*/)
-        : BtConfigPage() {
-    QVBoxLayout* vbox = new QVBoxLayout(this);
+CSwordSettingsPage::CSwordSettingsPage(QWidget *parent)
+        : BtConfigPage(parent)
+{
+    Q_ASSERT(qobject_cast<QVBoxLayout*>(layout()) != 0);
+    QVBoxLayout *vbox = static_cast<QVBoxLayout*>(layout());
+
     QTabWidget* tabWidget = new QTabWidget();
     vbox->addWidget(tabWidget);
-    setLayout(vbox);
 
     m_worksTab = new StandardWorksTab();
     m_filtersTab = new TextFiltersTab();
@@ -50,10 +52,9 @@ StandardWorksTab::StandardWorksTab()
 
     gridLayout->addWidget(
         util::tool::explanationLabel(
-            this,
-            tr(""),
-            tr("Standard works are used when no particular work is specified, \
-  for example when a hyperlink into a Bible or lexicon was clicked .")),
+            this, "",
+            tr("Standard works are used when no particular work is specified, for example "
+               "when a hyperlink into a Bible or lexicon was clicked.")),
         0, 0, 1, 2 /*fill the horizontal space*/
     );
 
@@ -143,7 +144,7 @@ StandardWorksTab::StandardWorksTab()
 
     //fill the comboboxes with the right modules
 
-    const QList<CSwordModuleInfo*> &modules(backend()->moduleList());
+    const QList<CSwordModuleInfo*> &modules(CSwordBackend::instance()->moduleList());
     QString modDescript;
     for (MLCI it(modules.begin()); it != modules.end(); it++) {
         modDescript = (*it)->config(CSwordModuleInfo::Description);
@@ -178,7 +179,7 @@ StandardWorksTab::StandardWorksTab()
                     inserted = true;
                 }
 
-                if (!inserted) {	//daily dvotionals, striong lexicons etc. are not very useful for word lookups
+                if (!inserted) {    //daily dvotionals, striong lexicons etc. are not very useful for word lookups
                     m_standardLexiconCombo->addItem(modDescript);
                 }
                 break;
@@ -258,11 +259,10 @@ TextFiltersTab::TextFiltersTab() {
     QVBoxLayout* layout = new QVBoxLayout(this);
     layout->setMargin(5);
     QWidget* eLabel = util::tool::explanationLabel(
-                          this,
-                          tr(""),
-                          tr("Filters control the appearance of text. \
-Here you can specify default settings for all filters. \
-You can override these settings in each display window.")
+                          this, "",
+                          tr("Filters control the appearance of text. Here you can specify "
+                             "default settings for all filters. You can override these "
+                             "settings in each display window.")
                       );
     eLabel->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Preferred);
     eLabel->setMaximumHeight(50);
@@ -324,14 +324,11 @@ void CSwordSettingsPage::save() {
     m_filtersTab->save();
 }
 
-QString CSwordSettingsPage::iconName() {
-    return CResMgr::settings::sword::icon;
+const QIcon &CSwordSettingsPage::icon() const {
+    return util::directory::getIcon(CResMgr::settings::sword::icon);
 }
-QString CSwordSettingsPage::label() {
-    //: Empty string, don't translate
-    return tr("");
-}
-QString CSwordSettingsPage::header() {
+
+QString CSwordSettingsPage::header() const {
     return tr("Desk");
 }
 
@@ -369,9 +366,8 @@ void StandardWorksTab::save() {
                 qWarning("Unhandled module type.");
         };
 
-        CSwordModuleInfo* const module = backend()->findModuleByDescription(moduleDescription);
-        CBTConfig::set
-        (moduleType, module);
+        CSwordModuleInfo * const module = CSwordBackend::instance()->findModuleByDescription(moduleDescription);
+        CBTConfig::set(moduleType, module);
     }
 }
 
