@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2009 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -11,7 +11,6 @@
 #define CSWORDSETTINGS_H
 
 #include "frontend/bookshelfmanager/btconfigdialog.h"
-#include "util/cpointers.h"
 #include <QWidget>
 
 
@@ -23,11 +22,15 @@ class TextFiltersTab;
 class CSwordSettingsPage : public BtConfigPage {
         Q_OBJECT
     public:
-        CSwordSettingsPage(QWidget* parent);
+        CSwordSettingsPage(QWidget *parent = 0);
+
         void save();
-        QString iconName();
-        QString label();
-        QString header();
+
+        /** Reimplemented from BtConfigPage. */
+        virtual const QIcon &icon() const;
+
+        /** Reimplemented from BtConfigPage. */
+        virtual QString header() const;
 
     private:
         StandardWorksTab* m_worksTab;
@@ -36,7 +39,7 @@ class CSwordSettingsPage : public BtConfigPage {
 
 //Tab pages. To be used only in Sword settings page.
 
-class StandardWorksTab : public QWidget, CPointers {
+class StandardWorksTab: public QWidget {
         Q_OBJECT
     public:
         StandardWorksTab();
