@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -41,28 +41,28 @@ const QString icon_add       = "book_add.svg";
 
 namespace categories {
 namespace bibles {
-const QString icon 			= "bible.svg";
+const QString icon             = "bible.svg";
 }
 namespace commentaries {
-const QString icon 			= "commentary.svg";
+const QString icon             = "commentary.svg";
 }
 namespace lexicons {
-const QString icon 			= "lexicon.svg";
+const QString icon             = "lexicon.svg";
 }
 namespace dailydevotional {
-const QString icon 			= "calendar.svg";
+const QString icon             = "calendar.svg";
 }
 namespace books {
-const QString icon 			= "books.svg";
+const QString icon             = "books.svg";
 }
 namespace glossary {
-const QString icon 			= "dictionary.svg";
+const QString icon             = "dictionary.svg";
 }
 namespace images {
-const QString icon 			= "map.svg";
+const QString icon             = "map.svg";
 }
 namespace cults {
-const QString icon 			= "questionable.svg";
+const QString icon             = "questionable.svg";
 }
 }//categories
 namespace mainMenu { //Main menu
@@ -141,6 +141,11 @@ const QString icon        = "tile_auto.svg";
 const QKeySequence accel(Qt::CTRL + Qt::ALT + Qt::Key_I);
 const char* actionName    = "windowAutoTile_action";
 }
+namespace autoTabbed {
+const QString icon        = "tabbed.svg";
+const QKeySequence accel(Qt::CTRL + Qt::ALT + Qt::Key_T);
+const char* actionName    = "windowAutoTabbed_action";
+}
 namespace autoCascade {
 const QString icon        = "cascade_auto.svg";
 const QKeySequence accel(Qt::CTRL + Qt::ALT + Qt::Key_J);
@@ -199,6 +204,11 @@ const QString icon        = "contents2.svg";
 const QKeySequence accel(Qt::Key_F2);
 const char* actionName    = "helpHowTo_action";
 }
+namespace tipOfTheDay {
+const QString icon        = "light_bulb.svg";
+const QKeySequence accel(Qt::Key_F3);
+const char* actionName    = "tipOfTheDay_action";
+}
 }//mainMenu::help
 }  //end of mainMenu
 
@@ -238,9 +248,9 @@ const QString icon = "print.svg";
 } //searchDialog
 
 namespace displaywindows {
-/*		namespace transliteration {
-			const QString icon = "bt_displaytranslit";
-		}*/
+/*        namespace transliteration {
+            const QString icon = "bt_displaytranslit";
+        }*/
 namespace displaySettings {
 const QString icon = "displayconfig.svg";
 }
@@ -306,7 +316,7 @@ const QString icon = "print.svg";
 namespace commentaryWindow {
 namespace syncWindow {
 const QString icon   = "sync.svg";
-const QKeySequence accel;
+const QKeySequence accel(Qt::SHIFT + Qt::Key_S);
 const char* actionName = "commentary_syncWindow";
 }
 }
@@ -411,6 +421,9 @@ const QString icon = "startconfig.svg";
 namespace fonts {
 const QString icon = "fonts.svg";
 }
+namespace languages {
+const QString icon = "flag.svg";
+}
 namespace profiles {
 const QString icon = "view_profile.svg";
 }
@@ -445,7 +458,13 @@ const QString icon = "folder.svg";
 namespace bookmark {
 const QString icon = "bookmark.svg";
 }
-namespace changeBookmark {
+namespace editBookmark {
+const QString icon = "bookmark.svg";
+}
+namespace sortFolderBookmarks {
+const QString icon = "bookmark.svg";
+}
+namespace sortAllBookmarks {
 const QString icon = "bookmark.svg";
 }
 namespace importBookmarks {
@@ -505,13 +524,5 @@ const QString add_icon = "plus";
 const QString edit_icon = "pencil";
 const QString remove_icon = "trash";
 }
-}
-
-}
-
-
-
-namespace CResMgr {
-void init_tr() {
-} //init_tr()
-} //CResMgr
+} // namespace bookshelfmgr
+} // namespace CResMgr
