@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2011 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -14,7 +14,6 @@
 #include <QString>
 
 namespace CResMgr {
-void init_tr();
 
 namespace mainWindow {
 extern const QString icon;
@@ -145,6 +144,11 @@ extern const QString icon;
 extern const QKeySequence accel;
 extern const char* actionName;
 }
+namespace autoTabbed {
+extern const QString icon;
+extern const QKeySequence accel;
+extern const char* actionName;
+}
 namespace autoCascade {
 extern const QString icon;
 extern const QKeySequence accel;
@@ -206,6 +210,11 @@ extern const QString icon;
 extern const QKeySequence accel;
 extern const char* actionName;
 }
+namespace tipOfTheDay {
+extern const QString icon;
+extern const QKeySequence accel;
+extern const char* actionName;
+}
 }
 }  //end of main menu
 
@@ -426,6 +435,9 @@ extern const QString icon;
 namespace fonts {
 extern const QString icon;
 }
+namespace languages {
+extern const QString icon;
+}
 namespace profiles {
 extern const QString icon;
 }
@@ -460,7 +472,13 @@ extern const QString icon;
 namespace bookmark {
 extern const QString icon;
 }
-namespace changeBookmark {
+namespace editBookmark {
+extern const QString icon;
+}
+namespace sortFolderBookmarks {
+extern const QString icon;
+}
+namespace sortAllBookmarks {
 extern const QString icon;
 }
 namespace importBookmarks {
